unit AddLineDlg;

interface

uses
  Winapi.Windows,
  Winapi.Messages,
  System.SysUtils,
  System.Variants,
  System.Classes,
  Vcl.Graphics,
  Vcl.Controls,
  Vcl.Forms,
  Vcl.Dialogs,
  Vcl.StdCtrls,

  Codec,
  VaxServerConstants,
  VaxTeleServerSIP;


type TAddLineForm = class(TForm)
    Label1: TLabel;
    ComboLine: TComboBox;
    GroupBox1: TGroupBox;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    EditAuthUser: TEdit;
    EditPassword: TEdit;
    EditDomainRealm: TEdit;
    EditProxyIP: TEdit;
    GroupBox2: TGroupBox;
    Label7: TLabel;
    Label8: TLabel;
    ListBoxEnableCodecs: TListBox;
    ListBoxDisableCodecs: TListBox;
    btnDisableCodec: TButton;
    btnEnableCodec: TButton;
    GroupBox3: TGroupBox;
    RadioRejectCall: TRadioButton;
    RadioConnectToUser: TRadioButton;
    RadioPutInConf: TRadioButton;
    ComboConnectToUser: TComboBox;
    ComboPutInConf: TComboBox;
    btnAddLine: TButton;
    btnRemoveLine: TButton;
    btnClear: TButton;
    Label9: TLabel;
    Label10: TLabel;
    Label11: TLabel;
    Label12: TLabel;
    Label13: TLabel;
    Label14: TLabel;
    Label15: TLabel;
    EditUserName: TEdit;
    EditDisplayName: TEdit;
    Label16: TLabel;
    CheckBoxRegLine: TCheckBox;

    procedure AddLine_Click(Sender: TObject);
    procedure RemoveLine_Click(Sender: TObject);
    procedure ComboLine_SelIndexChanged(Sender: TObject);
    procedure DisableCodec_Click(Sender: TObject);
    procedure EnableCodec_Click(Sender: TObject);
    procedure ClearDlg_Click(Sender: TObject);
    procedure OnCreate(Sender: TObject);

    public
    constructor Create(AOwner : TComponent; var pVaxTeleSIP : TVaxTeleServerSIP); reintroduce; overload;

  private

    procedure ShowUsers();
    procedure ShowLines();
    procedure ShowConfs();

    function AddLineChecks(var sInCallTo : string; var lInCallType : long) : boolean;
    procedure ClearDlgContent();
    procedure LoadCodecs();

    procedure UpdateDlgContent(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sRealm, sProxy, sCodecList : string; bRegister : boolean; lToPeerType : long; sToPeerName : string; bBlock, bAddToConf : boolean; sRoomName : string);
    procedure UpdateIncomingCallSection(nToPeerType : integer; sToPeerName : string; bRejected, bAddToConf : boolean; sRoomName : string);

  public

    procedure OnSetActive();

  end;

var
    AddLineForm: TAddLineForm;
    m_objCodecs : TCodec;
    m_pVaxTeleSIP : TVaxTeleServerSIP;
implementation

{$R *.dfm}

    constructor TAddLineForm.Create(AOwner : TComponent; var pVaxTeleSIP : TVaxTeleServerSIP);
    begin
        inherited Create(AOwner);
        m_pVaxTeleSIP := pVaxTeleSIP;
    end;

// functions

procedure TAddLineForm.ShowUsers();

var
nIndex : integer;
objListUsers : TStringList;

begin
    ComboConnectToUser.Items.Clear();

    objListUsers := TStringList.Create();
    m_pVaxTeleSIP.GetUserAll(objListUsers);

    if(objListUsers.Count <= 0) then
        exit;

    for nIndex := 0 to objListUsers.Count - 1 do
        ComboConnectToUser.Items.Add(objListUsers[nIndex]);

    ComboConnectToUser.ItemIndex := 0;
end;

procedure TAddLineForm.ShowLines();

var
    objListLines : TStringList;
    nIndex: Integer;

    sLineName, sDisplayName, sUserName, sAuthUser : string;
    sAuthPwd, sDomainRealm, sProxySIP : string;
    sCodecList, sToPeerName, sRoomName : string;

    nToPeerType : integer;

    bRegister, bBlock, bAddToConf : boolean;

begin

    ComboLine.Clear;

    sDisplayName := '';
    sUserName := '';
    sAuthUser := '';
    sAuthPwd := '';
    sDomainRealm := '';
    sProxySIP := '';
    sCodecList := '';
    sToPeerName := '';
    sRoomName := '';

    nToPeerType := -1;

    bRegister := false;
    bBlock := false;
    bAddToConf := false;

    objListLines := TStringList.Create();
    m_pVaxTeleSIP.GetLineAll(objListLines);

    if(objListLines.Count <= 0) then
    begin
        RadioRejectCall.Checked := True;
        //UpdateDlgContent('', '8051', '8051', '8051', '8051', '192.168.0.119', '192.168.0.119', '23014', true, -1, '', true, false, '');
        exit;
    end;

    for nIndex := 0 to objListLines.Count - 1 do
        ComboLine.Items.Add(objListLines[nIndex]);

    ComboLine.ItemIndex := 0;

    sLineName := ComboLine.Items[ComboLine.ItemIndex];

    m_pVaxTeleSIP.GetLineDetails(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);
    UpdateDlgContent(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);

end;

procedure TAddLineForm.ShowConfs();

var
    objListRooms : TStringList;
    nIndex: Integer;

begin

    objListRooms := TStringList.Create();
    m_pVaxTeleSIP.GetRoomAll(objListRooms);

    if(objListRooms.Count <= 0) then
        exit;

    for nIndex := 0 to objListRooms.Count - 1 do
        ComboPutInConf.Items.Add(objListRooms[nIndex]);
end;

procedure TAddLineForm.OnSetActive();
begin
    ShowUsers();
    ShowConfs();
    ShowLines();
end;

function TAddLineForm.AddLineChecks(var sInCallTo : string; var lInCallType : long) : boolean;
begin

    if(Length(ComboLine.Text ) = 0) then
    begin
      ShowMessage('Please enter line name.');
      exit;
    end;

    if(ListBoxEnableCodecs.Items.Count <= 0) then
    begin
      ShowMessage('Please select a codec.');
      exit;
    end;

    lInCallType := -1;

    if(RadioRejectCall.Checked = true) then
        sInCallTo := '';

    if(RadioConnectToUser.Checked = true) then
    begin

        if(ComboConnectToUser.ItemIndex = -1) then
        begin
            ShowMessage('Please select a user to forward the incoming call.');
            exit;
        end;

        lInCallType := TVaxServerConstants.VAX_PEER_TYPE_USER;
        sInCallTo := ComboConnectToUser.Text;
    end;

    if(RadioPutInConf.Checked = true) then
    begin
         if(ComboPutInConf.ItemIndex = -1) then
         begin
           ShowMessage('Please select a conference room.');
           exit;
         end;

         sInCallTo := ComboPutInConf.Text;
    end;

end;
procedure TAddLineForm.ClearDlgContent();
begin
      ComboLine.Text := '';

      EditUserName.Text := '';
      EditAuthUser.Text := '';
      EditPassword.Text:= '';
      EditDisplayName.Text := '';
      EditDomainRealm.Text := '';
      EditProxyIP.Text := '';

      if(ComboConnectToUser.Items.Count > 0) then
          ComboConnectToUser.ItemIndex := 0;

      if(ComboPutInConf.Items.Count > 0) then
          ComboPutInConf.ItemIndex := 0;

      CheckBoxRegLine.Checked := false;
      RadioRejectCall.Checked := true;

      ListBoxEnableCodecs.Items.Clear();
      ListBoxDisableCodecs.Items.Clear();

      LoadCodecs();

end;

procedure TAddLineForm.LoadCodecs();
var
  nIndex : Integer;

begin

    for nIndex := 0 to m_objCodecs.TOTAL_SIZE_CODEC - 1  do
    begin
        ListBoxEnableCodecs.Items.Add(m_objCodecs.GetCodecName(IntToStr(nIndex)));
    end;
end;

procedure TAddLineForm.UpdateDlgContent(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sRealm, sProxy, sCodecList : string; bRegister : boolean; lToPeerType : long; sToPeerName : string; bBlock, bAddToConf : boolean; sRoomName : string);

var
nIndex : integer;
sCodecName : string;
sChar : char;

begin

    EditDisplayName.Text := sDisplayName;
    EditUserName.Text := sUserName;

    EditAuthUser.Text := sAuthUser;
    EditPassword.Text := sAuthPwd;
    EditDomainRealm.Text := sRealm;
    EditProxyIP.Text := sProxy;

    CheckBoxRegLine.Checked := bRegister;

    UpdateIncomingCallSection(lToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);

    ListBoxEnableCodecs.Items.Clear();
    ListBoxDisableCodecs.Items.Clear();

    for nIndex := 0 to m_objCodecs.TOTAL_SIZE_CODEC -1 do
        ListBoxDisableCodecs.Items.Add(m_objCodecs.GetCodecName(IntToStr(nIndex)));

    for nIndex := 0 to Length(sCodecList) -1 do
    begin
        sCodecName := m_objCodecs.GetCodecName(sCodecList[nIndex+1]);
        ListBoxEnableCodecs.Items.Add(sCodecName);
        ListBoxDisableCodecs.Items.Delete(ListBoxDisableCodecs.Items.IndexOf(sCodecName));
    end;

end;

procedure TAddLineForm.UpdateIncomingCallSection(nToPeerType : integer; sToPeerName : string; bRejected, bAddToConf : boolean; sRoomName : string);

var
nIndex : integer;

begin

    if(bRejected = true ) then
        RadioRejectCall.Checked := true;

    if(nToPeerType = TVaxServerConstants.VAX_PEER_TYPE_USER) then
    begin
        nIndex := ComboConnectToUser.Items.IndexOf(sToPeerName);
        if(nIndex = -1) then
        begin
            RadioRejectCall.Checked := true;
            exit;
        end;

        ComboConnectToUser.ItemIndex := nIndex;
        RadioConnectToUser.Checked := true;

    end;

    if(bAddToConf = true) then
    begin

        nIndex := ComboPutInConf.Items.IndexOf(sRoomName);

        if(nIndex = -1) then
        begin

            RadioRejectCall.Checked := true;
            exit;

        end;

        ComboPutInConf.ItemIndex := nIndex;
        RadioPutInConf.Checked := true;

    end;

end;

// events

procedure TAddLineForm.AddLine_Click(Sender: TObject);

var
sInCallTo, sCodecList, sCodecName, sCodecNo, sToPeerName , sRoomName : string;
lInCallType, nIndex, nToPeerType : integer;
bRejected, bAddToConf : boolean;

begin

    sInCallTo := '';
    lInCallType := -1;

    if(AddLineChecks(sInCallTo, lInCallType) = false) then
        exit;

    if(ComboLine.Items.IndexOf(ComboLine.Text) <> -1) then
    begin
        ShowMessage('Line alrady exists.');
        exit;
    end;

    // Get the codec list

    sCodecList := '';
    sCodecName := '';
    for nIndex := 0 to ListBoxEnableCodecs.Items.Count - 1 do
    begin
        sCodecName := ListBoxEnableCodecs.Items[nIndex];    // get codec name
        sCodecNo := m_objCodecs.GetCodecNo(sCodecName);  // use codec name and get codec no
        sCodecList := sCodecList + sCodecNo;     // concat all these codec numbers
    end;

   if(RadioRejectCall.Checked = true) then
    bRejected := true;

   if(RadioConnectToUser.Checked = true) then
   begin
        nToPeerType := TVaxServerConstants.VAX_PEER_TYPE_USER;
        sToPeerName := ComboConnectToUser.Items[ComboConnectToUser.ItemIndex];
   end;

   if(RadioPutInConf.Checked = true) then
   begin
        sRoomName := ComboPutInConf.Text;
        bAddToConf := true;
   end;

    if(m_pVaxTeleSIP.AddLine(ComboLine.Text, EditDisplayName.Text, EditUserName.Text, EditAuthUser.Text, EditPassword.Text, EditDomainRealm.Text, EditProxyIP.Text, sCodecList, CheckBoxRegLine.Checked, nToPeerType, sToPeerName, bRejected, bAddToConf, sRoomName) = false) then
    begin
        ShowMessage('Line not added.');
        exit;
    end;

    ComboLine.Items.Add(ComboLine.Text );
    ShowMessage('Line created successfully.');

end;


procedure TAddLineForm.ClearDlg_Click(Sender: TObject);
begin
    ClearDlgContent();
end;
procedure TAddLineForm.ComboLine_SelIndexChanged(Sender: TObject);

var
    objListLines : TStringList;
    nIndex: Integer;

    sDisplayName, sUserName, sAuthUser : string;
    sAuthPwd, sDomainRealm, sProxySIP : string;
    sCodecList, sToPeerName, sRoomName : string;

    nToPeerType : integer;

    bRegister, bBlock, bAddToConf : boolean;

begin

    if(ComboLine.Items.Count <= 0) then
        Exit;

    m_pVaxTeleSIP.GetLineDetails(ComboLine.Text, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);
    UpdateDlgContent(ComboLine.Text, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);

end;

procedure TAddLineForm.DisableCodec_Click(Sender: TObject);
begin
    if(ListBoxEnableCodecs.Items.Count <= 0) then
        exit;

    if(ListBoxEnableCodecs.ItemIndex = -1) then
    begin
        ShowMessage('Please choose a codec first');
        exit;
    end;

    ListBoxDisableCodecs.Items.Add(ListBoxEnableCodecs.Items[ListBoxEnableCodecs.ItemIndex]);
    ListBoxEnableCodecs.Items.Delete(ListBoxEnableCodecs.ItemIndex);
end;
procedure TAddLineForm.EnableCodec_Click(Sender: TObject);
begin
    if(ListBoxDisableCodecs.Items.Count <= 0) then
        exit;

    if(ListBoxDisableCodecs.ItemIndex = -1) then
    begin
        ShowMessage('Please choose a codec first');
        exit;
    end;

    ListBoxEnableCodecs.Items.Add(ListBoxDisableCodecs.Items[ListBoxDisableCodecs.ItemIndex]);
    ListBoxDisableCodecs.Items.Delete(ListBoxDisableCodecs.ItemIndex);
end;
procedure TAddLineForm.RemoveLine_Click(Sender: TObject);

var
sLineName : string;
nIndex : integer;

begin

    sLineName := ComboLine.Items[ComboLine.ItemIndex];

    if(Length(sLineName) = 0) then
    begin
        ShowMessage('Please enter a line.');
        exit;
    end;

    m_pVaxTeleSIP.RemoveLine(sLineName);

    ComboLine.Items.Delete(ComboLine.ItemIndex);

    ShowMessage('Line removed successfully.');
    ClearDlgContent();
end;

procedure TAddLineForm.OnCreate(Sender: TObject);
begin
    LoadCodecs();
end;

end.
