unit VaxServerExCOM;

interface

uses
    VaxServerCOM,
    VaxServerRoot,
    VaxServerConstants,
    System.Variants;

type TVaxServerExCOM = class(TVaxServerCOM)


        /////////////////////////////////////////////////////////////////////////////////////////////////
        ///     Data Members
        /////////////////////////////////////////////////////////////////////////////////////////////////

        private

        const MAX_VAX_SERVER_SIP_REF_COUNT       = 7;

        public
        procedure OnLineRegisterTrying( sLineName : string); override;
        procedure OnLineRegisterFail( sLineName : string; nStatusCode : integer;  sReasonPhrase : string); override;
        procedure OnLineRegisterSuccess( sLineName : string); override;
        procedure OnLineUnRegisterTrying( sLineName : string); override;
        procedure OnLineUnRegisterFail( sLineName : string; nStatusCode : integer;  sReasonPhrase : string); override;
        procedure OnLineUnRegisterSuccess( sLineName : string); override;

        procedure OnUnRegisterUser( sUserLogin : WideString); override;
        procedure OnRegisterUser(sUserLogin: WideString; sDomain: WideString; sFromIP: WideString; nFromPort: Integer); override;
        procedure OnRegisterUserSuccess(sUserLogin: WideString); override;
        procedure OnRegisterUserFail( sUserLogin : WideString); override;

        procedure OnChatMessageText( nChatMsgId : integer;  sMsgFrom : string;  sMsgTo : string;  sMsgText : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer); override;
        procedure OnChatMessageTyping( nChatMsgId : integer;  sMsgFrom : string;  sMsgTo : string;  IsTypingStart : integer;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer); override;
        procedure OnChatStatusSubscribe( nSubscrbId : integer;  sMsgFrom : string;  sMsgTo : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer); override;

        procedure OnChatMessageSuccess( nChatMsgId : integer); override;
        procedure OnChatMessageFailure(ChatMsgId: Integer; StatusCode: Integer; const ReasonPhrase: WideString); override;
        procedure OnChatMessageTimeout( nChatMsgId : integer); override;

        procedure OnCallSessionOpen( nSessionId : integer;  sCallerName : string;  sCallerId : string;  sDialNo : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer); override;
        procedure OnCallSessionFailed( nSessionId : integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString); override;
        procedure OnCallSessionConnected( nSessionId : integer); override;
        procedure OnCallSessionClosed( nSessionId : integer; CallType: Integer; ReasonCode: Integer); override;

        procedure OnCallSessionConnecting(SessionId: Integer; CallType: Integer;StatusCode: Integer;
                                            const ReasonPhrase: WideString); override;
        procedure OnCallSessionLost(SessionId: Integer; CallType: Integer);  override;
        procedure OnCallSessionHangup(SessionId: Integer;CallType: Integer); override;
        procedure OnCallSessionTimeout(SessionId: Integer; CallType: Integer); override;
        procedure OnCallSessionCancelled(SessionId: Integer); override;


        procedure OnCallSessionOnHold( nSessionId : integer; CallType: Integer); override;
        procedure OnCallSessionOffHold( nSessionId : integer; CallType: Integer); override;

        procedure OnCallSessionTransferBlind(TransfererSessionId: Integer; lTransfererCallType: Integer; const Transferer: WideString;
                                            const Transferee: WideString; const TransferTo: WideString); override;
        procedure OnCallSessionTransferConsult(TransfererSessionId: Integer; TransfereeSessionId: Integer; TransferToSessionId: Integer;
                                                lTransfererCallType: Integer; lTransfereeCallType: Integer;lTransferToCallType: Integer;
                                                const Transferer: WideString; const Transferee: WideString; const TransferTo: WideString); override;

        procedure OnCallSessionTransfering( nSessionId : integer; TransferType: Integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString); override;
        procedure OnCallSessionTransferFailed( nSessionId : integer; TransferType: Integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString); override;
        procedure OnCallSessionTransferTimeout( nSessionId : integer; TransferType: Integer; CallType: Integer); override;
        procedure OnCallSessionTransfered( nSessionId : integer; TransferType: Integer); override;

        procedure OnDigitDetectDTMF( nSessionId : integer;  sDigitDTMF : string); override;

        procedure OnOutgoingDiagnosticLog( sMsgSIP : string;  sToIP : string;  nToPort : integer); override;
        procedure OnIncomingDiagnosticLog( sMsgSIP : string;  sFromIP : string;  nFromPort : integer); override;

        procedure OnVaxTeleTick( nTickId : integer); override;

        procedure OnSendTimeOutVM( nMsgIdVM : integer); override;
        procedure OnSendSuccessVM( nMsgIdVM : integer); override;

        procedure OnCallSessionDialToneStart( nSessionId : integer;  nWaveId : integer); override;
        procedure OnCallSessionDialToneStop( nSessionId : integer;  nWaveId : integer); override;

        procedure OnCallSessionCreated(nSessionId : Integer;  nCallType : integer;  nReasonCode : integer); override;
        procedure OnCallSessionOpenCall(nSessionId : Integer;  nCallType : integer;  nPeerType : integer;  sPeerName : string); override;

        procedure OnCallSessionCloseCall(nSessionId : Integer;  nCallType : integer;  nPeerType : integer;  sPeerName : string); override;
        procedure OnCallSessionDetectedAMD(nSessionId : Integer;  nCallType : integer;  bIsHuman : Boolean); override;

        {///////////////////////////////////////////////////////////////////////////////
        ///////////////////     Functions
        ///////////////////////////////////////////////////////////////////////////////}

        public

        constructor Create();

        procedure SetLicenseKey(sLicenseKey : string);

        function Initialize(sDomainRealm : string;  sSIPListenIP : string; nSIPListenPort : integer ;  sRTPListenIP : string; nRTPListenPort : integer ) : boolean;
        procedure UnInitialize();

        function AddUser( sUserName : string;  sPassword : string;  sCodecList : string) : boolean;
        procedure RemoveUser( sUserName : string);

        function AcceptRegister( sUserName : string) : boolean;
        function RejectRegister( sUserName : string; lStatusCode : integer;  sReasonPhrase : string) : boolean;
        function AuthRegister( sUserName : string) : boolean;

        function AddLine( sLineName : string;  sDisplayName : string;  sUserName : string;  sAuthUser : string;  sAuthPwd : string;  sDomainRealm : string;  sProxySIP : string;  sOutboundProxySIP : string;  sCodecList : string) : boolean;
        procedure RemoveLine( sLineName : string);

        function RegisterLine( sLineName : string) : boolean;
        function UnRegisterLine( sLineName : string) : boolean;

        function AddDirectProxySIP( sProxyName : string;  sAuthLogin : string;  sAuthPwd : string;  sDomainRealm : string;  sProxyIP : string; lProxyPort : integer ;  sCodecList : string) : boolean;
        procedure RemoveDirectProxySIP( sProxyName : string);

        function AcceptCallSession(lSessionId : integer ;  sCallerName : string;  sCallerId : string;  sDialNo : string;  nToPeerType : integer ;  sToPeerName : string; lTimeOut : integer ) : boolean;
        procedure RejectCallSession(lSessionId : integer ; lStatusCode : integer ;  sReasonPhrase : string);
        procedure CloseCallSession(lSessionId : integer );

        function CreateCallSession( sCallerName : string;  sCallerId : string;  sDialNo : string;  nToPeerType : integer ;  sToPeerName : string; lTimeOut : integer ) : integer;
        function OpenCallSession( sCallerName : string;  sCallerId : string;  sDialNo : string;  nToPeerType : integer ;  sToPeerName : string; lTimeOut : integer ) : integer;

        function AcceptTransferBlind(lTransfererSessionId : integer ;  sCallerName : string;  sCallerId : string;  sTransferTo : string;  nToPeerType : integer ;  sToPeerName : string; lTimeOut : integer) : Integer;
        function AcceptTransferConsult(lTransfererSessionId : integer ; lTransferToSessionId : integer ) : Integer;
        procedure RejectTransfer(lSessionId : integer );

        function PlayWaveStartToCallSession(lSessionId : integer ; lWaveId : integer ; bLoop : boolean) : boolean;
        function PlayWaveStopToCallSession(lSessionId : integer ) : boolean;

        function RecordWaveStartToCallSession(lSessionId : integer ;  sFileName : string) : boolean;
        function RecordWaveStopToCallSession(lSessionId : integer ) : boolean;
        function RecordWavePauseToCallSession(lSessionId : integer ; bEnable : boolean) : boolean;

        function LoadWaveFile( sFileName : string) : integer;
        procedure UnLoadWaveFile(lWaveId : integer);

        function LoadMusicHold( sFileName : string) : boolean;
        procedure UnLoadMusicHold();

        function AcceptOnHoldRequest(lSessionId  : integer ) : boolean;
        function AcceptOffHoldRequest(lSessionId : integer ) : boolean;

        function AcceptChatMessage(lChatMsgId : integer ;  nToPeerType : integer ;  sToPeerName : string) : boolean;
        procedure RejectChatMessage(lChatMsgId : integer ; lStatusCode : integer ;  sReasonPhrase : string);

        function AcceptChatStatusSubscribe(lStatusSubscribe : integer ;  sMsgFrom : string;  sMsgTo : string;  nToPeerType : integer ;  sToPeerName : string) : boolean;
        procedure RejectChatStatusSubscribe(lStatusSubscribe : integer ;  sMsgFrom : string;  sMsgTo : string);

        function OpenConferenceRoom( sRoomName : string) : boolean;
        procedure CloseConferenceRoom( sRoomName : string);

        function AddCallSessionToConferenceRoom( sRoomName : string;  lSessionId : integer ;  nType : integer ) : boolean;
        function RemoveCallSessionFromConferenceRoom( lSessionId : integer ) : boolean;

        function PlayWaveStartToConferenceRoom( sRoomName : string;  lWaveId : integer ;  bLoop : boolean) : boolean;
        function PlayWaveStopToConferenceRoom( sRoomName : string) : boolean;

        function RecordWaveStartToConferenceRoom( sRoomName : string;  sFileName : string) : boolean;
        function RecordWaveStopToConferenceRoom( sRoomName : string) : boolean;
        function RecordWavePauseToConferenceRoom( sRoomName : string; bEnable : boolean) : boolean;

        function VoiceSessionLost(bEnable : boolean; lTimeOut : integer ) : boolean;

        function SendInfoVM( sUserLogin : string;  nNewMsgCount : integer ;  nOldMsgCount : integer ; bMsgWaiting : Boolean ) : integer;

        function StartVaxTeleTick(lTickId : integer ; lElapse : integer ) : boolean;
        function StopVaxTeleTick(lTickId : integer ) : boolean;

        function SetUserAgentName( sName : string) : boolean;
        function GetUserAgentName() : string;

        function SetSessionNameSDP( sName : string) : boolean;
        function GetSessionNameSDP() : string;

        function SendDTMFCallSession( lSessionId : integer ;  nTypeDTMF : integer ;  nDigit : integer ) : boolean;
        function DetectDTMFCallSession( lSessionId : integer ;  nTypeDTMF : integer ; bEnable : boolean;  nTimeout : integer ) : boolean;

        function GetVaxObjectError() : integer;

        function DialToneToCallSession( bEnable : boolean;  lSessionId : integer ;  lWaveId : integer ) : boolean;
        function DiagnosticLogSIP( bInbound : boolean;  bOutbound : boolean) : boolean;

        procedure AddRef(var pVaxServerSIP : TVaxServerRoot; nClassId : integer);
        procedure RemoveRef(var pVaxServerSIP : TVaxServerRoot);
        function GetRefCount() : integer;

        private
            m_aVaxServerSIP : Array[0..MAX_VAX_SERVER_SIP_REF_COUNT] of TVaxServerRoot;

end;

implementation

        // Line events

        procedure TVaxServerExCOM.OnLineRegisterTrying( sLineName : string);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_LINE_SIP].OnLineRegisterTrying(sLineName);
        end;

        procedure TVaxServerExCOM.OnLineRegisterFail( sLineName : string; nStatusCode : integer;  sReasonPhrase : string);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_LINE_SIP].OnLineRegisterFail(sLineName, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnLineRegisterSuccess( sLineName : string);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_LINE_SIP].OnLineRegisterSuccess(sLineName);
        end;

        procedure TVaxServerExCOM.OnLineUnRegisterTrying( sLineName : string);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_LINE_SIP].OnLineUnRegisterTrying(sLineName);
        end;

        procedure TVaxServerExCOM.OnLineUnRegisterFail( sLineName : string; nStatusCode : integer;  sReasonPhrase : string);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_LINE_SIP].OnLineUnRegisterFail(sLineName, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnLineUnRegisterSuccess( sLineName : string);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_LINE_SIP].OnLineUnRegisterSuccess(sLineName);
        end;

        // User Events

        procedure TVaxServerExCOM.OnUnRegisterUser( sUserLogin : WideString);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_USER_SIP].OnUnRegisterUser(sUserLogin);
        end;

        procedure TVaxServerExCOM.OnRegisterUser(sUserLogin: WideString; sDomain: WideString; sFromIP: WideString; nFromPort: Integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_USER_SIP].OnRegisterUser(sUserLogin, sDomain, sFromIP, nFromPort);
        end;

        procedure TVaxServerExCOM.OnRegisterUserSuccess(sUserLogin: WideString);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_USER_SIP].OnRegisterUserSuccess(sUserLogin);
        end;

        procedure TVaxServerExCOM.OnRegisterUserFail( sUserLogin : WideString);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_USER_SIP].OnRegisterUserFail(sUserLogin);
        end;

        // Chat Message Events

        procedure TVaxServerExCOM.OnChatMessageText( nChatMsgId : integer;  sMsgFrom : string;  sMsgTo : string;  sMsgText : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CHAT_SIP].OnChatMessageText(nChatMsgId, sMsgFrom, sMsgTo, sMsgText, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        end;

        procedure TVaxServerExCOM.OnChatMessageTyping( nChatMsgId : integer;  sMsgFrom : string;  sMsgTo : string;  IsTypingStart : integer;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CHAT_SIP].OnChatMessageTyping(nChatMsgId, sMsgFrom, sMsgTo, IsTypingStart, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        end;
        procedure TVaxServerExCOM.OnChatStatusSubscribe( nSubscrbId : integer;  sMsgFrom : string;  sMsgTo : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CHAT_SIP].OnChatStatusSubscribe(nSubscrbId, sMsgFrom, sMsgTo, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        end;

        procedure TVaxServerExCOM.OnChatMessageSuccess( nChatMsgId : integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CHAT_SIP].OnChatMessageSuccess(nChatMsgId);
        end;

        procedure TVaxServerExCOM.OnChatMessageFailure(ChatMsgId: Integer; StatusCode: Integer; const ReasonPhrase: WideString);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CHAT_SIP].OnChatMessageFailure(ChatMsgId, StatusCode, ReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnChatMessageTimeout( nChatMsgId : integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CHAT_SIP].OnChatMessageTimeout(nChatMsgId);
        end;

        // Call Session Events

        procedure TVaxServerExCOM.OnCallSessionOpen( nSessionId : integer;  sCallerName : string;  sCallerId : string;  sDialNo : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionOpen(nSessionId, sCallerName, sCallerId, sDialNo, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        end;

        procedure TVaxServerExCOM.OnCallSessionFailed(  nSessionId : integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionFailed(nSessionId, CallType, StatusCode, ReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnCallSessionConnected( nSessionId : integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionConnected(nSessionId);
        end;

        procedure TVaxServerExCOM.OnCallSessionClosed( nSessionId : integer; CallType: Integer; ReasonCode: Integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionClosed(nSessionId, CallType, ReasonCode);
        end;

        procedure TVaxServerExCOM.OnCallSessionConnecting(SessionId: Integer; CallType: Integer;StatusCode: Integer;
                                            const ReasonPhrase: WideString);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionConnecting(SessionId, CallType, StatusCode, ReasonPhrase);
        end;
        procedure TVaxServerExCOM.OnCallSessionLost(SessionId: Integer; CallType: Integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionLost(SessionId, CallType);
        end;
        procedure TVaxServerExCOM.OnCallSessionHangup(SessionId: Integer;CallType: Integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionHangup(SessionId, CallType);
        end;
        procedure TVaxServerExCOM.OnCallSessionTimeout(SessionId: Integer; CallType: Integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionTimeout(SessionId, CallType);
        end;
        procedure TVaxServerExCOM.OnCallSessionCancelled(SessionId: Integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionCancelled(SessionId);
        end;


        procedure TVaxServerExCOM.OnCallSessionOnHold( nSessionId : integer; CallType: Integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionOnHold(nSessionId, CallType);
        end;

        procedure TVaxServerExCOM.OnCallSessionOffHold( nSessionId : integer; CallType: Integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionOffHold(nSessionId, CallType);
        end;

        // Transfer Events

        procedure TVaxServerExCOM.OnCallSessionTransferBlind(TransfererSessionId: Integer; lTransfererCallType: Integer; const Transferer: WideString;
                                            const Transferee: WideString; const TransferTo: WideString);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionTransferBlind(TransfererSessionId, lTransfererCallType, Transferer, Transferee, TransferTo);
        end;

        procedure TVaxServerExCOM.OnCallSessionTransferConsult(TransfererSessionId: Integer; TransfereeSessionId: Integer; TransferToSessionId: Integer;
                                                lTransfererCallType: Integer; lTransfereeCallType: Integer;lTransferToCallType: Integer;
                                                const Transferer: WideString; const Transferee: WideString; const TransferTo: WideString);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionTransferConsult(TransfererSessionId, TransfereeSessionId, TransferToSessionId, lTransfererCallType,
                                                                            lTransfereeCallType, lTransferToCallType, Transferer, Transferee, TransferTo);
        end;

        procedure TVaxServerExCOM.OnCallSessionTransfering( nSessionId : integer; TransferType: Integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionTransfering(nSessionId, TransferType, CallType, StatusCode, ReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnCallSessionTransferFailed( nSessionId : integer; TransferType: Integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString);
        begin
          m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionTransferFailed(nSessionId, TransferType, CallType, StatusCode, ReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnCallSessionTransferTimeout( nSessionId : integer; TransferType: Integer; CallType: Integer);
        begin
          m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionTransferTimeout(nSessionId, TransferType, CallType);
        end;

        procedure TVaxServerExCOM.OnCallSessionTransfered( nSessionId : integer; TransferType: Integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionTransfered(nSessionId, TransferType);
        end;


        // Misc Events

        procedure TVaxServerExCOM.OnDigitDetectDTMF( nSessionId : integer;  sDigitDTMF : string);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnDigitDetectDTMF(nSessionId, sDigitDTMF);
        end;

        procedure TVaxServerExCOM.OnOutgoingDiagnosticLog( sMsgSIP : string;  sToIP : string;  nToPort : integer);
        begin
        end;

        procedure TVaxServerExCOM.OnIncomingDiagnosticLog( sMsgSIP : string;  sFromIP : string;  nFromPort : integer);
        begin
        end;

        procedure TVaxServerExCOM.OnVaxTeleTick( nTickId : integer);
        begin
        end;

        procedure TVaxServerExCOM.OnSendTimeOutVM( nMsgIdVM : integer);
        begin
        end;

        procedure TVaxServerExCOM.OnSendSuccessVM( nMsgIdVM : integer);
        begin
        end;

        // Dial Tone Events

        procedure TVaxServerExCOM.OnCallSessionDialToneStart( nSessionId : integer;  nWaveId : integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionDialToneStart(nSessionId, nWaveId);
        end;

        procedure TVaxServerExCOM.OnCallSessionDialToneStop( nSessionId : integer;  nWaveId : integer);
        begin
            m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionDialToneStop(nSessionId, nWaveId);
        end;

        procedure TVaxServerExCOM.OnCallSessionCreated(nSessionId : Integer;  nCallType : integer;  nReasonCode : integer);
        begin
           m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionCreated(nSessionId, nCallType, nReasonCode);
        end;

        procedure TVaxServerExCOM.OnCallSessionOpenCall(nSessionId : Integer;  nCallType : integer;  nPeerType : integer;  sPeerName : string);
        begin
          m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionOpenCall(nSessionId, nCallType, nPeerType, sPeerName);
        end;

        procedure TVaxServerExCOM.OnCallSessionCloseCall(nSessionId : Integer;  nCallType : integer;  nPeerType : integer;  sPeerName : string);
        begin
          m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionCloseCall(nSessionId, nCallType, nPeerType, sPeerName);
        end;

        procedure TVaxServerExCOM.OnCallSessionDetectedAMD(nSessionId : Integer;  nCallType : integer;  bIsHuman : Boolean);
        begin
          m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP].OnCallSessionDetectedAMD(nSessionId, nCallType, bIsHuman);
        end;

        {///////////////////////////////////////////////////////////////////////////////
        ///////////////////     Functions
        ///////////////////////////////////////////////////////////////////////////////}

        procedure TVaxServerExCOM.AddRef(var pVaxServerSIP : TVaxServerRoot; nClassId : integer);
        begin
          m_aVaxServerSIP[nClassId] := pVaxServerSIP;
        end;

        procedure TVaxServerExCOM.RemoveRef(var pVaxServerSIP : TVaxServerRoot);
            var
                nIndex : integer;
        begin

            for nIndex := 0 to MAX_VAX_SERVER_SIP_REF_COUNT do
            begin

                if(m_aVaxServerSIP[nIndex] = pVaxServerSIP) then
                    m_aVaxServerSIP[nIndex] := nil;

            end;    // end for

        end;

        function TVaxServerExCOM.GetRefCount() : integer;
            var
                nIndex, nCount : integer;
        begin
            nCount := 0;

            for nIndex := 0 to MAX_VAX_SERVER_SIP_REF_COUNT do
            begin

                if(m_aVaxServerSIP[nIndex] <> nil) then
                    nCount := nCount + 1;

            end;    // end for

            Result := nCount;

        end;


        constructor TVaxServerExCOM.Create();
        begin
            inherited Create();
        end;

        procedure TVaxServerExCOM.SetLicenseKey(sLicenseKey : string);
        begin
            inherited;
        end;

        function TVaxServerExCOM.Initialize(sDomainRealm : string;  sSIPListenIP : string; nSIPListenPort : integer ;  sRTPListenIP : string; nRTPListenPort : integer ) : boolean;
        begin
            Result := inherited;
        end;

        procedure TVaxServerExCOM.UnInitialize();
        begin
            inherited;
        end;

        function TVaxServerExCOM.AddUser( sUserName : string;  sPassword : string;  sCodecList : string) : boolean;
        begin
            Result := inherited;
        end;

        procedure TVaxServerExCOM.RemoveUser( sUserName : string);
        begin
            inherited;
        end;

        function TVaxServerExCOM.AcceptRegister( sUserName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.RejectRegister( sUserName : string; lStatusCode : integer;  sReasonPhrase : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.AuthRegister( sUserName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.AddLine( sLineName : string;  sDisplayName : string;  sUserName : string;  sAuthUser : string;  sAuthPwd : string;  sDomainRealm : string;  sProxySIP : string;  sOutboundProxySIP : string;  sCodecList : string) : boolean;
        begin
            Result := inherited;
        end;

        procedure TVaxServerExCOM.RemoveLine( sLineName : string);
        begin
            inherited;
        end;

        function TVaxServerExCOM.RegisterLine( sLineName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.UnRegisterLine( sLineName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.AddDirectProxySIP( sProxyName : string;  sAuthLogin : string;  sAuthPwd : string;  sDomainRealm : string;  sProxyIP : string; lProxyPort : integer ;  sCodecList : string) : boolean;
        begin
            Result := inherited;
        end;

        procedure TVaxServerExCOM.RemoveDirectProxySIP( sProxyName : string);
        begin
            inherited;
        end;

        function TVaxServerExCOM.AcceptCallSession(lSessionId : integer ;  sCallerName : string;  sCallerId : string;  sDialNo : string;  nToPeerType : integer ;  sToPeerName : string; lTimeOut : integer ) : boolean;
        begin
            Result := inherited;
        end;

        procedure TVaxServerExCOM.RejectCallSession(lSessionId : integer ; lStatusCode : integer ;  sReasonPhrase : string);
        begin
            inherited;
        end;

        procedure TVaxServerExCOM.CloseCallSession(lSessionId : integer );
        begin
            inherited;
        end;

        function TVaxServerExCOM.CreateCallSession( sCallerName : string;  sCallerId : string;  sDialNo : string;  nToPeerType : integer ;  sToPeerName : string; lTimeOut : integer ) : integer;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.OpenCallSession( sCallerName : string;  sCallerId : string;  sDialNo : string;  nToPeerType : integer ;  sToPeerName : string; lTimeOut : integer ) : integer;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.AcceptTransferBlind(lTransfererSessionId : integer ;  sCallerName : string;  sCallerId : string;  sTransferTo : string;  nToPeerType : integer ;  sToPeerName : string; lTimeOut : integer) : Integer;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.AcceptTransferConsult(lTransfererSessionId : integer ; lTransferToSessionId : integer ) : Integer;
        begin
            Result := inherited;
        end;

        procedure TVaxServerExCOM.RejectTransfer(lSessionId : integer );
        begin
            inherited;
        end;

        function TVaxServerExCOM.PlayWaveStartToCallSession(lSessionId : integer ; lWaveId : integer ; bLoop : boolean) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.PlayWaveStopToCallSession(lSessionId : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.RecordWaveStartToCallSession(lSessionId : integer ;  sFileName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.RecordWaveStopToCallSession(lSessionId : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.RecordWavePauseToCallSession(lSessionId : integer ; bEnable : boolean) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.LoadWaveFile( sFileName : string) : integer;
        begin
            Result := inherited;
        end;

        procedure TVaxServerExCOM.UnLoadWaveFile(lWaveId : integer);
        begin
            inherited;
        end;

        function TVaxServerExCOM.LoadMusicHold( sFileName : string) : boolean;
        begin
            Result := inherited;

            if(Result = False) then
            begin
   		        m_aVaxServerSIP[TVaxServerConstants.ID_CLASS_ERROR_SIP].OnVaxTeleError(GetVaxObjectError());
            end;
        end;

        procedure TVaxServerExCOM.UnLoadMusicHold();
        begin
            inherited;
        end;

        function TVaxServerExCOM.AcceptOnHoldRequest(lSessionId  : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.AcceptOffHoldRequest(lSessionId : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.AcceptChatMessage(lChatMsgId : integer ;  nToPeerType : integer ;  sToPeerName : string) : boolean;
        begin
            Result := inherited;
        end;

        procedure TVaxServerExCOM.RejectChatMessage(lChatMsgId : integer ; lStatusCode : integer ;  sReasonPhrase : string);
        begin
            inherited;
        end;

        function TVaxServerExCOM.AcceptChatStatusSubscribe(lStatusSubscribe : integer ;  sMsgFrom : string;  sMsgTo : string;  nToPeerType : integer ;  sToPeerName : string) : boolean;
        begin
            Result := inherited;
        end;

        procedure TVaxServerExCOM.RejectChatStatusSubscribe(lStatusSubscribe : integer ;  sMsgFrom : string;  sMsgTo : string);
        begin
            inherited;
        end;

        function TVaxServerExCOM.OpenConferenceRoom( sRoomName : string) : boolean;
        begin
            Result := inherited OpenConferenceRoom(sRoomName);
        end;

        procedure TVaxServerExCOM.CloseConferenceRoom( sRoomName : string);
        begin
            inherited CloseConferenceRoom(sRoomName);
        end;

        function TVaxServerExCOM.AddCallSessionToConferenceRoom( sRoomName : string;  lSessionId : integer ;  nType : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.RemoveCallSessionFromConferenceRoom( lSessionId : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.PlayWaveStartToConferenceRoom( sRoomName : string;  lWaveId : integer ;  bLoop : boolean) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.PlayWaveStopToConferenceRoom( sRoomName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.RecordWaveStartToConferenceRoom( sRoomName : string;  sFileName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.RecordWaveStopToConferenceRoom( sRoomName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.RecordWavePauseToConferenceRoom( sRoomName : string; bEnable : boolean) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.VoiceSessionLost(bEnable : boolean; lTimeOut : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.SendInfoVM( sUserLogin : string;  nNewMsgCount : integer ;  nOldMsgCount : integer ; bMsgWaiting : Boolean ) : integer;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.StartVaxTeleTick(lTickId : integer ; lElapse : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.StopVaxTeleTick(lTickId : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.SetUserAgentName( sName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.GetUserAgentName() : string;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.SetSessionNameSDP( sName : string) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.GetSessionNameSDP() : string;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.SendDTMFCallSession( lSessionId : integer ;  nTypeDTMF : integer ;  nDigit : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.DetectDTMFCallSession( lSessionId : integer ;  nTypeDTMF : integer ; bEnable : boolean;  nTimeout : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.GetVaxObjectError() : integer;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.DialToneToCallSession( bEnable : boolean;  lSessionId : integer ;  lWaveId : integer ) : boolean;
        begin
            Result := inherited;
        end;

        function TVaxServerExCOM.DiagnosticLogSIP( bInbound : boolean;  bOutbound : boolean) : boolean;
        begin
            Result := inherited;
        end;

end.
