unit VaxCallSession;

interface

uses
    System.Classes,

    VaxCallSessionRoute,
    VaxServerConstants,
    VaxServerRoot,
    VaxCallSessionList;

type TVaxCallSession = class(TVaxServerRoot)

    private

        m_objVaxCallSessionList : TVaxCallSessionList;
        m_objRouteCallSIP : TVaxCallSessionRoute;

        m_lDialToneId, m_lTotalCallCount : Integer;

    public

        const CONNECT_TIME_OUT : Integer = 30;

    public

        procedure OnCallSessionOpen( nSessionId : integer;  sCallerName : string;  sCallerId : string;  sDialNo : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer); override;
        procedure OnCallSessionFailed( nSessionId : integer; nCallType: Integer; nStatusCode: Integer; const sReasonPhrase: string); override;

        procedure OnCallSessionConnected( nSessionId : integer); override;
        procedure OnCallSessionClosed( nSessionId : integer; nCallType: Integer; nReasonCode: Integer); override;

        procedure OnCallSessionOnHold( nSessionId : integer; nCallType: Integer); override;
        procedure OnCallSessionOffHold( nSessionId : integer; nCallType: Integer); override;

        procedure OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererCallType: Integer; const sTransferer: string; const sTransferee: string; const sTransferTo: string); override;
        procedure OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfereeSessionId: Integer; nTransferToSessionId: Integer; nTransfererCallType: Integer; nTransfereeCallType: Integer; nTransferToCallType: Integer; const sTransferer: string; const sTransferee: string; const sTransferTo: string); override;

        procedure OnCallSessionTransfering( nSessionId : integer; TransferType: Integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString); override;
        procedure OnCallSessionTransferFailed( nSessionId : integer; TransferType: Integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString); override;
        procedure OnCallSessionTransferTimeout( nSessionId : integer; TransferType: Integer; CallType: Integer); override;
        procedure OnCallSessionTransfered( nSessionId : integer; TransferType: Integer); override;

        procedure OnCallSessionConnecting(nSessionId: Integer; nCallType: Integer; nStatusCode: Integer; const sReasonPhrase: string); override;
        procedure OnCallSessionLost(nSessionId: Integer; nCallType: Integer);  override;
        procedure OnCallSessionHangup(nSessionId: Integer; nCallType: Integer); override;
        procedure OnCallSessionTimeout(nSessionId: Integer; nCallType: Integer); override;
        procedure OnCallSessionCancelled(nSessionId: Integer); override;

        procedure OnDigitDetectDTMF( nSessionId : integer;  sDigitDTMF : string); override;

        procedure OnCallSessionCreated(nSessionId : Integer;  nCallType : integer;  nReasonCode : integer);  override;
        procedure OnCallSessionOpenCall(nSessionId : Integer;  nCallType : integer;  nPeerType : integer;  sPeerName : string);   override;
        procedure OnCallSessionCloseCall(nSessionId : Integer;  nCallType : integer;  nPeerType : integer;  sPeerName : string);  override;
        procedure OnCallSessionDetectedAMD(nSessionId : Integer;  nCallType : integer;  bIsHuman : Boolean);  override;

    public

        constructor Create();

        procedure ResetOBJ();

        function AcceptCallSession(lSessionId : Integer; sCallerName, sCallerId, sDialNo : string; nToPeerType : Integer; sToPeerName : string; lTimeOut : Integer) : Boolean;
        procedure CloseCallSession(lSessionId : Integer);
        function CreateCallSession(sCallerName, sCallerId, sDialNo : string; nToPeerType : Integer; sToPeerName : string; lTimeOut : Integer) : Integer;

        function AddRoom(sRoomName : string ; sRoomNo : string) : Boolean;
        procedure RemoveRoom(sRoomName : string);

        function GetRoomDetails(sRoomName : string; var sRoomNo : string) : Boolean;

        function IsRoomNoExist(sRoomName : string) : Boolean;
        function GetRoomAll(var pRoomList : TStringList) : Boolean;

        function LoadDialTonMusic(sFileName : string) : Boolean;
        procedure UnLoadDialToneMusic();

        function AddUserRoute(sUserName, sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : Boolean;
        procedure RemoveUserRoute(sUserName : string);

        function AddLineRoute(sLineName : string; nToPeerType : Integer; sToPeerName : string; bRejected, bAddToConf : Boolean; sRoomName : string) : Boolean;
        procedure RemoveLineRoute(sLineName : string);

        function AddDirectProxyRoute(sProxyName: string; nToPeerType : Integer; sToPeerName : string; bRejected, bAddToConf : Boolean; sRoomName : string) : Boolean;
        procedure RemoveDirectProxyRoute(sProxyName: string);

        function GetCallCount() : Integer;

end;

implementation

uses
    ConfRoom;   // put it here because of 'circular reference error' in TConfRoom
var
    m_objConfRoom : TConfRoom;

        procedure TVaxCallSession.OnCallSessionOpen( nSessionId : integer;  sCallerName : string;  sCallerId : string;  sDialNo : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer);
        var
            sToPeerName, sDialToNo, sRoomName : string;
            nToPeerType : Integer;
            bRejected, bAddToConf, bResult : Boolean;
        begin

            bRejected := False;
            bAddToConf := False;

            // If call is from USER
            if(nFromPeerType = TVaxServerConstants.VAX_PEER_TYPE_USER) then
            begin

                if(m_objConfRoom.IsRoomNoExist(sDialNo) = True) then
                begin
                  bAddToConf := True;
                  sRoomName := m_objConfRoom.GetRoomName(sDialNo);
                end
                else
                    m_objRouteCallSIP.OnCallFromUser(sFromPeerName, sDialNo, sDialToNo, nToPeerType, sToPeerName);

            end

            // if call is from LINE
            else if(nFromPeerType = TVaxServerConstants.VAX_PEER_TYPE_LINE) then
            begin
		        m_objRouteCallSIP.OnCallFromLine(sFromPeerName, nToPeerType, sToPeerName, bRejected, bAddToConf, sRoomName);
		        sDialToNo := sToPeerName;
            end

            // if call is from PROXY
            else if(nFromPeerType = TVaxServerConstants.VAX_PEER_TYPE_DIRECT_PROXY) then
            begin
		        m_objRouteCallSIP.OnCallFromDirectProxySIP(sFromPeerName, nToPeerType, sToPeerName, bRejected, bAddToConf, sRoomName);
		        sDialToNo := sToPeerName;
            end;

            /////////////////////////////////////////////////////
            /////////////////////////////////////////////////////

            if(bRejected = True) then
            begin
              inherited RejectCallSession(nSessionId, 404, 'Not Found');
            end;

            m_objVaxCallSessionList.AddCallSession(nSessionId, sCallerName, sCallerId, sDialToNo, bAddToConf, sRoomName);

            if(bAddToConf = True) then
            begin
		        m_objConfRoom.OnCallSessionOpen(nSessionId, sCallerName, sCallerId, sRoomName, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
		        Exit;
            end;

            //////////////////////////////////////////////////////////////////////

            if nToPeerType = TVaxServerConstants.VAX_PEER_TYPE_LINE then
            begin
                sCallerName := '';
                sCallerId := '';

                // Let AcceptCallSession() use DisplayName & UserName values of LINE as CallerName & CallerId.
            end;

             bResult := AcceptCallSession(nSessionId, sCallerName, sCallerId, sDialToNo, nToPeerType, sToPeerName, CONNECT_TIME_OUT);
             if(bResult = True) then
             begin

               if(m_lDialToneId <> -1) then
                    inherited DialToneToCallSession(True, nSessionId, m_lDialToneId);

             end;
        end;

        procedure TVaxCallSession.OnCallSessionFailed( nSessionId : integer; nCallType: Integer; nStatusCode: Integer; const sReasonPhrase: string);
        begin

            if(m_objVaxCallSessionList.IsAddedToConfRoom(nSessionId) = True) then
            begin
              m_objConfRoom.OnCallSessionFailed(nSessionId, nCallType, nStatusCode, sReasonPhrase);
              Exit;
            end;

            m_objVaxCallSessionList.DeleteCallSession(nSessionId);

        end;

        procedure TVaxCallSession.OnCallSessionConnected( nSessionId : integer);
        var
            bResult : Boolean;
            sRoomName : string;
        begin

            bResult := False;

            bResult := m_objVaxCallSessionList.IsAddedToConfRoom(nSessionId);
            if(bResult = True) then
            begin
                sRoomName := m_objVaxCallSessionList.GetRoomName(nSessionId);
                m_objConfRoom.OnCallSessionConnected(nSessionId, sRoomName);
                Exit;
            end;

            bResult := inherited DetectDTMFCallSession(nSessionId, TVaxServerConstants.VAX_DIGIT_DTMF_TYPE_SIP, True, 3000);

        end;

        procedure TVaxCallSession.OnCallSessionClosed( nSessionId : integer; nCallType: Integer; nReasonCode: Integer);
        begin
            if(m_objVaxCallSessionList.IsAddedToConfRoom(nSessionId) = True) then
            begin
              m_objConfRoom.OnCallSessionClosed(nSessionId, nCallType, nReasonCode);
              Exit;
            end;

            m_objVaxCallSessionList.DeleteCallSession(nSessionId);

        end;

        procedure TVaxCallSession.OnCallSessionOnHold( nSessionId : integer; nCallType: Integer);
        var bResult : Boolean;
        begin
            if(m_objVaxCallSessionList.IsAddedToConfRoom(nSessionId) = True) then
            begin
              m_objConfRoom.OnCallSessionOnHold(nSessionId, nCallType);
              Exit;
            end;

            bResult := inherited AcceptOnHoldRequest(nSessionId);

        end;

        procedure TVaxCallSession.OnCallSessionOffHold( nSessionId : integer; nCallType: Integer);
        var bResult : Boolean;
        begin
            if(m_objVaxCallSessionList.IsAddedToConfRoom(nSessionId) = True) then
            begin
              m_objConfRoom.OnCallSessionOffHold(nSessionId, nCallType);
              Exit;
            end;

            bResult := inherited AcceptOffHoldRequest(nSessionId);
        end;

        procedure TVaxCallSession.OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererCallType: Integer; const sTransferer: string; const sTransferee: string; const sTransferTo: string);
        var nResult : Integer;
        begin
            if(m_objVaxCallSessionList.IsAddedToConfRoom(nTransfererSessionId) = True) then
            begin
                m_objConfRoom.OnCallSessionTransferBlind(nTransfererSessionId, nTransfererCallType, sTransferer, sTransferee, sTransferTo);
                Exit;
            end;

            nResult := inherited AcceptTransferBlind(nTransfererSessionId, sTransferee, sTransferee, sTransferTo, TVaxServerConstants.VAX_PEER_TYPE_USER, sTransferTo, 30);
        end;

        procedure TVaxCallSession.OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfereeSessionId: Integer; nTransferToSessionId: Integer;
                                                nTransfererCallType: Integer; nTransfereeCallType: Integer; nTransferToCallType: Integer; const sTransferer: string; const sTransferee: string; const sTransferTo: string);
        var nResult : Integer;
        begin
            if(m_objVaxCallSessionList.IsAddedToConfRoom(nTransfererSessionId) = True) then
            begin
                m_objConfRoom.OnCallSessionTransferConsult(nTransfererSessionId, nTransfereeSessionId, nTransferToSessionId, nTransfererCallType, nTransfereeCallType, nTransferToCallType, sTransferer, sTransferee, sTransferTo);
                Exit;
            end;

            nResult := inherited AcceptTransferConsult(nTransfererSessionId, nTransferToSessionId);

        end;

        procedure TVaxCallSession.OnCallSessionConnecting(nSessionId: Integer; nCallType: Integer; nStatusCode: Integer; const sReasonPhrase: string);
        begin
          //
        end;
        procedure TVaxCallSession.OnCallSessionLost(nSessionId: Integer; nCallType: Integer);
        begin
          //
        end;
        procedure TVaxCallSession.OnCallSessionHangup(nSessionId: Integer; nCallType: Integer);
        begin
          //
        end;
        procedure TVaxCallSession.OnCallSessionTimeout(nSessionId: Integer; nCallType: Integer);
        begin
          //
        end;
        procedure TVaxCallSession.OnCallSessionCancelled(nSessionId: Integer);
        begin
          //
        end;

        procedure TVaxCallSession.OnDigitDetectDTMF( nSessionId : integer;  sDigitDTMF : string);
        begin
        end;

        constructor TVaxCallSession.Create();
        begin
            inherited;
            inherited AddRef(TVaxServerConstants.ID_CLASS_CALL_SESSION_SIP);

            m_objVaxCallSessionList := TVaxCallSessionList.Create();
            m_objRouteCallSIP := TVaxCallSessionRoute.Create();
            m_objConfRoom := TConfRoom.Create(Self);
        end;

        procedure TVaxCallSession.ResetOBJ();
        begin
            m_objConfRoom.ResetOBJ();
            m_objVaxCallSessionList.ResetOBJ();
        end;

        function TVaxCallSession.AcceptCallSession(lSessionId : Integer; sCallerName, sCallerId, sDialNo : string; nToPeerType : Integer; sToPeerName : string; lTimeOut : Integer) : Boolean;
        var
            bResult : Boolean;
        begin

            bResult := inherited AcceptCallSession(lSessionId, sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName, lTimeOut);
            if(bResult = False) then
            begin
                inherited RejectCallSession(lSessionId, 404, 'Not Found');
                Exit(False);
            end;

            Result := True;
        end;

        procedure TVaxCallSession.CloseCallSession(lSessionId : Integer);
        begin

            inherited CloseCallSession(lSessionId);
            m_objVaxCallSessionList.DeleteCallSession(lSessionId);

        end;

        function TVaxCallSession.CreateCallSession(sCallerName, sCallerId, sDialNo : string; nToPeerType : Integer; sToPeerName : string; lTimeOut : Integer) : Integer;
        var
            lResult : Integer;
        begin

            lResult := inherited CreateCallSession(sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName, lTimeOut);
            if(lResult = -1) then
            begin
              Result := -1;
              Exit;
            end;

            m_objVaxCallSessionList.AddCallSession(lResult, sCallerName, sCallerId, sDialNo, False, '');
            Result := lResult;

        end;

        function TVaxCallSession.AddRoom(sRoomName : string ; sRoomNo : string) : Boolean;
        begin
            Result := m_objConfRoom.AddRoom(sRoomName, sRoomNo);
        end;

        procedure TVaxCallSession.RemoveRoom(sRoomName : string);
        begin
            m_objConfRoom.RemoveRoom(sRoomName);
        end;

        function TVaxCallSession.GetRoomDetails(sRoomName : string; var sRoomNo : string) : Boolean;
        begin
            Result := m_objConfRoom.GetRoomDetails(sRoomName, sRoomNo);
        end;

        function TVaxCallSession.IsRoomNoExist(sRoomName : string) : Boolean;
        begin
            Result := m_objConfRoom.IsRoomNoExist(sRoomName);
        end;

        function TVaxCallSession.GetRoomAll(var pRoomList : TStringList) : Boolean;
        begin
            Result := m_objConfRoom.GetRoomAll(pRoomList);
        end;

        function TVaxCallSession.LoadDialTonMusic(sFileName : string) : Boolean;
        var
            bResult : Boolean;
        begin
            bResult := True;

            m_lDialToneId := inherited LoadWaveFile(sFileName);
            if(m_lDialToneId = -1) then
                bResult := False;

            Result := bResult;

        end;

        procedure TVaxCallSession.UnLoadDialToneMusic();
        begin
            if(m_lDialToneId <> -1) then
                inherited UnLoadWaveFile(m_lDialToneId);
        end;

        function TVaxCallSession.AddUserRoute(sUserName, sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : Boolean;
        begin
            Result := m_objRouteCallSIP.AddUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
        end;

        procedure TVaxCallSession.RemoveUserRoute(sUserName : string);
        begin
            m_objRouteCallSIP.RemoveUserRoute(sUserName);
        end;

        function TVaxCallSession.AddLineRoute(sLineName : string; nToPeerType : Integer; sToPeerName : string; bRejected, bAddToConf : Boolean; sRoomName : string) : Boolean;
        begin
            Result := m_objRouteCallSIP.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, bAddToConf, sRoomName);
        end;

        procedure TVaxCallSession.RemoveLineRoute(sLineName : string);
        begin
            m_objRouteCallSIP.RemoveLineRoute(sLineName);
        end;

        function TVaxCallSession.AddDirectProxyRoute(sProxyName: string; nToPeerType : Integer; sToPeerName : string; bRejected, bAddToConf : Boolean; sRoomName : string) : Boolean;
        begin
            Result := m_objRouteCallSIP.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, bAddToConf, sRoomName);
        end;

        procedure TVaxCallSession.RemoveDirectProxyRoute(sProxyName: string);
        begin
            m_objRouteCallSIP.RemoveDirectProxyRoute(sProxyName);
        end;

        function TVaxCallSession.GetCallCount() : Integer;
        begin
           Result := m_lTotalCallCount;
        end;

        procedure TVaxCallSession.OnCallSessionTransfering( nSessionId : integer; TransferType: Integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString);
        begin
        end;

        procedure TVaxCallSession.OnCallSessionTransferFailed( nSessionId : integer; TransferType: Integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString);
        begin
        end;

        procedure TVaxCallSession.OnCallSessionTransferTimeout( nSessionId : integer; TransferType: Integer; CallType: Integer);
        begin
        end;

        procedure TVaxCallSession.OnCallSessionTransfered( nSessionId : integer; TransferType: Integer);
        begin
        end;

        procedure TVaxCallSession.OnCallSessionCreated(nSessionId : Integer;  nCallType : integer;  nReasonCode : integer);
        begin
        end;

        procedure TVaxCallSession.OnCallSessionOpenCall(nSessionId : Integer;  nCallType : integer;  nPeerType : integer;  sPeerName : string);
        begin
              m_lTotalCallCount := m_lTotalCallCount + 1;
        end;

        procedure TVaxCallSession.OnCallSessionCloseCall(nSessionId : Integer;  nCallType : integer;  nPeerType : integer;  sPeerName : string);
        begin
              m_lTotalCallCount := m_lTotalCallCount - 1;
        end;

        procedure TVaxCallSession.OnCallSessionDetectedAMD(nSessionId : Integer;  nCallType : integer;  bIsHuman : Boolean);
        begin
        end;

end.
