unit VaxCallSessionList;

interface

uses
    System.SysUtils,
    System.Classes,
    Generics.Collections;

type TVaxCallSessionDetails = class

    public
        m_lSessionId, m_lBindSessionId : Integer;
        m_sCallerName, m_sCallerId, m_sRoomName, m_sDialNo : string;
        m_bAddedToConfRoom : Boolean;


end;

type TVaxCallSessionList = class

    var
        m_objCallSessionList : TObjectDictionary<Integer, TVaxCallSessionDetails>;

    private

        function FindCallSession(lSessionId : Integer) : TVaxCallSessionDetails;
        procedure DeleteAll();

    public

        constructor Create();
        Destructor Destroy();
        procedure ResetOBJ();

        function AddCallSession(lSessionId : Integer; sCallerName, sCallerId, sDialNo : string; bAddToConf : Boolean; sRoomName : string) : Boolean;
        procedure DeleteCallSession(lSessionId : Integer);

        function GetCallerName(lSessionId : Integer) : string;
        function GetCallerId(lSessionId : Integer) : string;

        function GetDialNo(lSessionId : Integer) : string;
        function GetRoomName(lSessionId : Integer) : string;

        function IsAddedToConfRoom(lSessionId : Integer) : Boolean;
        function GetCallSessionDetails(lSessionId : Integer; var sCallerName, sCallerId : string) : Boolean;

end;

implementation

        constructor TVaxCallSessionList.Create();
        begin
            m_objCallSessionList := TObjectDictionary<Integer, TVaxCallSessionDetails>.Create([doOwnsValues], 256);
        end;

        Destructor TVaxCallSessionList.Destroy();
        begin
            DeleteAll();
            m_objCallSessionList.Free;
        end;

        function TVaxCallSessionList.FindCallSession(lSessionId : Integer) : TVaxCallSessionDetails;
        var objVaxCallSession : TVaxCallSessionDetails;
            bResult : Boolean;
        begin
            objVaxCallSession := Nil;

            bResult := m_objCallSessionList.TryGetValue(lSessionId, objVaxCallSession);
            if(bResult = False) then
                Exit(Nil);

            Result := objVaxCallSession;

        end;

        procedure TVaxCallSessionList.DeleteAll();
        begin
            m_objCallSessionList.Clear;
        end;

        procedure TVaxCallSessionList.ResetOBJ();
        begin
            DeleteAll();
        end;

        function TVaxCallSessionList.AddCallSession(lSessionId : Integer; sCallerName, sCallerId, sDialNo : string; bAddToConf : Boolean; sRoomName : string) : Boolean;
        var
            objCallSession : TVaxCallSessionDetails;
        begin

            objCallSession := FindCallSession(lSessionId);
            if(objCallSession <> nil) then
            begin
              Exit(False);
            end;

            objCallSession := TVaxCallSessionDetails.Create();

            objCallSession.m_lSessionId := lSessionId;
            objCallSession.m_sCallerName := sCallerName;
            objCallSession.m_sCallerId := sCallerId;
            objCallSession.m_sDialNo := sDialNo;

            objCallSession.m_bAddedToConfRoom := bAddToConf;
            objCallSession.m_sRoomName := sRoomName;

            m_objCallSessionList.Add(lSessionId, objCallSession);

            Result := True;
        end;

        procedure TVaxCallSessionList.DeleteCallSession(lSessionId : Integer);
        var
            objCallSession : TVaxCallSessionDetails;
        begin
            objCallSession := FindCallSession(lSessionId);
            if(objCallSession = nil) then Exit;

            m_objCallSessionList.Remove(lSessionId);
            //objCallSession.Free;

        end;

        function TVaxCallSessionList.GetCallerName(lSessionId : Integer) : string;
        var
            objCallSession : TVaxCallSessionDetails;
        begin
            objCallSession := FindCallSession(lSessionId);
            if(objCallSession = nil) then
            begin
                Result := '';
                Exit;
            end;

            Result := objCallSession.m_sCallerName;
        end;

        function TVaxCallSessionList.GetCallerId(lSessionId : Integer) : string;
        var
            objCallSession : TVaxCallSessionDetails;
        begin
            objCallSession := FindCallSession(lSessionId);
            if(objCallSession = nil) then
            begin
                  Result := '';
                  Exit;
            end;

            Result := objCallSession.m_sCallerId;
        end;

        function TVaxCallSessionList.GetDialNo(lSessionId : Integer) : string;
        var
            objCallSession : TVaxCallSessionDetails;
        begin
            objCallSession := FindCallSession(lSessionId);
            if(objCallSession = nil) then
            begin
                  Result := '';
                  Exit;
            end;

            Result := objCallSession.m_sDialNo;
        end;

        function TVaxCallSessionList.GetRoomName(lSessionId : Integer) : string;
        var
            objCallSession : TVaxCallSessionDetails;
        begin
            objCallSession := FindCallSession(lSessionId);
            if(objCallSession = nil) then
            begin
                  Result := '';
                  Exit;
            end;

            Result := objCallSession.m_sRoomName;

        end;

        function TVaxCallSessionList.IsAddedToConfRoom(lSessionId : Integer) : Boolean;
        var
            objCallSession : TVaxCallSessionDetails;
        begin

            objCallSession := FindCallSession(lSessionId);
            if(objCallSession = nil) then
                  Exit(False);

            Result := objCallSession.m_bAddedToConfRoom;

        end;

        function TVaxCallSessionList.GetCallSessionDetails(lSessionId : Integer; var sCallerName, sCallerId : string) : Boolean;
        var
            objCallSession : TVaxCallSessionDetails;
        begin
            objCallSession := FindCallSession(lSessionId);
            if(objCallSession = nil) then
                  Exit(False);

            sCallerName := objCallSession.m_sCallerName;
            sCallerId := objCallSession.m_sCallerId;

            Result := True;

        end;


end.
