unit VaxCallSessionRoute;

interface

uses
    System.StrUtils,
    System.SysUtils,
    System.Classes,
    Generics.Collections,

    VaxServerConstants;

type TUserRouteDetails = class

public
    m_sUserPrefix, m_sToPeerName, m_sDialPrefix : string;
    m_nToPeerType : Integer;

end;

type TLineRouteDetails = class

  public
    m_sLineName, m_sRoomName, m_sToPeerName : string;
    m_nToPeerType : Integer;
    m_bRejected , m_bAddToConfRoom : Boolean;


end;

type TDirectProxyRouteDetails = class

  public
    m_sProxyName, m_sRoomName, m_sToPeerName : string;
    m_nToPeerType : Integer;
    m_bRejected, m_bAddToConfRoom : Boolean;


end;

type TVaxCallSessionRoute = class

    var
        m_objMapUserRouteToPtr : TObjectDictionary<string, TUserRouteDetails>;
        m_objMapLineRouteToPtr : TObjectDictionary<string, TLineRouteDetails>;
        m_objMapDirectProxyRouteToPtr : TObjectDictionary<string, TDirectProxyRouteDetails>;

    private

        function GenKey(sValue : string) : string;

        function FindUserRoute(sUserName : string) : TUserRouteDetails;
        function FindLineRoute(sLineName : string) : TLineRouteDetails;
        function FindDirectProxyRoute(sProxyName : string) : TDirectProxyRouteDetails;

        procedure DeleteAllUserRoutes();
        procedure DeleteAllLineRoutes();
        procedure DeleteAllDirectProxyRoutes();

        function GetUserRouteDetails(sUserName : string; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : Boolean;
        function GetLineRouteDetails(sLineName : string; var nToPeerType : Integer; var sToPeerName : string; var bRejected, bAddToConf : Boolean; var sRoomName : string) : Boolean;
        function GetDirectProxyRouteDetails(sProxyName: string; var nToPeerType : Integer; var sToPeerName : string; var bRejected, bAddToConf : Boolean; var sRoomName : string) : Boolean;



    public

        constructor Create();
        Destructor Destroy();

        procedure ResetOBJ();

        function AddUserRoute(sUserName, sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : Boolean;
        procedure RemoveUserRoute(sUserName : string);

        function AddLineRoute(sLineName : string; nToPeerType : Integer; sToPeerName : string; bRejected, bAddToConf : Boolean; sRoomName : string) : Boolean;
        procedure RemoveLineRoute(sLineName : string);

        function AddDirectProxyRoute(sProxyName: string; nToPeerType : Integer; sToPeerName : string; bRejected, bAddToConf : Boolean; sRoomName : string) : Boolean;
        procedure RemoveDirectProxyRoute(sProxyName: string);

        function OnCallFromUser(sUserName, sUserDialedNo : string; var sDialno : string; var nToPeerType : Integer; var sToPeerName : string) : Boolean;
        function onCallFromLine(sLineName : string; var nToPeerType : Integer; var sToPeerName : string; var bRejected, bAddToConf : Boolean; var sRoomName : string) : Boolean;
        function OnCallFromDirectProxySIP(sProxyName: string; var nToPeerType : Integer; var sToPeerName : string; var bRejected, bAddToConf : Boolean; var sRoomName : string) : Boolean;


end;

implementation

        constructor TVaxCallSessionRoute.Create();
        begin
            m_objMapUserRouteToPtr := TObjectDictionary<string, TUserRouteDetails>.Create([doOwnsValues], 256);
            m_objMapLineRouteToPtr := TObjectDictionary<string, TLineRouteDetails>.Create([doOwnsValues], 256);
            m_objMapDirectProxyRouteToPtr := TObjectDictionary<string, TDirectProxyRouteDetails>.Create([doOwnsValues], 256);
        end;

        Destructor TVaxCallSessionRoute.Destroy();
        begin
            DeleteAllUserRoutes();
            DeleteAllLineRoutes();
            DeleteAllDirectProxyRoutes();
        end;

        function TVaxCallSessionRoute.GenKey(sValue : string) : string;
        begin
            Result := AnsiLowerCase(sValue);
        end;

        function TVaxCallSessionRoute.FindUserRoute(sUserName : string) : TUserRouteDetails;
        var
            bResult : Boolean;
            objUserRoute : TUserRouteDetails;
        begin
            bResult := m_objMapUserRouteToPtr.TryGetValue(AnsiLowerCase(sUserName), objUserRoute);
            if(bResult = False) then Exit(nil);

            Result := objUserRoute;
        end;

        function TVaxCallSessionRoute.FindLineRoute(sLineName : string) : TLineRouteDetails;
        var
            bResult : Boolean;
            objLineRoute : TLineRouteDetails;
        begin
            bResult := m_objMapLineRouteToPtr.TryGetValue(AnsiLowerCase(sLineName), objLineRoute);
            if(bResult = False) then Exit(nil);

            Result := objLineRoute;
        end;

        function TVaxCallSessionRoute.FindDirectProxyRoute(sProxyName : string) : TDirectProxyRouteDetails;
        var
            bResult : Boolean;
            objProxyRoute : TDirectProxyRouteDetails;
        begin
            bResult := m_objMapDirectProxyRouteToPtr.TryGetValue(AnsiLowerCase(sProxyName), objProxyRoute);
            if(bResult = False) then Exit(nil);

            Result := objProxyRoute;
        end;

        procedure TVaxCallSessionRoute.DeleteAllUserRoutes();
        var
            objUserRoute : TUserRouteDetails;
        begin

            if(m_objMapUserRouteToPtr.Count <= 0) then
              Exit;

            for objUserRoute in m_objMapUserRouteToPtr.Values do
              begin
                    objUserRoute.Free;
              end;

              if(m_objMapUserRouteToPtr.Count > 0) then
                  m_objMapUserRouteToPtr.Clear();

        end;

        procedure TVaxCallSessionRoute.DeleteAllLineRoutes();
        var
            objLineRoute : TLineRouteDetails;
        begin

            if(m_objMapLineRouteToPtr.Count <= 0) then
              Exit;

            for objLineRoute in m_objMapLineRouteToPtr.Values do
              begin
                    objLineRoute.Free;
              end;

              if(m_objMapLineRouteToPtr.Count > 0 ) then
                    m_objMapLineRouteToPtr.Clear();
        end;

        procedure TVaxCallSessionRoute.DeleteAllDirectProxyRoutes();
        var
            objProxyRoute : TDirectProxyRouteDetails;
        begin

            if(m_objMapDirectProxyRouteToPtr.Count <= 0) then
              Exit;

            for objProxyRoute in m_objMapDirectProxyRouteToPtr.Values do
              begin
                    objProxyRoute.Free;
              end;

              if(m_objMapDirectProxyRouteToPtr.Count > 0 ) then
                  m_objMapDirectProxyRouteToPtr.Clear();
        end;

        function TVaxCallSessionRoute.GetUserRouteDetails(sUserName : string; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : Boolean;
        var
            objUserRoute : TUserRouteDetails;
        begin

            objUserRoute := FindUserRoute(sUserName);
            if(objUserRoute = nil) then Exit(False);

            sUserPrefix := objUserRoute.m_sUserPrefix;
            sDialPrefix := objUserRoute.m_sDialPrefix;

            nToPeerType := objUserRoute.m_nToPeerType;
            sToPeerName := objUserRoute.m_sToPeerName;

            Exit(True);

        end;

        function TVaxCallSessionRoute.GetLineRouteDetails(sLineName : string; var nToPeerType : Integer; var sToPeerName : string; var bRejected, bAddToConf : Boolean; var sRoomName : string) : Boolean;
        var
            objLineRoute : TLineRouteDetails;
        begin

            objLineRoute := FindLineRoute(sLineName);
            if(objLineRoute = nil) then Exit(False);

            nToPeerType := objLineRoute.m_nToPeerType;
            sToPeerName := objLineRoute.m_sToPeerName;

            bRejected := objLineRoute.m_bRejected;
            bAddToConf := objLineRoute.m_bAddToConfRoom;
            sRoomName := objLineRoute.m_sRoomName;

            Exit(True);

        end;

        function TVaxCallSessionRoute.GetDirectProxyRouteDetails(sProxyName: string; var nToPeerType : Integer; var sToPeerName : string; var bRejected, bAddToConf : Boolean; var sRoomName : string) : Boolean;
        var
            ObjProxyRoute : TDirectProxyRouteDetails;
        begin

            objProxyRoute := FindDirectProxyRoute(sProxyName);
            if(objProxyRoute = nil) then Exit(False);

            nToPeerType := objProxyRoute.m_nToPeerType;
            sToPeerName := objProxyRoute.m_sToPeerName;

            bRejected := objProxyRoute.m_bRejected;
            bAddToConf := objProxyRoute.m_bAddToConfRoom;
            sRoomName := objProxyRoute.m_sRoomName;

            Exit(True);

        end;

        procedure TVaxCallSessionRoute.ResetOBJ();
        begin
            DeleteAllUserRoutes();
            DeleteAllLineRoutes();
            DeleteAllDirectProxyRoutes();
        end;

        function TVaxCallSessionRoute.AddUserRoute(sUserName, sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : Boolean;
        var
            sKey : string;
            objUserRoute : TUserRouteDetails;
        begin

            sKey := GenKey(sUserName);

            objUserRoute := FindUserRoute(sUserName);
            if(objUserRoute = nil) then
            begin

                objUserRoute := TUserRouteDetails.Create();

                objUserRoute.m_sUserPrefix := sUserPrefix;
                objUserRoute.m_sDialPrefix := sDialPrefix;

                objUserRoute.m_nToPeerType := nToPeerType;
                objUserRoute.m_sToPeerName := sToPeerName;

                m_objMapUserRouteToPtr.Add(sKey, objUserRoute);

                Exit(True);
            end;

            objUserRoute.m_sUserPrefix := sUserPrefix;
            objUserRoute.m_sDialPrefix := sDialPrefix;

            objUserRoute.m_nToPeerType := nToPeerType;
            objUserRoute.m_sToPeerName := sToPeerName;

            // Reference of object. No need to call following function
            //m_objMapUserRouteToPtr.AddOrSetValue(sKey, objUserRoute);
        end;

        procedure TVaxCallSessionRoute.RemoveUserRoute(sUserName : string);
        var
            objUserRoute : TUserRouteDetails;
        begin
            objUserRoute := FindUserRoute(sUserName);
            if(objUserRoute = nil) then Exit;

            m_objMapUserRouteToPtr.Remove(AnsiLowerCase(sUserName));
            //FreeAndNil(objUserRoute);
        end;

        function TVaxCallSessionRoute.AddLineRoute(sLineName : string; nToPeerType : Integer; sToPeerName : string; bRejected, bAddToConf : Boolean; sRoomName : string) : Boolean;
        var
            sKey : string;
            objLineRoute : TLineRouteDetails;
        begin

            sKey := GenKey(sLineName);

            objLineRoute := FindLineRoute(sLineName);
            if(objLineRoute = nil) then
            begin
                objLineRoute := TLineRouteDetails.Create();

                objLineRoute.m_nToPeerType := nToPeerType;
                objLineRoute.m_sToPeerName := sToPeerName;

                objLineRoute.m_bRejected := bRejected;
                objLineRoute.m_bAddToConfRoom := bAddToConf;
                objLineRoute.m_sRoomName := sRoomName;

                m_objMapLineRouteToPtr.Add(sKey, objLineRoute);

                Exit(True);
            end;

            objLineRoute.m_nToPeerType := nToPeerType;
            objLineRoute.m_sToPeerName := sToPeerName;

            objLineRoute.m_bRejected := bRejected;
            objLineRoute.m_bAddToConfRoom := bAddToConf;
            objLineRoute.m_sRoomName := sRoomName;

            // Reference of object. No need to call following function
            //m_objMapLineRouteToPtr.AddOrSetValue(sKey, objLineRoute);
        end;

        procedure TVaxCallSessionRoute.RemoveLineRoute(sLineName : string);
        var
            objLineRoute : TLineRouteDetails;
        begin

            objLineRoute := FindLineRoute(sLineName);
            if(objLineRoute = nil) then Exit;

            m_objMapLineRouteToPtr.Remove(AnsiLowerCase(sLineName));
            //FreeAndNil(objLineRoute);

        end;

        function TVaxCallSessionRoute.AddDirectProxyRoute(sProxyName: string; nToPeerType : Integer; sToPeerName : string; bRejected, bAddToConf : Boolean; sRoomName : string) : Boolean;
        var
            sKey : string;
            objProxyRoute : TDirectProxyRouteDetails;
        begin

            sKey := GenKey(sProxyName);

            objProxyRoute := FindDirectProxyRoute(sProxyName);
            if(objProxyRoute = nil) then
            begin

                objProxyRoute := TDirectProxyRouteDetails.Create();

                objProxyRoute.m_nToPeerType := nToPeerType;
                objProxyRoute.m_sToPeerName := sToPeerName;

                objProxyRoute.m_bRejected := bRejected;
                objProxyRoute.m_bAddToConfRoom := bAddToConf;
                objProxyRoute.m_sRoomName := sRoomName;

                m_objMapDirectProxyRouteToPtr.Add(sKey, objProxyRoute);

                Exit(True);

            end;

            objProxyRoute.m_nToPeerType := nToPeerType;
            objProxyRoute.m_sToPeerName := sToPeerName;

            objProxyRoute.m_bRejected := bRejected;
            objProxyRoute.m_bAddToConfRoom := bAddToConf;
            objProxyRoute.m_sRoomName := sRoomName;

            // Reference of object. No need to call following function
            //m_objMapDirectProxyRouteToPtr.AddOrSetValue(sKey, objProxyRoute);

            Result := True;

        end;

        procedure TVaxCallSessionRoute.RemoveDirectProxyRoute(sProxyName: string);
        var
            objProxyRoute : TDirectProxyRouteDetails;
        begin

            objProxyRoute := FindDirectProxyRoute(sProxyName);
            if(objProxyRoute = nil) then Exit;

            m_objMapDirectProxyRouteToPtr.Remove(AnsiLowerCase(sProxyName));
            //FreeAndNil(objProxyRoute);
        end;

        function TVaxCallSessionRoute.OnCallFromUser(sUserName, sUserDialedNo : string; var sDialno : string; var nToPeerType : Integer; var sToPeerName : string) : Boolean;
        var
            nCharCount, nToPeerNameLen : Integer;
            sUserPrefix, sDialPrefix : string;
            bResult : Boolean;
        begin

            bResult := GetUserRouteDetails(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
            nToPeerNameLen := Length(sToPeerName);

            if ((bResult = False) OR (nToPeerType = -1) OR (nToPeerNameLen <= 0)) then
            begin
              sDialNo := sUserDialedNo;
              nToPeerType := TVaxServerConstants.VAX_PEER_TYPE_USER;
              sToPeerName := sUserDialedNo;

              Exit(True);

            end;

            nCharCount := Length(sUserPrefix);
            if(AnsiMidStr(sUserDialedNo, 1, nCharCount) = sUserPrefix) then // see if 'sUserDialNo' has the 'sUserPrefix' ?
            begin
                Delete(sUserDialedNo, 1, nCharCount);
                sDialNo := sDialPrefix + sUserDialedNo;
            end
            else // else make it USER_TO_USER call
            begin
              sDialNo := sUserDialedNo;
              nToPeerType := TVaxServerConstants.VAX_PEER_TYPE_USER;
              sToPeerName := sUserDialedNo;
            end;

            Result := True;

        end;

        function TVaxCallSessionRoute.onCallFromLine(sLineName : string; var nToPeerType : Integer; var sToPeerName : string; var bRejected, bAddToConf : Boolean; var sRoomName : string) : Boolean;
        begin
            Result := GetLineRouteDetails(sLineName, nToPeerType, sToPeerName, bRejected, bAddToConf, sRoomName);
        end;

        function TVaxCallSessionRoute.OnCallFromDirectProxySIP(sProxyName: string; var nToPeerType : Integer; var sToPeerName : string; var bRejected, bAddToConf : Boolean; var sRoomName : string) : Boolean;
        begin
            Result := GetDirectProxyRouteDetails(sProxyName, nToPeerType, sToPeerName, bRejected, bAddToConf, sRoomName);
        end;


end.
