unit ConfRoom;

interface

uses
    System.Classes,

    VaxCallSession,
    VaxServerConstants,
    ConfRoomList;

type TConfRoom = class

    private

    m_objVaxCallSession : TVaxCallSession;
    m_objConfRoomList : TConfRoomList;

    public
        const CONNECT_TIME_OUT : Integer = 30;

    public

        procedure OnCallSessionOpen( nSessionId : integer;  sCallerName : string;  sCallerId : string;  sDialNo : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer);
        procedure OnCallSessionFailed( nSessionId : integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString);

        procedure OnCallSessionConnected( nSessionId : integer; sRoomName : string);
        procedure OnCallSessionClosed(nSessionId : integer; CallType: Integer; ReasonCode: Integer);

        procedure OnCallSessionOnHold(nSessionId : integer; CallType: Integer);
        procedure OnCallSessionOffHold(nSessionId : integer; CallType: Integer);

        procedure OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererCallType: Integer; const sTransferer: WideString; const sTransferee: WideString; const sTransferTo: WideString);
        procedure OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfereeSessionId: Integer; nTransferToSessionId: Integer;
                                                nTransfererCallType: Integer; nTransfereeCallType: Integer; nTransferToCallType: Integer; const sTransferer: WideString; const sTransferee: WideString; const sTransferTo: WideString);



    public

        constructor Create(var objVaxCallSession : TVaxCallSession);

        procedure ResetOBJ();

        function AddRoom(sRoomName : string ; sRoomNo : string) : Boolean;
        procedure RemoveRoom(sRoomName : string);

        function GetRoomName(sRoomNo : string) : string;

        function GetRoomDetails(sRoomName : string; var sRoomNo : string) : Boolean;

        function IsRoomNoExist(sRoomNo : string) : Boolean;

        function GetRoomAll(var pRoomList : TStringList) : Boolean;


end;

implementation

        procedure TConfRoom.OnCallSessionOpen( nSessionId : integer;  sCallerName : string;  sCallerId : string;  sDialNo : string;  nFromPeerType : integer;  sFromPeerName : string;  sFromIP : string;  nFromPort : integer);
        var bResult : Boolean;
        begin
            bResult := m_objVaxCallSession.AcceptCallSession(nSessionId, sCallerName, sCallerId, '', -1, '', CONNECT_TIME_OUT);
        end;

        procedure TConfRoom.OnCallSessionFailed( nSessionId : integer; CallType: Integer; StatusCode: Integer; const ReasonPhrase: WideString);
        begin
          //
        end;

        procedure TConfRoom.OnCallSessionConnected( nSessionId : integer; sRoomName : string);
        var bResult : Boolean;
        begin
            bResult := m_objVaxCallSession.AddCallSessionToConferenceRoom(sRoomName, nSessionId, TVaxServerConstants.CONF_ROOM_NORMAL_LISTENER); // CVaxServerExCOM.CONF_ROOM_NORMAL_LISTENER = 100
        end;

        procedure TConfRoom.OnCallSessionClosed(nSessionId : integer; CallType: Integer; ReasonCode: Integer);
        begin
          //
        end;

        procedure TConfRoom.OnCallSessionOnHold(nSessionId : integer; CallType: Integer);
        begin
          //
        end;

        procedure TConfRoom.OnCallSessionOffHold(nSessionId : integer; CallType: Integer);
        begin
            //
        end;

        procedure TConfRoom.OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererCallType: Integer; const sTransferer: WideString; const sTransferee: WideString; const sTransferTo: WideString);
        begin
            m_objVaxCallSession.RejectTransfer(nTransfererSessionId);
        end;

        procedure TConfRoom.OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfereeSessionId: Integer; nTransferToSessionId: Integer;
                                                nTransfererCallType: Integer; nTransfereeCallType: Integer; nTransferToCallType: Integer; const sTransferer: WideString; const sTransferee: WideString; const sTransferTo: WideString);
        begin
            m_objVaxCallSession.RejectTransfer(nTransfererSessionId);
        end;

        constructor TConfRoom.Create(var objVaxCallSession : TVaxCallSession);
        begin
            m_objVaxCallSession := objVaxCallSession;
            m_objConfRoomList := TConfRoomList.Create();
        end;

        procedure TConfRoom.ResetOBJ();
        begin
            m_objConfRoomList.ResetOBJ();
        end;

        function TConfRoom.AddRoom(sRoomName : string ; sRoomNo : string) : Boolean;
        var bResult : Boolean;
        begin
            bResult := m_objConfRoomList.AddRoom(sRoomName, sRoomNo);
            if(bResult = False) then
                Exit(False);

            bResult := m_objVaxCallSession.OpenConferenceRoom(sRoomName);
            if(bResult = False) then
            begin
                m_objConfRoomList.RemoveRoom(sRoomName);
                Exit(False);
            end;

            Result := True;
        end;

        procedure TConfRoom.RemoveRoom(sRoomName : string);
        begin
            m_objVaxCallSession.CloseConferenceRoom(sRoomName);
            m_objConfRoomList.RemoveRoom(sRoomName);
        end;

        function TConfRoom.GetRoomName(sRoomNo : string) : string;
        begin
            Result := m_objConfRoomList.GetRoomName(sRoomNo);
        end;

        function TConfRoom.GetRoomDetails(sRoomName : string; var sRoomNo : string) : Boolean;
        begin
            Result := m_objConfRoomList.GetRoomDetails(sRoomName, sRoomNo);
        end;

        function TConfRoom.IsRoomNoExist(sRoomNo : string) : Boolean;
        begin
            Result := m_objConfRoomList.IsRoomNoExist(sRoomNo);
        end;

        function TConfRoom.GetRoomAll(var pRoomList : TStringList) : Boolean;
        begin
            Result := m_objConfRoomList.GetRoomAll(pRoomList);
        end;


end.
