unit VaxError;

interface

uses
    Define,
    VaxServerConstants,
    VaxTeleServerSIP,
    VaxServerRoot;

type TVaxError = class(TVaxServerRoot)

    public
        m_objVaxServer : TVaxTeleServerSIP;


    public
        procedure OnVaxTeleError(nErrorCode : Integer); override;

    public
        constructor Create();


    private
        function FetchErrorMsg(nErrorCode : Integer) : string;


end;

implementation

        constructor TVaxError.Create();
        begin
            inherited;
            inherited AddRef(TVaxServerConstants.ID_CLASS_ERROR_SIP); //ID_CLASS_ERROR_SIP = 6
        end;


        procedure TVaxError.OnVaxTeleError(nErrorCode : Integer);

        var
            sErrorMsg : string;

        begin

            sErrorMsg := FetchErrorMsg(nErrorCode);
            m_objVaxServer.OnVaxTeleError(nErrorCode, sErrorMsg);

        end;

        function TVaxError.FetchErrorMsg(nErrorCode : Integer) : string;

        var
            sErrorMsg : string;

        begin

            sErrorMsg := '';

            case nErrorCode of

                 200:
                    sErrorMsg := TDefine.FAIL_TO_INITIALIZE_RTP_SOCKET;
                 201:
                    sErrorMsg := TDefine.FAIL_TO_ALLOCATE_RTP_LISTEN_PORT;

                 202:
                    sErrorMsg := TDefine.FAIL_TO_CREATE_RTP_TASK_WND;

                 203:
                    sErrorMsg := TDefine.FAIL_TO_START_MEDIA_THREAD;

                 204:
                    sErrorMsg := TDefine.FAIL_TO_CREATE_RTP_COMMUNICATION_WND;

                 205:
                    sErrorMsg := TDefine.FAIL_TO_USE_RTP_COMMUNICATION_WND;

                 206:
                    sErrorMsg := TDefine.FAIL_TO_OPEN_FILE;

                 207:
                    sErrorMsg := TDefine.FAIL_TO_READ_FILE;

                 208:
                    sErrorMsg := TDefine.INVALID_WAVE_FILE_FORMAT;

                 209:
                    sErrorMsg := TDefine.INVALID_PLAY_WAVE_ID;

                 210:
                    sErrorMsg := TDefine.FAIL_TO_START_RECORDING_MANAGER;

                 211:
                    sErrorMsg := TDefine.CALL_NOT_IN_SESSION;

                 212:
                    sErrorMsg := TDefine.ERROR_INITIALIZE_VAXOBJECT;

                 213:
                    sErrorMsg := TDefine.ERROR_TO_CREATE_SDP;

                 214:
                    sErrorMsg := TDefine.ERROR_TO_CREATE_INVITE_REQUEST;

                 215:
                    sErrorMsg := TDefine.ERROR_TO_INITIALIZE_SIP_COMM_LAYER;

                 216:
                    sErrorMsg := TDefine.ERROR_TO_OPEN_SIP_LISTEN_PORT;

                 217:
                    sErrorMsg := TDefine.ERROR_FAIL_TO_CREATE_SIP_TASK_WND;

                 218:
                    sErrorMsg := TDefine.ERROR_TO_CREATE_REGISTER_REQUEST;

                 219:
                    sErrorMsg := TDefine.ERROR_TO_CREATE_UNREGISTER_REQUEST;

                 220:
                    sErrorMsg := TDefine.ERROR_TO_CREATE_BYE_REQUEST;

                 221:
                    sErrorMsg := TDefine.ERROR_TO_CREATE_CANCEL_REQUEST;

                 222:
                    sErrorMsg := TDefine.ERROR_INVALID_CALL_SESSION_ID;

                 223:
                    sErrorMsg := TDefine.ERROR_SESSION_DOES_NOT_EXIST;

                 224:
                    sErrorMsg := TDefine.ERROR_USER_LOGIN_DOES_NOT_EXIST;

                 225:
                    sErrorMsg := TDefine.ERROR_USER_LOGIN_INVALID_LENGTH;

                 226:
                    sErrorMsg := TDefine.ERROR_LINE_DOES_NOT_EXIST;

                 227:
                    sErrorMsg := TDefine.ERROR_CANNOT_SEND_RESPONSE;

                 228:
                    sErrorMsg := TDefine.ERROR_INVALID_REPONSE_CODE;

                 229:
                    sErrorMsg := TDefine.ERROR_TO_CREATE_SIP_MSG;

                 230:
                    sErrorMsg := TDefine.ERROR_LINE_ALREADY_EXIST;

                 231:
                    sErrorMsg := TDefine.ERROR_INVALID_REG_ID;

                 232:
                    sErrorMsg := TDefine.ERROR_TO_CREATE_SIP_RESPONSE;

                 233:
                    sErrorMsg := TDefine.ERROR_USER_NOT_REGISTER;

                 234:
                    sErrorMsg := TDefine.ERROR_NO_STREAM_CODEC_FOUND;

                 235:
                    sErrorMsg := TDefine.ERROR_INVALID_DTMF_TYPE;

                 236:
                    sErrorMsg := TDefine.ERROR_OTHER_PARTY_NOT_SUPPORT_RFC2833_DTMF;

                 237:
                    sErrorMsg := TDefine.ERROR_TO_CREATE_REFER;

                 238:
                    sErrorMsg := TDefine.ERROR_FAIL_TO_CREATE_EVENT_OBJECT;

                 239:
                    sErrorMsg := TDefine.ERROR_LICENSE_KEY;

                 240:
                    sErrorMsg := TDefine.ERROR_INVALID_DIGIT_DTMF;

                 241:
                    sErrorMsg := TDefine.ERROR_INVALID_PROXY_URI;

                 242:
                    sErrorMsg := TDefine.ERROR_LINE_NOT_REGISTER;

                 243:
                    sErrorMsg := TDefine.ERROR_INVALID_TO_URI;

                 244:
                    sErrorMsg := TDefine.ERROR_NOT_CONNECTED_CALL;

                 245:
                    sErrorMsg := TDefine.ERROR_CONNECTED_CALL;

                 246:
                    sErrorMsg := TDefine.ERROR_NO_INCOMING_ANONYMOUS_REQ;

                 247:
                    sErrorMsg := TDefine.ERROR_INVALID_PARAM_VALUE;

                 248:
                    sErrorMsg := TDefine.ERROR_INVALID_CHAT_MSG_ID;

                 249:
                    sErrorMsg := TDefine.ERROR_INVALID_CHAT_SUBSCRIBE_ID;

                 250:
                    sErrorMsg := TDefine.ERROR_TO_ALLOCATE_UNIQUE_ID;

                 251:
                    sErrorMsg := TDefine.ERROR_INVALID_UNIQUE_ID;

                 252:
                    sErrorMsg := TDefine.VAX_ERROR_ALREADY_EXIST;

                 253:
                    sErrorMsg := TDefine.VAX_ERROR_NOT_FOUND;

                 254:
                    sErrorMsg := TDefine.VAX_UNABLE_CREATE_CALL_SESSION;

                 255:
                    sErrorMsg := TDefine.VAX_ERROR_DTMF_DETECT;

            end;

            Result := sErrorMsg;

        end;


end.
