unit VaxLine;

interface

uses
    System.Classes,
    VaxLineList,
    VaxTeleServerSIP,
    VaxServerConstants,
    VaxServerRoot;

type TVaxLine = class(TVaxServerRoot)

    private
        m_objVaxLineList : TVaxLineList;

    public
        m_objVaxServer : TVaxTeleServerSIP;

    public

        procedure OnLineRegisterTrying( sLineName : string); override;
        procedure OnLineRegisterFail( sLineName : string; nStatusCode : integer;  sReasonPhrase : string); override;
        procedure OnLineRegisterSuccess( sLineName : string); override;
        procedure OnLineUnRegisterTrying( sLineName : string); override;
        procedure OnLineUnRegisterFail( sLineName : string; nStatusCode : integer;  sReasonPhrase : string); override;
        procedure OnLineUnRegisterSuccess( sLineName : string); override;

    private

        function IsLineExist(sLineName : string) : boolean;

    public

        constructor Create();

        procedure ResetOBJ();

        function AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList : string; bRegister : boolean; nToPeerType : integer; sToPeerName : string; bBlocked, bAddToConf : boolean; sRoomName : string) : boolean;
        procedure RemoveLine(sLineName : string);

        function RegisterLine(sLineName : string) : boolean;
        function UnRegisterLine(sLineName : string) : boolean;

        function GetLineAll(var pLineList : TStringList) : boolean;
        function GetLineDetails(sLineName : string; var sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList : string; var bRegister : boolean; var nToPeerType : integer; var sToPeerName : string; var bBlocked, bAddToConf : boolean; var sRoomName : string) : boolean;
end;

implementation


        //////////////////////////////////////////////////////////////////////////
        ///     Events
        //////////////////////////////////////////////////////////////////////////

        procedure TVaxLine.OnLineRegisterTrying( sLineName : string);
        begin
            m_objVaxServer.OnLineRegisterTrying(sLineName);
        end;

        procedure TVaxLine.OnLineRegisterFail( sLineName : string; nStatusCode : integer;  sReasonPhrase : string);
        begin
            m_objVaxServer.OnLineRegisterFail(sLineName, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxLine.OnLineRegisterSuccess( sLineName : string);
        begin
            m_objVaxServer.OnLineRegisterSuccess(sLineName);
        end;

        procedure TVaxLine.OnLineUnRegisterTrying( sLineName : string);
        begin
          //
        end;

        procedure TVaxLine.OnLineUnRegisterFail( sLineName : string; nStatusCode : integer;  sReasonPhrase : string);
        begin
          //
        end;

        procedure TVaxLine.OnLineUnRegisterSuccess( sLineName : string);
        begin
          //
        end;


        //////////////////////////////////////////////////////////////////////////
        ///     Functions
        //////////////////////////////////////////////////////////////////////////

        constructor TVaxLine.Create();
        begin
          inherited;
          inherited AddRef(TVaxServerConstants.ID_CLASS_LINE_SIP);  // ID_CLASS_LINE_SIP = 4

          m_objVaxLineList := TVaxLineList.Create();
        end;

        function TVaxLine.IsLineExist(sLineName : string) : boolean;
        begin
            Result := m_objVaxLineList.IsLineExist(sLineName);
        end;

        procedure TVaxLine.ResetOBJ();
        begin
            m_objVaxLineList.ResetOBJ();
        end;

        function TVaxLine.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList : string; bRegister : boolean; nToPeerType : integer; sToPeerName : string; bBlocked, bAddToConf : boolean; sRoomName : string) : boolean;
        begin

           if(inherited AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, '', sCodecList) = false) then
           begin
             Result := False;
             Exit;
           end;

           if(bRegister = True) then
             inherited RegisterLine(sLineName);

           Result := m_objVaxLineList.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlocked, bAddToConf, sRoomName);

        end;

        procedure TVaxLine.RemoveLine(sLineName : string);
        begin

            inherited RemoveLine(sLineName);
            m_objVaxLineList.DeleteLine(sLineName);
        end;

        function TVaxLine.RegisterLine(sLineName : string) : boolean;
        begin
            Result := inherited RegisterLine(sLineName);
        end;

        function TVaxLine.UnRegisterLine(sLineName : string) : boolean;
        begin
            Result := inherited UnRegisterLine(sLineName);
        end;

        function TVaxLine.GetLineAll(var pLineList : TStringList) : boolean;
        begin
            Result := m_objVaxLineList.GetLineAll(pLineList);
        end;

        function TVaxLine.GetLineDetails(sLineName : string; var sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList : string; var bRegister : boolean; var nToPeerType : integer; var sToPeerName : string; var bBlocked, bAddToConf : boolean; var sRoomName : string) : boolean;
        begin
            Result := m_objVaxLineList.GetLineDetails(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlocked, bAddToConf, sRoomName);
        end;


end.
