unit VaxTeleServerSIP;

interface

uses
    ErrorLogDlg,
    StatusLogDlg,

    Windows,
    psapi,
    System.SysUtils,
    System.Classes,
    Vcl.Dialogs;

type TVaxTeleServerSIP = class

    public
      m_objStatusLogDlg : TStatusLogForm;
      m_objErrorLogDlg : TErrorLogForm;

      //////////////////////////////////////////////////////////////////////
      ///       Events
      //////////////////////////////////////////////////////////////////////

      procedure OnLineRegisterTrying( sLineName : string);
      procedure OnLineRegisterFail( sLineName : string;  lStatusCode : integer; sReasonPhrase : string);
      procedure OnLineRegisterSuccess( sLineName : string);

      procedure OnUnRegisterUser( sUserLogin : string);
      procedure OnRegisterUser( sUserLogin : string;  sDomain : string;  sFromIP : string; nFromPort : integer);
      procedure OnRegisterUserSuccess( sUserLogin : string);
      procedure OnRegisterUserFail( sUserLogin : string);

      procedure OnVaxTeleError(nErrorCode : integer; sErrorMsg : string);

      //////////////////////////////////////////////////////////////////////
      ///       Functions
      //////////////////////////////////////////////////////////////////////

      constructor Create();
      procedure ResetOBJ();

      // TVaxUser Functions

      function AddUser(sLogin, sPassword, sCodecList : string; bBlocked : boolean; sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : boolean;
      procedure RemoveUser(sLogin : string);
      procedure GetUserAll(var objLoginList : TStringList);
      function GetUserDetails(sLogin : string; var sPassword, sCodecList : string; var bBlocked : boolean; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : boolean;

      // TVaxLine Functions

      function AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList : string; bRegister : boolean; nToPeerType : integer; sToPeerName : string; bBlocked, bAddToConf : boolean; sRoomName : string) : boolean;
      procedure RemoveLine(sLineName : string);

      function RegisterLine(sLineName : string) : boolean;
      function UnRegisterLine(sLineName : string) : boolean;

      function GetLineAll(var pLineList : TStringList) : boolean;
      function GetLineDetails(sLineName : string; var sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList : string; var bRegister : boolean; var nToPeerType : integer; var sToPeerName : string; var bBlocked, bAddToConf : boolean; var sRoomName : string) : boolean;

      // TVaxDirectProxy Functions

      function AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP : string; lProxyPort : Integer; sCodecList : string; nToPeerType : Integer; sToPeerName : string; bBlock, bAddToConf : boolean; sRoomName : string) : boolean;
      procedure RemoveDirectProxySIP(sProxyName : string);

      function GetDirectProxyAll(var pProxyList : TStringList) : boolean;
      function GetDirectProxyDetails(sProxyName : string; var sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP : string; var lProxyPort : Integer; var sCodecList : string; var nToPeerType : Integer; sToPeerName : string; var bBlock, bAddToConf : boolean; var sRoomName : string) : boolean;

      // TVaxCallSession Functions

      function AddRoom(sRoomName : string ; sRoomNo : string) : Boolean;
      procedure RemoveRoom(sRoomName : string);

      function GetRoomDetails(sRoomName : string; var sRoomNo : string) : Boolean;

      function IsRoomNoExist(sRoomName : string) : Boolean;
      function GetRoomAll(var pRoomList : TStringList) : Boolean;


      // TVaxMain Functions

      procedure SetLicenseKey(sLicenseKey : string);

      function Initialize(sDomainRealm : string;  sSIPListenIP : string; nSIPListenPort : integer ;  sRTPListenIP : string; nRTPListenPort : integer ) : boolean;
      procedure UnInitialize();

      function PlayWaveStartToCallSession(lSessionId : integer ; lWaveId : integer ; bLoop : boolean) : boolean;
      function PlayWaveStopToCallSession(lSessionId : integer ) : boolean;

      function RecordWaveStartToCallSession(lSessionId : integer ;  sFileName : string) : boolean;
      function RecordWaveStopToCallSession(lSessionId : integer ) : boolean;
      function RecordWavePauseToCallSession(lSessionId : integer ; bEnable : boolean) : boolean;

      function LoadWaveFile( sFileName : string) : integer;
      procedure UnLoadWaveFile(lWaveId : integer);

      function LoadMusicHold( sFileName : string) : boolean;
      procedure UnLoadMusicHold();

      function OpenConferenceRoom( sRoomName : string) : boolean;
      procedure CloseConferenceRoom( sRoomName : string);

      function VoiceSessionLost(bEnable : boolean; lTimeOut : integer ) : boolean;

      function SendInfoVM( sUserLogin : string;  nNewMsgCount : integer ;  nOldMsgCount : integer ; bMsgWaiting : Boolean ) : integer;

      function StartVaxTeleTick(lTickId : integer ; lElapse : integer ) : boolean;
      function StopVaxTeleTick(lTickId : integer ) : boolean;

      function SetUserAgentName( sName : string) : boolean;
      function GetUserAgentName() : string;

      function SetSessionNameSDP( sName : string) : boolean;
      function GetSessionNameSDP() : string;

      function SendDTMFCallSession( lSessionId : integer ;  nTypeDTMF : integer ;  nDigit : integer ) : boolean;
      function DetectDTMFCallSession( lSessionId : integer ;  nTypeDTMF : integer ; bEnable : boolean;  nTimeout : integer ) : boolean;

      function GetVaxObjectError() : integer;

      function DialToneToCallSession( bEnable : boolean;  lSessionId : integer ;  lWaveId : integer ) : boolean;
      function DiagnosticLogSIP( bInbound : boolean;  bOutbound : boolean) : boolean;

      function GetUserCount() : Integer;
      function GetCallCount() : Integer;
      function GetAvailableMEM() : Integer;

      function GetUsageCPU() : Integer;

      function LoadMusicDialTone(sFileName : string) : Boolean;
      procedure UnLoadMusicDialTone();

      procedure OnStatusLog(sStatus : string);
      procedure OnErrorLog(sError : string);

end;


implementation

uses
    Define,
    VaxChat,
    VaxDirectProxy,
    VaxError,
    VaxMain,
    VaxUser,
    VaxCallSession,
    VaxLine;

var
    m_objVaxMain : TVaxMain;
    m_objVaxUser : TVaxUser;
    m_objVaxLine : TVaxLine;
    m_objVaxDirectProxy : TVaxDirectProxy;
    m_objVaxChat : TVaxChat;
    m_objVaxCallSession : TVaxCallSession;
    m_objVaxError : TVaxError;

    KernalDllHandle : THandle;
    SystemTimesPtr : Pointer;

      procedure TVaxTeleServerSIP.OnLineRegisterTrying( sLineName : string);
      begin
            OnStatusLog(sLineName + ' ' + TDefine.LINE_REG_TRYING);
      end;

      procedure TVaxTeleServerSIP.OnLineRegisterFail( sLineName : string;  lStatusCode : integer; sReasonPhrase : string);
      begin
            OnStatusLog(sLineName + ' ' + TDefine.LINE_REG_FAILED);
      end;
      procedure TVaxTeleServerSIP.OnLineRegisterSuccess( sLineName : string);
      begin
            OnStatusLog(sLineName + ' ' + TDefine.LINE_REG_SUCCESS);
      end;

      procedure TVaxTeleServerSIP.OnUnRegisterUser( sUserLogin : string);
      begin
            m_objVaxUser.SetUserRegister(sUserLogin, False);
            OnStatusLog(sUserLogin + ' logged off.');
      end;

      procedure TVaxTeleServerSIP.OnRegisterUser( sUserLogin : string;  sDomain : string;  sFromIP : string; nFromPort : integer);
      var bResult : Boolean;
      begin
            If Not m_objVaxUser.IsUserExist(sUserLogin) then
            begin
                m_objVaxUser.RejectRegister(sUserLogin, 404, TDefine.NOT_FOUND);
                Exit;
            end;

            If m_objVaxUser.IsUserBlocked(sUserLogin) then
            begin
                m_objVaxUser.RejectRegister(sUserLogin, 404, TDefine.NOT_FOUND);
                Exit;
            end;

            bResult := m_objVaxUser.AuthRegister(sUserLogin);
            OnStatusLog(sUserLogin + ' ' + TDefine.USER_REG_TRYING);

      end;

      procedure TVaxTeleServerSIP.OnRegisterUserSuccess( sUserLogin : string);
      begin
            m_objVaxUser.SetUserRegister(sUserLogin, True);
            OnStatusLog(sUserLogin + ' ' + TDefine.USER_REG_SUCCESS);
      end;

      procedure TVaxTeleServerSIP.OnRegisterUserFail( sUserLogin : string);
      begin
            OnStatusLog(sUserLogin + ' ' + TDefine.USER_REG_FAILED);
      end;

      procedure TVaxTeleServerSIP.OnVaxTeleError(nErrorCode : integer; sErrorMsg : string);
      begin
            OnErrorLog(IntToStr(nErrorCode) + ': ' + sErrorMsg);
      end;

      //////////////////////////////////////////////////////////////////////
      ///       Functions
      //////////////////////////////////////////////////////////////////////

      constructor TVaxTeleServerSIP.Create();
      var
        nError : Integer;
      begin

            m_objVaxMain := TVaxMain.Create();
            m_objVaxUser := TVaxUser.Create();
            m_objVaxLine := TVaxLine.Create();
            m_objVaxDirectProxy := TVaxDirectProxy.Create();
            m_objVaxChat := TVaxChat.Create();
            m_objVaxCallSession := TVaxCallSession.Create();
            m_objVaxError := TVaxError.Create();

            m_objVaxUser.m_objVaxServer := self;
            m_objVaxLine.m_objVaxServer := self;
            m_objVaxError.m_objVaxServer := self;

            KernalDllHandle := LoadLibraryW('Kernel32.dll');
            if KernalDllHandle <> 0 then
            begin
              SystemTimesPtr := GetProcAddress(KernalDllHandle, 'GetSystemTimes');
              if(SystemTimesPtr = Nil) then
              begin
                ShowMessage('GetProcAddress Failed.');
                FreeLibrary(KernalDllHandle);
              end;

            end;

      end;

      procedure TVaxTeleServerSIP.ResetOBJ();
      begin

            m_objVaxCallSession.ResetOBJ();
            m_objVaxUser.ResetOBJ();
            m_objVaxLine.ResetOBJ();
            m_objVaxDirectProxy.ResetOBJ();

            FreeLibrary(KernalDllHandle);


      end;

      // TVaxUser Functions

      function TVaxTeleServerSIP.AddUser(sLogin, sPassword, sCodecList : string; bBlocked : boolean; sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : boolean;
      begin

            // If both sUserPrefix and sDialPrefix are EMPTY then set sToPeerName := ''

            if( Length(sUserPrefix) = 0 ) then
            begin

              if(Length(sDialPrefix) = 0) then
                sToPeerName := '';

            end;

            m_objVaxCallSession.AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
            Result := m_objVaxUser.AddUser(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

      end;

      procedure TVaxTeleServerSIP.RemoveUser(sLogin : string);
      begin

            m_objVaxUser.RemoveUser(sLogin);
            m_objVaxCallSession.RemoveUserRoute(sLogin);

      end;

      procedure TVaxTeleServerSIP.GetUserAll(var objLoginList : TStringList);
      begin

            m_objVaxUser.GetUserAll(objLoginList);
      end;

      function TVaxTeleServerSIP.GetUserDetails(sLogin : string; var sPassword, sCodecList : string; var bBlocked : boolean; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : boolean;
      begin

            Result := m_objVaxUser.GetUserDetails(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
      end;

      // TVaxLine Functions

      function TVaxTeleServerSIP.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList : string; bRegister : boolean; nToPeerType : integer; sToPeerName : string; bBlocked, bAddToConf : boolean; sRoomName : string) : boolean;
      begin

            m_objVaxCallSession.AddLineRoute(sLineName, nToPeerType, sToPeerName, bBlocked, bAddToConf, sRoomName);
            Result := m_objVaxLine.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlocked, bAddToConf, sRoomName)
      end;

      procedure TVaxTeleServerSIP.RemoveLine(sLineName : string);
      begin

            m_objVaxLine.RemoveLine(sLineName);
            m_objVaxCallSession.RemoveLineRoute(sLineName);
      end;

      function TVaxTeleServerSIP.RegisterLine(sLineName : string) : boolean;
      begin

            Result := m_objVaxLine.RegisterLine(sLineName);
      end;

      function TVaxTeleServerSIP.UnRegisterLine(sLineName : string) : boolean;
      begin

            Result := m_objVaxLine.UnRegisterLine(sLineName);
      end;

      function TVaxTeleServerSIP.GetLineAll(var pLineList : TStringList) : boolean;
      begin

            Result := m_objVaxLine.GetLineAll(pLineList);
      end;

      function TVaxTeleServerSIP.GetLineDetails(sLineName : string; var sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList : string; var bRegister : boolean; var nToPeerType : integer; var sToPeerName : string; var bBlocked, bAddToConf : boolean; var sRoomName : string) : boolean;
      begin

            Result := m_objVaxLine.GetLineDetails(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlocked, bAddToConf, sRoomName);
      end;

      // TVaxDirectProxy Functions

      function TVaxTeleServerSIP.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP : string; lProxyPort : Integer; sCodecList : string; nToPeerType : Integer; sToPeerName : string; bBlock, bAddToConf : boolean; sRoomName : string) : boolean;
      begin

            m_objVaxCallSession.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);
            Result := m_objVaxDirectProxy.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList, nToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);

      end;

      procedure TVaxTeleServerSIP.RemoveDirectProxySIP(sProxyName : string);
      begin

            m_objVaxCallSession.RemoveDirectProxyRoute(sProxyName);
            m_objVaxDirectProxy.RemoveDirectProxySIP(sProxyName);

      end;

      function TVaxTeleServerSIP.GetDirectProxyAll(var pProxyList : TStringList) : boolean;
      begin

            Result := m_objVaxDirectProxy.GetDirectProxyAll(pProxyList);
      end;

      function TVaxTeleServerSIP.GetDirectProxyDetails(sProxyName : string; var sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP : string; var lProxyPort : Integer; var sCodecList : string; var nToPeerType : Integer; sToPeerName : string; var bBlock, bAddToConf : boolean; var sRoomName : string) : boolean;
      begin

            Result := m_objVaxDirectProxy.GetDirectProxyDetails(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList, nToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);
      end;

      // TVaxCallSession Functions

      function TVaxTeleServerSIP.AddRoom(sRoomName : string ; sRoomNo : string) : Boolean;
      begin

            Result := m_objVaxCallSession.AddRoom(sRoomName, sRoomNo);
      end;

      procedure TVaxTeleServerSIP.RemoveRoom(sRoomName : string);
      begin

            m_objVaxCallSession.RemoveRoom(sRoomName);
      end;

      function TVaxTeleServerSIP.GetRoomDetails(sRoomName : string; var sRoomNo : string) : Boolean;
      begin

            Result := m_objVaxCallSession.GetRoomDetails(sRoomName, sRoomNo);
      end;

      function TVaxTeleServerSIP.IsRoomNoExist(sRoomName : string) : Boolean;
      begin

            Result := m_objVaxCallSession.IsRoomNoExist(sRoomName);
      end;

      function TVaxTeleServerSIP.GetRoomAll(var pRoomList : TStringList) : Boolean;
      begin

            Result := m_objVaxCallSession.GetRoomAll(pRoomList);
      end;

      // TVaxMain Functions

      procedure TVaxTeleServerSIP.SetLicenseKey(sLicenseKey : string);
      begin

            m_objVaxMain.SetLicenseKey(sLicenseKey);
      end;

      function TVaxTeleServerSIP.Initialize(sDomainRealm : string;  sSIPListenIP : string; nSIPListenPort : integer ;  sRTPListenIP : string; nRTPListenPort : integer ) : boolean;
      begin
            Result := m_objVaxMain.Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sRTPListenIP, nRTPListenPort);
      end;

      procedure TVaxTeleServerSIP.UnInitialize();
      begin

            ResetOBJ();
            m_objVaxMain.UnInitialize();
      end;

      function TVaxTeleServerSIP.PlayWaveStartToCallSession(lSessionId : integer ; lWaveId : integer ; bLoop : boolean) : boolean;
      begin

            Result := m_objVaxMain.PlayWaveStartToCallSession(lSessionId, lWaveId, bLoop);
      end;

      function TVaxTeleServerSIP.PlayWaveStopToCallSession(lSessionId : integer ) : boolean;
      begin

            Result := m_objVaxMain.PlayWaveStopToCallSession(lSessionId);
      end;

      function TVaxTeleServerSIP.RecordWaveStartToCallSession(lSessionId : integer ;  sFileName : string) : boolean;
      begin

            Result := m_objVaxMain.RecordWaveStartToCallSession(lSessionId, sFileName);
      end;

      function TVaxTeleServerSIP.RecordWaveStopToCallSession(lSessionId : integer ) : boolean;
      begin

            Result := m_objVaxMain.RecordWaveStopToCallSession(lSessionId);
      end;

      function TVaxTeleServerSIP.RecordWavePauseToCallSession(lSessionId : integer ; bEnable : boolean) : boolean;
      begin

            Result := m_objVaxMain.RecordWavePauseToCallSession(lSessionId, bEnable);
      end;

      function TVaxTeleServerSIP.LoadWaveFile( sFileName : string) : integer;
      begin

            Result := m_objVaxMain.LoadWaveFile(sFileName);
      end;

      procedure TVaxTeleServerSIP.UnLoadWaveFile(lWaveId : integer);
      begin

            m_objVaxMain.UnLoadWaveFile(lWaveId);
      end;

      function TVaxTeleServerSIP.LoadMusicHold( sFileName : string) : boolean;
      begin

            Result := m_objVaxMain.LoadMusicHold(sFileName);
      end;

      procedure TVaxTeleServerSIP.UnLoadMusicHold();
      begin

            m_objVaxMain.UnLoadMusicHold();
      end;

      function TVaxTeleServerSIP.OpenConferenceRoom( sRoomName : string) : boolean;
      begin
            Result := m_objVaxMain.OpenConferenceRoom(sRoomName);
      end;

      procedure TVaxTeleServerSIP.CloseConferenceRoom( sRoomName : string);
      begin
        //
      end;

      function TVaxTeleServerSIP.VoiceSessionLost(bEnable : boolean; lTimeOut : integer ) : boolean;
      begin

            Result := m_objVaxMain.VoiceSessionLost(bEnable, lTimeOut);
      end;

      function TVaxTeleServerSIP.SendInfoVM( sUserLogin : string;  nNewMsgCount : integer ;  nOldMsgCount : integer ; bMsgWaiting : Boolean ) : integer;
      begin

            Result := m_objVaxMain.SendInfoVM(sUserLogin, nNewMsgCount, nOldMsgCount, bMsgWaiting);
      end;

      function TVaxTeleServerSIP.StartVaxTeleTick(lTickId : integer ; lElapse : integer ) : boolean;
      begin

            Result := m_objVaxMain.StartVaxTeleTick(lTickId, lElapse);
      end;

      function TVaxTeleServerSIP.StopVaxTeleTick(lTickId : integer ) : boolean;
      begin
            Result := m_objVaxMain.StopVaxTeleTick(lTickId);
      end;

      function TVaxTeleServerSIP.SetUserAgentName( sName : string) : boolean;
      begin
            Result := m_objVaxMain.SetUserAgentName(sName);
      end;

      function TVaxTeleServerSIP.GetUserAgentName() : string;
      begin
            Result := m_objVaxMain.GetUserAgentName();
      end;

      function TVaxTeleServerSIP.SetSessionNameSDP( sName : string) : boolean;
      begin
            Result := m_objVaxMain.SetSessionNameSDP(sName);
      end;

      function TVaxTeleServerSIP.GetSessionNameSDP() : string;
      begin
            Result := m_objVaxMain.GetSessionNameSDP();
      end;

      function TVaxTeleServerSIP.SendDTMFCallSession( lSessionId : integer ;  nTypeDTMF : integer ;  nDigit : integer ) : boolean;
      begin
            Result := m_objVaxMain.SendDTMFCallSession(lSessionId, nTypeDTMF, nDigit);
      end;

      function TVaxTeleServerSIP.DetectDTMFCallSession( lSessionId : integer ;  nTypeDTMF : integer ; bEnable : boolean;  nTimeout : integer ) : boolean;
      begin
            Result := m_objVaxMain.DetectDTMFCallSession(lSessionId, nTypeDTMF, bEnable, nTimeout);
      end;

      function TVaxTeleServerSIP.GetVaxObjectError() : integer;
      begin
            Result := m_objVaxMain.GetVaxObjectError();
      end;

      function TVaxTeleServerSIP.DialToneToCallSession( bEnable : boolean;  lSessionId : integer ;  lWaveId : integer ) : boolean;
      begin
            Result := m_objVaxMain.DialToneToCallSession(bEnable, lSessionId, lWaveId);
      end;

      function TVaxTeleServerSIP.DiagnosticLogSIP( bInbound : boolean;  bOutbound : boolean) : boolean;
      begin
            Result := m_objVaxMain.DiagnosticLogSIP(bInbound, bOutbound);
      end;

      function TVaxTeleServerSIP.GetUserCount() : Integer;
      begin
            Result := m_objVaxUser.GetUserCount();
      end;

      function TVaxTeleServerSIP.GetCallCount() : Integer;
      begin
            Result := m_objVaxCallSession.GetCallCount();
      end;

      function TVaxTeleServerSIP.GetAvailableMEM() : Integer;
      var MemStatus: TMemoryStatusEx;
      begin
            FillChar(MemStatus, sizeof(MemStatus), 0);
            MemStatus.dwLength := sizeof(TMemoryStatusEx);

            Win32Check(GlobalMemoryStatusEx(MemStatus));
            Result := MemStatus.ullAvailPhys div ( 1024 * 1024);
      end;

      function TVaxTeleServerSIP.GetUsageCPU() : Integer;
      var
        time, createTime, exitTime : FILETIME;
        idleTimeProcess, kernelTimeProcess, userTimeProcess : FILETIME;
        sTime, sLastUpTime : Long;
        sLastCpu, sLastCpuProcess : Integer;

        idleTime, kernelTime, userTime : Long;
        usr, ker, idl, sys, cpu : Long;
      begin

//            GetSystemTimeAsFileTime(&time);
//            if(sTime = 0) then
//            begin
//
//                GetProcessTimes(GetCurrentProcess(), &createTime, &exitTime, &kernelTimeProcess, &userTimeProcess);
//
//            end;
//
//            idleTime    := 0;
//            kernelTime  := 0;
//            userTime    := 0;
//
//            if( GetSystemTimes(&idleTimeProcess, &kernelTimeProcess, &userTimeProcess) = False) then
//            begin
//
////              EnterCriticalSection();
//
////              usr := userTime   - s_userTime;
////              ker := kernelTime - s_kernelTime;
////              idl := idleTime   - s_idleTime;
//
//                usr := 0;
//                ker := 0;
//                sys := (usr + ker);
//
//                if(sys = 0) then
//                begin
//                    cpu := 0;
//                end
//                else if(sys <> 0) then
//                begin
//                    cpu := Trunc( (sys - idl) * 100 / sys);
//                end;
//            end;

            Result := 0;
      end;

      function TVaxTeleServerSIP.LoadMusicDialTone(sFileName : string) : Boolean;
      begin

            Result := m_objVaxCallSession.LoadDialTonMusic(sFileName);
      end;

      procedure TVaxTeleServerSIP.UnLoadMusicDialTone();
      begin

            m_objVaxCallSession.UnLoadDialToneMusic();
      end;

      procedure TVaxTeleServerSIP.OnStatusLog(sStatus : string);
      begin
            m_objStatusLogDlg.OnStatusLog(sStatus);
      end;

      procedure TVaxTeleServerSIP.OnErrorLog(sError : string);
      begin
            m_objErrorLogDlg.OnErrorLog(sError);
      end;

end.
