unit VaxUser;

interface

uses

    System.Classes,
    VaxTeleServerSIP,
    VaxServerRoot,
    VaxServerConstants,
    VaxUserList;



type TVaxUser = class(TVaxServerRoot)

    private
        m_objVaxUserList : TVaxUserList;
        nCount, m_lUserCount : integer;

    public
        m_objVaxServer : TVaxTeleServerSIP;

    public

        procedure OnUnRegisterUser( sUserLogin : string); override;
        procedure OnRegisterUser( sUserLogin : string;  sDomain : string;  sFromIP : string; nFromPort : integer); override;
        procedure OnRegisterUserSuccess( sUserLogin : string); override;
        procedure OnRegisterUserFail( sUserLogin : string); override;

    public

        constructor Create();

        procedure ResetOBJ();

        function GetUserCount() : Integer;

        procedure SetUserRegister(sLogin : string; bRegister : boolean);

        function IsUserExist(sLogin : string) : boolean;
        function IsUserBlocked(sLogin : string) : boolean;

        function AddUser(sLogin, sPassword, sCodecList : string; bBlocked : boolean; sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : boolean;
        procedure RemoveUser(sLogin : string);

        procedure GetUserAll(var objLoginList : TStringList);
        function GetUserDetails(sLogin : string; var sPassword, sCodecList : string; var bBlocked : boolean; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : boolean;

end;

implementation

        //////////////////////////////////////////////////////////////////////////
        /////////////       Events
        //////////////////////////////////////////////////////////////////////////

        procedure TVaxUser.OnUnRegisterUser( sUserLogin : string);
        begin
            m_objVaxServer.OnUnRegisterUser(sUserLogin);
        end;

        procedure TVaxUser.OnRegisterUser( sUserLogin : string;  sDomain : string;  sFromIP : string; nFromPort : integer);
        begin
            m_objVaxServer.OnRegisterUser(sUserLogin, sDomain, sFromIP, nFromPort);
        end;

        procedure TVaxUser.OnRegisterUserSuccess( sUserLogin : string);
        var bResult : Boolean;
        begin
            m_objVaxServer.OnRegisterUserSuccess(sUserLogin);
        end;

        procedure TVaxUser.OnRegisterUserFail( sUserLogin : string);
        begin
            m_objVaxServer.OnRegisterUserFail(sUserLogin);
        end;


        //////////////////////////////////////////////////////////////////////////
        /////////////       Functions
        //////////////////////////////////////////////////////////////////////////

        constructor TVaxUser.Create();
        begin
            inherited;
            inherited AddRef(TVaxServerConstants.ID_CLASS_USER_SIP);

            m_objVaxUserList := TVaxUserList.Create();
        end;

        procedure TVaxUser.ResetOBJ();
        begin
            m_objVaxUserList.ResetOBJ();
        end;

        function TVaxUser.GetUserCount() : Integer;
        begin
            Result :=  m_lUserCount;
        end;

        procedure TVaxUser.SetUserRegister(sLogin : string; bRegister : boolean);
        begin

            if(bRegister = True) then
            begin

                  if(m_objVaxUserList.IsRegistered(sLogin) = True) then
                      Exit;

                  m_objVaxUserList.SetRegister(sLogin, True);
                  m_lUserCount := m_lUserCount + 1;

            end;

            if(bRegister = False) then
            begin
                  m_objVaxUserList.SetRegister(sLogin, False);
                  m_lUserCount := m_lUserCount - 1;
            end;

        end;

        function TVaxUser.IsUserExist(sLogin : string) : boolean;
        begin
            Result := m_objVaxUserList.IsUserExist(sLogin);
        end;

        function TVaxUser.IsUserBlocked(sLogin : string) : boolean;
        begin
            Result := m_objVaxUserList.IsUserBlocked(sLogin);
        end;

        function TVaxUser.AddUser(sLogin, sPassword, sCodecList : string; bBlocked : boolean; sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : boolean;

        var
            bResult : Boolean;

        begin

            bResult := True;

            m_objVaxUserList.AddUser(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

            if(inherited AddUser(sLogin, sPassword, sCodecList) = False) then
                bResult := False;

            Result := bResult;
        end;

        procedure TVaxUser.RemoveUser(sLogin : string);
        begin

            inherited RemoveUser(sLogin);
            m_objVaxUserList.DeleteUser(sLogin);
        end;

        procedure TVaxUser.GetUserAll(var objLoginList : TStringList);
        begin
            m_objVaxUserList.GetUserAll(objLoginList);
        end;

        function TVaxUser.GetUserDetails(sLogin : string; var sPassword, sCodecList : string; var bBlocked : boolean; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : boolean;
        begin
            Result := m_objVaxUserList.GetUserDetails(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
        end;

end.
