unit VaxUserList;

interface

uses
    System.SysUtils,
    System.Classes,
    Generics.Collections;

type TVaxUserDetails = class

  public
        m_sLogin, m_sPassword, m_sCodecList : string;
        m_sUserPrefix, m_sDialPrefix, m_sToPeerName : string;
        m_bBlocked, m_bIsRegistered : Boolean;
        m_nToPeerType : Integer;


end;

type TVaxUserList = class

var
        m_objUserList : TObjectDictionary<string, TVaxUserDetails>;

      private

        function GenKey(sValue : string) : string;
        procedure DeleteUserAll();

        function FindUser(sLogin : string) : TVaxUserDetails;

      public

        constructor Create();
        Destructor Destroy();

        procedure ResetOBJ();

        procedure SetRegister(sLogin : string; bRegister : boolean);
        function IsRegistered(sLogin : string) : boolean;

        function IsUserExist(sLogin : string) : boolean;
        function IsUserBlocked(sLogin : string) : boolean;

        function AddUser(sLogin, sPassword, sCodecList : string; bBlocked : boolean; sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : boolean;
        procedure DeleteUser(sLogin : string);

        procedure GetUserAll(var objLoginList : TStringList);
        function GetUserDetails(sLogin : string; var sPassword, sCodecList : string; var bBlocked : boolean; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : boolean;


end;


implementation

        constructor TVaxUserList.Create();
        begin
            m_objUserList := TObjectDictionary<string, TVaxUserDetails>.Create([doOwnsValues], 256);
        end;

        Destructor TVaxUserList.Destroy();
        begin
            DeleteUserAll();
            m_objUserList.Free;
        end;

        function TVaxUserList.GenKey(sValue : string) : string;
        begin
            Result := AnsiLowerCase(sValue);
        end;

        procedure TVaxUserList.DeleteUserAll();
        begin
            m_objUserList.Clear;
        end;

        function TVaxUserList.FindUser(sLogin : string) : TVaxUserDetails;
        var
            objUserDetails : TVaxUserDetails;
            bResult : Boolean;
        begin
            objUserDetails := Nil;

            bResult := m_objUserList.TryGetValue(sLogin, objUserDetails);
            if(bResult = False) then
                Exit(nil);

            Result := objUserDetails;
        end;

        procedure TVaxUserList.ResetOBJ();
        begin
            DeleteUserAll();
        end;

        procedure TVaxUserList.SetRegister(sLogin : string; bRegister : boolean);
        var
            objUserDetails : TVaxUserDetails;
        begin
            objUserDetails := Nil;

            objUserDetails := FindUser(sLogin);
            if(objUserDetails = nil) then Exit;

            objUserDetails.m_bIsRegistered := bRegister;

            // Reference of object. No need to call following function
            //m_objUserList.AddOrSetValue(AnsiLowerCase(sLogin), objUserDetails);
        end;

        function TVaxUserList.IsRegistered(sLogin : string) : boolean;
        var
            objUserDetails : TVaxUserDetails;
        begin
            objUserDetails := FindUser(sLogin);
            if(objUserDetails = nil) then
                Exit(False);

            Result := objUserDetails.m_bIsRegistered;
        end;

        function TVaxUserList.IsUserExist(sLogin : string) : boolean;
        var
            objUserDetails : TVaxUserDetails;
            bResult : Boolean;
        begin

            bResult := m_objUserList.TryGetValue(AnsiLowerCase(sLogin), objUserDetails);
            if(bResult = False) then Exit(False);

            Exit(True);
        end;

        function TVaxUserList.IsUserBlocked(sLogin : string) : boolean;
        var
            objUserDetails : TVaxUserDetails;
        begin
            objUserDetails := FindUser(sLogin);
            if(objUserDetails = nil) then Exit(False);

            Result := objUserDetails.m_bBlocked;
        end;

        function TVaxUserList.AddUser(sLogin, sPassword, sCodecList : string; bBlocked : boolean; sUserPrefix, sDialPrefix : string; nToPeerType : Integer; sToPeerName : string) : boolean;

        var
            sKey : string;
            objUser : TVaxUserDetails;

        begin

            if(IsUserExist(sLogin) = True) then
                Exit(False);

            objUser := TVaxUserDetails.Create();

            objUser.m_sLogin := sLogin;
            objUser.m_sPassword := sPassword;
            objUser.m_sCodecList := sCodecList;
            objUser.m_bBlocked := bBlocked;

            objUser.m_sUserPrefix := sUserPrefix;
            objUser.m_sDialPrefix := sDialPrefix;

            objUser.m_nToPeerType := nToPeerType;
            objUser.m_sToPeerName := sToPeerName;

            sKey := GenKey(sLogin);
            m_objUserList.Add(sKey, objUser);

            Exit(True);

        end;

        procedure TVaxUserList.DeleteUser(sLogin : string);
        var
            objUserDetails : TVaxUserDetails;
        begin

            objUserDetails := FindUser(AnsiLowerCase(sLogin));
            if(objUserDetails = nil) then Exit;

            m_objUserList.Remove(AnsiLowerCase(sLogin));

        end;

        procedure TVaxUserList.GetUserAll(var objLoginList : TStringList);
        var
            objUserDetails : TVaxUserDetails;
            nIndex : Integer;
        begin

            if(m_objUserList.Count <= 0) then
                Exit;

            for objUserDetails in m_objUserList.Values do
            begin
                objLoginList.Add(objUserDetails.m_sLogin);
            end;
        end;

        function TVaxUserList.GetUserDetails(sLogin : string; var sPassword, sCodecList : string; var bBlocked : boolean; var sUserPrefix, sDialPrefix : string; var nToPeerType : Integer; var sToPeerName : string) : boolean;
        var
            objUserDetails : TVaxUserDetails;
        begin

            objUserDetails := FindUser(sLogin);
            if(objUserDetails = nil) then
                Exit(False);

            sPassword := objUserDetails.m_sPassword;
            sCodecList := objUserDetails.m_sCodecList;
            bBlocked := objUserDetails.m_bBlocked;

            sUserPrefix := objUserDetails.m_sUserPrefix;
            sDialPrefix := objUserDetails.m_sDialPrefix;

            nToPeerType := objUserDetails.m_nToPeerType;
            sToPeerName := objUserDetails.m_sToPeerName;

            Result := True;

        end;


end.
