﻿
''' <summary>
''' User Route Details
''' </summary>

Class CUserRouteDetails

    Public m_sUserPrefix As String = "", m_sToPeerName As String = "", m_sDialPrefix As String = ""
    Public m_nToPeerType As Integer = -1

End Class

''' <summary>
''' Line Route Details
''' </summary>
Class CLineRouteDetails

    Public m_sLineName As String = "", m_sRoomName As String = "", m_sToPeerName As String = ""
    Public m_nToPeerType As Integer = -1
    Public m_bRejected As Boolean = False

End Class

''' <summary>
''' DirectProxy Route Details
''' </summary>
Class CDirectProxyRouteDetails

    Public m_sProxyName As String = "", m_sRoomName As String = "", m_sToPeerName As String = ""
    Public m_nToPeerType As Integer = -1
    Public m_bRejected As Boolean = False

End Class



Public Class CVaxCallSessionRoute

    Private m_objMapUserRouteToPtr As Hashtable
    Private m_objMapLineRouteToPtr As Hashtable
    Private m_objMapDirectProxyRouteToPtr As Hashtable

    Public Sub New()

        m_objMapUserRouteToPtr = New Hashtable(256)
        m_objMapLineRouteToPtr = New Hashtable(256)
        m_objMapDirectProxyRouteToPtr = New Hashtable(256)

    End Sub

    Protected Overrides Sub Finalize()

        DeleteAllUserRoutes()
        DeleteAllLineRoutes()
        DeleteAllProxyRoutes()

    End Sub

    Private Sub DeleteAllUserRoutes()

        m_objMapUserRouteToPtr.Clear()

    End Sub

    Private Sub DeleteAllLineRoutes()

        m_objMapLineRouteToPtr.Clear()

    End Sub

    Private Sub DeleteAllProxyRoutes()

        m_objMapDirectProxyRouteToPtr.Clear()

    End Sub

    Private Function FindUserRoute(ByVal sUserLogin As String) As CUserRouteDetails
        Return CType(m_objMapUserRouteToPtr(sUserLogin.ToLower()), CUserRouteDetails)
    End Function

    Private Function FindLineRoute(ByVal sLineName As String) As CLineRouteDetails
        Return CType(m_objMapLineRouteToPtr(sLineName.ToLower()), CLineRouteDetails)
    End Function

    Private Function FindDirectProxyRoute(ByVal sProxyName As String) As CDirectProxyRouteDetails
        Return CType(m_objMapDirectProxyRouteToPtr(sProxyName.ToLower()), CDirectProxyRouteDetails)
    End Function

    Private Function GetUserRouteDetails(ByVal sUserName As String, ByRef sUserPrefix As String, ByRef sDialPrefix As String, ByRef nToPeerType As Integer, ByRef sToPeerName As String) As Boolean

        Dim objUserRoute As CUserRouteDetails = FindUserRoute(sUserName)
        If (objUserRoute Is Nothing) Then Return False

        sUserPrefix = objUserRoute.m_sUserPrefix
        sDialPrefix = objUserRoute.m_sDialPrefix

        nToPeerType = objUserRoute.m_nToPeerType
        sToPeerName = objUserRoute.m_sToPeerName

        Return True

    End Function

    Private Function GetLineRouteDetails(ByVal sLineName As String, ByRef nToPeerType As Integer, ByRef sToPeerName As String, ByRef bRejected As Boolean, ByRef sRoomName As String) As Boolean

        Dim objLineRoute As CLineRouteDetails = FindLineRoute(sLineName)
        If (objLineRoute Is Nothing) Then Return False

        nToPeerType = objLineRoute.m_nToPeerType
        sToPeerName = objLineRoute.m_sToPeerName

        bRejected = objLineRoute.m_bRejected
        sRoomName = objLineRoute.m_sRoomName

        Return True

    End Function

    Private Function GetDirectProxyRouteDetails(ByVal sProxyName As String, ByRef nToPeerType As Integer, ByRef sToPeerName As String, ByRef bRejected As Boolean, ByRef sRoomName As String) As Boolean

        Dim objProxyRoute As CDirectProxyRouteDetails = FindDirectProxyRoute(sProxyName)
        If (objProxyRoute Is Nothing) Then Return False

        nToPeerType = objProxyRoute.m_nToPeerType
        sToPeerName = objProxyRoute.m_sToPeerName

        bRejected = objProxyRoute.m_bRejected
        sRoomName = objProxyRoute.m_sRoomName

        Return True

    End Function

    Public Sub ResetOBJ()
        DeleteAllUserRoutes()
        DeleteAllLineRoutes()
        DeleteAllProxyRoutes()
    End Sub

    Public Function AddUserRoute(ByVal sUserName As String, ByVal sUserPrefix As String, ByVal sDialPrefix As String, ByVal nToPeerType As Integer, ByVal sToPeerName As String) As Boolean

        Dim objUserRoute As CUserRouteDetails = FindUserRoute(sUserName)
        If (objUserRoute Is Nothing) Then

            objUserRoute = New CUserRouteDetails()

            objUserRoute.m_sUserPrefix = sUserPrefix
            objUserRoute.m_sDialPrefix = sDialPrefix

            objUserRoute.m_nToPeerType = nToPeerType
            objUserRoute.m_sToPeerName = sToPeerName

            m_objMapUserRouteToPtr.Add(sUserName.ToLower(), objUserRoute)

            Return True
        End If

        objUserRoute.m_sUserPrefix = sUserPrefix
        objUserRoute.m_sDialPrefix = sDialPrefix

        objUserRoute.m_nToPeerType = nToPeerType
        objUserRoute.m_sToPeerName = sToPeerName

        m_objMapUserRouteToPtr(sUserName.ToLower()) = objUserRoute

        Return True

    End Function

    Public Sub RemoveUserRoute(ByVal sUserName As String)

        Dim objUserRoute As CUserRouteDetails = FindUserRoute(sUserName)
        If (objUserRoute Is Nothing) Then Return

        m_objMapUserRouteToPtr.Remove(sUserName.ToLower())
        objUserRoute = Nothing

    End Sub

    Public Function AddLineRoute(ByVal sLineName As String, ByVal nToPeerType As Integer, ByVal sToPeerName As String, ByVal bRejected As Boolean, ByVal sRoomName As String) As Boolean


        Dim objLineRoute As CLineRouteDetails = FindLineRoute(sLineName)
        If (objLineRoute Is Nothing) Then

            objLineRoute = New CLineRouteDetails()

            objLineRoute.m_nToPeerType = nToPeerType
            objLineRoute.m_sToPeerName = sToPeerName

            objLineRoute.m_bRejected = bRejected
            objLineRoute.m_sRoomName = sRoomName

            m_objMapLineRouteToPtr.Add(sLineName.ToLower(), objLineRoute)

            Return True

        End If

        objLineRoute.m_nToPeerType = nToPeerType
        objLineRoute.m_sToPeerName = sToPeerName

        objLineRoute.m_bRejected = bRejected
        objLineRoute.m_sRoomName = sRoomName

        m_objMapLineRouteToPtr(sLineName.ToLower()) = objLineRoute

        Return True

    End Function

    Public Sub RemoveLineRoute(ByVal sLineName As String)

        Dim objLineRoute As CLineRouteDetails = FindLineRoute(sLineName)
        If (objLineRoute Is Nothing) Then Return

        m_objMapLineRouteToPtr.Remove(sLineName.ToLower())
        objLineRoute = Nothing

    End Sub

    Public Function AddDirectProxyRoute(ByVal sProxyName As String, ByVal nToPeerType As Integer, ByVal sToPeerName As String, ByVal bRejected As Boolean, ByVal sRoomName As String) As Boolean

        Dim objProxyRoute As CDirectProxyRouteDetails = FindDirectProxyRoute(sProxyName)
        If (objProxyRoute Is Nothing) Then

            objProxyRoute = New CDirectProxyRouteDetails()

            objProxyRoute.m_nToPeerType = nToPeerType
            objProxyRoute.m_sToPeerName = sToPeerName

            objProxyRoute.m_bRejected = bRejected
            objProxyRoute.m_sRoomName = sRoomName

            m_objMapDirectProxyRouteToPtr.Add(sProxyName.ToLower(), objProxyRoute)

            Return True
        End If

        objProxyRoute.m_nToPeerType = nToPeerType
        objProxyRoute.m_sToPeerName = sToPeerName

        objProxyRoute.m_bRejected = bRejected
        objProxyRoute.m_sRoomName = sRoomName

        m_objMapDirectProxyRouteToPtr(sProxyName.ToLower()) = objProxyRoute

        Return True

    End Function

    Public Sub RemoveDirectProxyRoute(ByVal sProxyName As String)

        Dim objProxyRoute As CDirectProxyRouteDetails = FindDirectProxyRoute(sProxyName)
        If (objProxyRoute Is Nothing) Then Return

        m_objMapDirectProxyRouteToPtr.Remove(sProxyName.ToLower())
        objProxyRoute = Nothing

    End Sub

    Public Function OnCallFromUser(ByVal sUserName As String, ByVal sUserDialedNo As String, ByRef sDialNo As String, ByRef nToPeerType As Integer, ByRef sToPeerName As String) As Boolean

        Dim sUserPrefix As String = "", sDialPrefix As String = ""

        Dim bResult As Boolean = GetUserRouteDetails(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName)

        ' USER-ROUTE not found. Make it U2U call.

        If (Not bResult Or nToPeerType = -1 Or sToPeerName.Equals("")) Then

            sDialNo = sUserDialedNo
            nToPeerType = CVaxServerExCOM.VAX_PEER_TYPE_USER
            sToPeerName = sUserDialedNo

            Return True

        End If

        Dim nUserPrefixLength As Integer = sUserPrefix.Length

        ' check if first 'N' charachters are equal to sUserPrefix. If YES; Modify it according to dialplan. Callee is on other server.

        If (sUserDialedNo.Substring(0, nUserPrefixLength) = sUserPrefix) Then

            Dim sCallTo As String = sUserDialedNo.Remove(0, nUserPrefixLength)
            sDialNo = sDialPrefix + sCallTo
        Else
            'Make it U2U call.

            sDialNo = sUserDialedNo
            nToPeerType = CVaxServerExCOM.VAX_PEER_TYPE_USER
            sToPeerName = sUserDialedNo

        End If

        Return True

    End Function

    Public Function OnCallFromLine(ByVal sLineName As String, ByRef nToPeerType As Integer, ByRef sToPeerName As String, ByRef bRejected As Boolean, ByRef sRoomName As String) As Boolean

        Dim bResult As Boolean = GetLineRouteDetails(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName)
        If (Not bResult) Then Return False

        Return True

    End Function

    Public Function OnCallFromDirectProxySIP(ByVal sProxyName As String, ByRef nToPeerType As Integer, ByRef sToPeerName As String, ByRef bRejected As Boolean, ByRef sRoomName As String) As Boolean

        Dim bResult As Boolean = GetDirectProxyRouteDetails(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName)
        If (Not bResult) Then Return False

        Return True

    End Function



End Class
