// AddLoginDlg.cpp : implementation file
//

#include "stdafx.h"
#include "VaxTeleServerApp.h"
#include "VaxTeleServerAppDlg.h"
#include "AddLoginDlg.h"
#include "Codec.h"
#include "VaxServerSIP.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif



/////////////////////////////////////////////////////////////////////////////
// CAddLoginDlg dialog


CAddLoginDlg::CAddLoginDlg(CVaxServerSIP* pVaxTeleSIP) : CPropertyPage(CAddLoginDlg::IDD)
	, m_sCallPrefix(_T(""))
	, m_sDialPrefix(_T(""))
{
	//{{AFX_DATA_INIT(CAddLoginDlg)
	m_sPasswordSIP = _T("");
	m_bAccountBlocked = FALSE;
	m_sLoginSIP = _T("");
	//}}AFX_DATA_INIT

	m_psp.dwFlags &= ~PSP_HASHELP;  // Lose the Help button

	m_pVaxTeleSIP = pVaxTeleSIP;
}


void CAddLoginDlg::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CAddLoginDlg)
	DDX_Control(pDX, IDC_COMBO_LOGIN, m_ctrlComboLogin);
	DDX_Control(pDX, IDC_LIST_ENABLE_CODEC, m_ctrlEnableCodecList);
	DDX_Control(pDX, IDC_LIST_DISABLE_CODEC, m_ctrlDisableCodecList);
	DDX_Text(pDX, IDC_EDIT_PWD_SIP, m_sPasswordSIP);
	DDX_Check(pDX, IDC_CHECK_BLOCK_ACCOUNT, m_bAccountBlocked);
	DDX_CBString(pDX, IDC_COMBO_LOGIN, m_sLoginSIP);
	//}}AFX_DATA_MAP
	DDX_Text(pDX, IDC_EDIT_DIAL_PLAN_DIAL_PREFIX, m_sDialPrefix);
	DDX_Text(pDX, IDC_EDIT_DIAL_PLAN_USER_PREFIX, m_sCallPrefix);
	DDX_Control(pDX, IDC_COMBO_DIAL_PLAN_LINES, m_comboLineNames);
}


BEGIN_MESSAGE_MAP(CAddLoginDlg, CPropertyPage)
	//{{AFX_MSG_MAP(CAddLoginDlg)
	ON_BN_CLICKED(IDC_BUTTON_LOGIN_ADD, OnButtonLoginAdd)
	ON_BN_CLICKED(IDC_BUTTON_REMOVE_LOGIN, OnButtonRemoveLogin)
	ON_BN_CLICKED(IDC_BUTTON_ENABLE_CODEC, OnButtonEnableCodec)
	ON_BN_CLICKED(IDC_BUTTON_DISABLE_CODEC, OnButtonDisableCodec)
	ON_CBN_SELCHANGE(IDC_COMBO_LOGIN, OnSelchangeComboLogin)
	ON_BN_CLICKED(IDC_BUTTON_CLEAR, OnButtonClear)
	ON_BN_CLICKED(IDC_BUTTON_LOGIN_HELP, OnButtonLoginHelp)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CAddLoginDlg message handlers

BOOL CAddLoginDlg::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	
	m_ctrlComboLogin.SetWindowPos(NULL, 0, 0, 160, 150, SWP_NOMOVE|SWP_NOZORDER);
	
	LoadCodecs();

	return TRUE;  // return TRUE unless you set the focus to a control
}

void CAddLoginDlg::OnButtonLoginAdd() 
{
	UpdateData();

	if(!AddLoginChecks())
		return;
		
	if(m_ctrlComboLogin.FindStringExact(0, m_sLoginSIP) != -1)
	{
		MessageBox("Login already exists.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return;
	}

	CCodec objCodec;
	CString sCodecList;
	
	for(int nCount = 0; nCount < m_ctrlEnableCodecList.GetCount(); nCount++)
	{
		CString sCodecText;
		m_ctrlEnableCodecList.GetText(nCount, sCodecText);

		sCodecList += objCodec.GetCodecNo(sCodecText);
	}
	
	BOOL bUpdated = FALSE;
	
	CString sToPeerName;
	DWORD dwRouteType = VAX_PEER_TYPE_USER;

	if(m_comboLineNames.GetCount() >= 1)
	{
		m_comboLineNames.GetLBText(m_comboLineNames.GetCurSel(), sToPeerName);
		dwRouteType = m_comboLineNames.GetItemData(m_comboLineNames.GetCurSel());
	}

	if(!m_pVaxTeleSIP->AddUser(m_sLoginSIP, m_sPasswordSIP, sCodecList, m_bAccountBlocked, m_sCallPrefix, m_sDialPrefix, (int)dwRouteType, sToPeerName))
	{
		MessageBox("User could't be added.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return;
	}

	m_ctrlComboLogin.AddString(m_sLoginSIP);
	MessageBox("Login created successfully", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
}

void CAddLoginDlg::OnButtonRemoveLogin() 
{
	UpdateData();
	
	if(m_sLoginSIP.IsEmpty())
	{
		MessageBox("Please enter login.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return;
	}

	m_pVaxTeleSIP->RemoveUser(m_sLoginSIP);

	int nIndex = m_ctrlComboLogin.FindStringExact(0, m_sLoginSIP);
		
	if(nIndex != -1)
		m_ctrlComboLogin.DeleteString(nIndex);

	MessageBox("Login removed successfully!", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
	ClearDlgContent();

}

void CAddLoginDlg::OnButtonEnableCodec() 
{
	int nCurSel = m_ctrlDisableCodecList.GetCurSel();
	if(nCurSel == -1) return;

	CString sCurSelText;
	
	m_ctrlDisableCodecList.GetText(nCurSel, sCurSelText);
	m_ctrlDisableCodecList.DeleteString(nCurSel);
	
	m_ctrlEnableCodecList.AddString(sCurSelText);
}

void CAddLoginDlg::OnButtonDisableCodec() 
{
	int nCurSel = m_ctrlEnableCodecList.GetCurSel();
	if(nCurSel == -1) return;

	CString sCurSelText;
	m_ctrlEnableCodecList.GetText(nCurSel, sCurSelText);
	m_ctrlEnableCodecList.DeleteString(nCurSel);
	
	m_ctrlDisableCodecList.AddString(sCurSelText);
}

BOOL CAddLoginDlg::AddLoginChecks()
{
	if(m_sLoginSIP.IsEmpty())
	{
		MessageBox("Please enter login.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}

	CString sDigits = "0123456789";
	for(int nIndex = 0; nIndex < m_sLoginSIP.GetLength(); nIndex++)
	{
		if(sDigits.Find(m_sLoginSIP.GetAt(nIndex)) == -1)
		{
			MessageBox("Login should contain only numerals 0 through 9.\n\nFor example: 12 or 324323 or 800122 or 2109756 etc.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
			return FALSE;
		}
	}
		
	if(m_sPasswordSIP.IsEmpty())
	{
		MessageBox("Please enter login password.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}
		
	if(m_sLoginSIP.GetLength() > 20 || m_sPasswordSIP.GetLength() > 20)
	{
		MessageBox("Login and password size should not be more 20.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}

	if(m_sLoginSIP.Left(2) == "00")
	{
		MessageBox("Please donot enter 00 as login prefix. 00 prefix is use to prepare dial plan.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}

	if(m_ctrlEnableCodecList.GetCount() == 0)
	{
		MessageBox("Please select a codec.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}

	return TRUE;
}

void CAddLoginDlg::ClearDlgContent()
{
	m_ctrlEnableCodecList.ResetContent();
	m_ctrlDisableCodecList.ResetContent();

	m_ctrlEnableCodecList.AddString(G711U_TEXT);
	m_ctrlEnableCodecList.AddString(G711A_TEXT);
	m_ctrlEnableCodecList.AddString(ILBC_TEXT);
	m_ctrlEnableCodecList.AddString(G610_TEXT);
	m_ctrlEnableCodecList.AddString(G729_TEXT);

	m_sLoginSIP    = "";
	m_sPasswordSIP = "";
		
	m_bAccountBlocked = FALSE;

	UpdateData(FALSE);
}

void CAddLoginDlg::OnSelchangeComboLogin() 
{
	int nCurIndex = m_ctrlComboLogin.GetCurSel();
	if(nCurIndex == -1) return;

	m_ctrlComboLogin.GetLBText(nCurIndex, m_sLoginSIP);

	UpdateData(FALSE);
		
	CString sConnectName, sPassword, sUserPrefix ;
	CString sDialPrefix, sCodecList, sExtNo, sToPeerName;
	int nToPeerType; BOOL bBlock;
	
	m_pVaxTeleSIP->GetUserDetails(m_sLoginSIP, sPassword, sCodecList, bBlock, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);	
	UpdateDlgContent(m_sLoginSIP, sPassword, sCodecList, sDialPrefix, sUserPrefix, sToPeerName, bBlock);
}

void CAddLoginDlg::UpdateDlgContent(LPCTSTR sLogin, LPCTSTR sPassword, CString sCodecList, LPCTSTR sDialPrefix, LPCTSTR sUserPrefix, LPCTSTR sToPeerName, BOOL bBlock)
{
	UpdateData();

	if(m_sLoginSIP != sLogin) return;

	m_sPasswordSIP = sPassword;

	CCodec objCodec;
	
	m_ctrlEnableCodecList.ResetContent();
	m_ctrlDisableCodecList.ResetContent();

	for(char cCodec = '0'; cCodec < TOTAL_NO_CODEC; cCodec++)	
		m_ctrlDisableCodecList.AddString(objCodec.GetCodecName(cCodec));
	
	for(int nCount = 0; nCount < sCodecList.GetLength(); nCount++)
	{
		CString sCodecName = objCodec.GetCodecName(sCodecList.GetAt(nCount));
		m_ctrlEnableCodecList.AddString(sCodecName);
		
		int nIndex = m_ctrlDisableCodecList.FindStringExact(0, sCodecName);
		if(nIndex == -1) continue;
		
		m_ctrlDisableCodecList.DeleteString(nIndex);
	}

	m_sCallPrefix = sUserPrefix;
	m_sDialPrefix = sDialPrefix;
	
	int nIndex = m_comboLineNames.FindStringExact(0, sToPeerName);
	
	if( nIndex != -1)
		m_comboLineNames.SetCurSel(nIndex);

	m_bAccountBlocked  = bBlock;

	UpdateData(FALSE);
}

void CAddLoginDlg::OnButtonClear() 
{
	ClearDlgContent();
}

void CAddLoginDlg::OnButtonLoginHelp() 
{
	
}

void CAddLoginDlg::LoadCodecs()
{
	CCodec objCodec;
	
	m_ctrlEnableCodecList.ResetContent();
	m_ctrlDisableCodecList.ResetContent();

	for(char cCodec = '0'; cCodec < TOTAL_NO_CODEC; cCodec++)	
		m_ctrlEnableCodecList.AddString(objCodec.GetCodecName(cCodec));
}

void CAddLoginDlg::ShowUsers()
{
	// Get and show Login list in the combo box

 	m_ctrlComboLogin.ResetContent();

	CStringList objListUsers;
	m_pVaxTeleSIP->GetUserAll(&objListUsers);

	if(objListUsers.GetCount() <= 0) return;

	for(int nCount = 0; nCount < objListUsers.GetCount(); nCount++)
	{
		CString objLogin = objListUsers.GetAt(objListUsers.FindIndex(nCount));
		m_ctrlComboLogin.AddString(objLogin);
	}

	// Select the first login and fill up the form with its data

	m_ctrlComboLogin.SetCurSel(0);
	m_ctrlComboLogin.GetLBText(0, m_sLoginSIP);

	CString sConnectName, sPassword, sUserPrefix ;
	CString sDialPrefix, sCodecList, sToPeerName;
	int nToPeerType;
	BOOL bBlock;
	
	m_pVaxTeleSIP->GetUserDetails(m_sLoginSIP, sPassword, sCodecList, bBlock, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
	UpdateDlgContent(m_sLoginSIP, sPassword, sCodecList, sDialPrefix, sUserPrefix, sToPeerName, bBlock);
}

void CAddLoginDlg::ShowLines()
{
	CStringList objLineList;
	m_pVaxTeleSIP->GetLineAll(&objLineList);
	
	if(objLineList.GetCount() <= 0) return;

	CComboBox* comboLines = (CComboBox*)GetDlgItem(IDC_COMBO_DIAL_PLAN_LINES);
	comboLines->ResetContent();

	int nIndex = -1;
	CString sLineName;

	while(!objLineList.IsEmpty())
	{
		sLineName = objLineList.RemoveHead();
		nIndex = comboLines->AddString(sLineName);
		comboLines->SetItemData(nIndex, VAX_PEER_TYPE_LINE);
	}

	comboLines->SetCurSel(0);
}

void CAddLoginDlg::ShowDirectProxies()
{
	CStringList objProxyList;
	m_pVaxTeleSIP->GetDirectProxyAll(&objProxyList);
	
	if(objProxyList.GetCount() <= 0) return;

	CComboBox* pComboProxy = (CComboBox*)GetDlgItem(IDC_COMBO_DIAL_PLAN_LINES);

	int nIndex = -1;
	CString sProxyName;

	while(!objProxyList.IsEmpty())
	{
		sProxyName = objProxyList.RemoveHead();
		nIndex = pComboProxy->AddString(sProxyName);
		pComboProxy->SetItemData(nIndex, VAX_PEER_TYPE_DIRECT_PROXY);
	}

	pComboProxy->SetCurSel(0);
}

BOOL CAddLoginDlg::OnSetActive()
{
	ShowUsers();
	ShowLines();
	ShowDirectProxies();

	return CPropertyPage::OnSetActive();
}
