// GeneralDlg.cpp : implementation file
//

#include "stdafx.h"
#include "VaxTeleServerApp.h"
#include "VaxTeleServerAppDlg.h"
#include "GeneralDlg.h"
#include "VaxServerSIP.h"
#include "CPU.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

#define IDC_STATS_TIMER	9005

/////////////////////////////////////////////////////////////////////////////
// CGeneralDlg dialog


CGeneralDlg::CGeneralDlg(CVaxServerSIP* pVaxTeleSIP) : CPropertyPage(CGeneralDlg::IDD)
{
	//{{AFX_DATA_INIT(CGeneralDlg)
	
	m_objHoldPlayWave = _T("Hold.wav");
	m_objDialTonePlayWave = _T("DialTone.wav");
	
	m_objListenIP = _T("");
	m_sServerStatus = _T("");

	m_nListenPort = 5060;

	//}}AFX_DATA_INIT

	m_psp.dwFlags &= ~PSP_HASHELP;  // Lose the Help button

	m_pVaxTeleSIP = pVaxTeleSIP;

}


void CGeneralDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CGeneralDlg)
	DDX_Text(pDX, IDC_EDIT_SIP_SERVER_HOLD_MUSIC, m_objHoldPlayWave);
	DDX_Text(pDX, IDC_EDIT_SIP_SERVER_DIAL_TONE_MUSIC, m_objDialTonePlayWave);
	DDX_Text(pDX, IDC_EDIT_SIP_SERVER_LISTEN_IP, m_objListenIP);
	DDX_Text(pDX, IDC_EDIT_SIP_SERVER_LISTEN_PORT, m_nListenPort);
	DDX_Text(pDX, IDC_STATIC_SERVER_STATUS, m_sServerStatus);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CGeneralDlg, CPropertyPage)
	//{{AFX_MSG_MAP(CGeneralDlg)
	ON_BN_CLICKED(IDC_BUTTON_SERVER_START, OnButtonServerStart)
	ON_BN_CLICKED(IDC_BUTTON_SERVER_STOP, OnButtonServerStop)
	ON_WM_TIMER()
	//}}AFX_MSG_MAP
	ON_WM_DESTROY()
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CGeneralDlg message handlers


BOOL CGeneralDlg::OnSetActive() 
{
	//MessageBox("GeneralDlg - OnSetActivePage", "", MB_OK);

	return CPropertyPage::OnSetActive();
}

BOOL CGeneralDlg::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	
	UpdateStats();
	
	SetTimer(IDC_STATS_TIMER, 2000, NULL);
		
	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

void CGeneralDlg::OnButtonServerStart() 
{
	UpdateData();

	m_pVaxTeleSIP->UnInitialize();

	m_pVaxTeleSIP->SetLicenseKey("TRIAL-LICENSE-KEY");
	BOOL bResult = m_pVaxTeleSIP->Initialize(m_objListenIP, m_objListenIP, m_nListenPort, m_objListenIP, -1);
	
	if(!bResult)
	{
		m_sServerStatus = "Server Not Started";
		UpdateData(FALSE);

		return;
	}

	m_sServerStatus = "Server Started.";
	
	m_pVaxTeleSIP->LoadMusicHold(m_objHoldPlayWave);
	m_pVaxTeleSIP->LoadDialToneMusic(m_objDialTonePlayWave);

	m_pVaxTeleSIP->VoiceSessionLost(TRUE, 30);
	m_pVaxTeleSIP->VideoCOMM(TRUE); // Enable Video Communication.
	
	
	AddUserLogins();
	
	UpdateData(FALSE);
}

void CGeneralDlg::AddUserLogins()
{
	for(int nCount = 4040; nCount < 4050; nCount++)
	{
		CString sLogin;
		sLogin.Format("%d", nCount);

		m_pVaxTeleSIP->AddUser(sLogin, sLogin, "32014", FALSE, "", "", VAX_PEER_TYPE_USER, "");
	}
}

void CGeneralDlg::OnButtonServerStop() 
{
	m_pVaxTeleSIP->UnLoadMusicHold();
	m_pVaxTeleSIP->UnLoadDialToneMusic();

	m_pVaxTeleSIP->UnInitialize();

	m_sServerStatus = "Server Stopped.";
	UpdateData(FALSE);
}

void CGeneralDlg::OnTimer(UINT_PTR nIDEvent) 
{
	UpdateStats();
	CPropertyPage::OnTimer(nIDEvent);
}

void CGeneralDlg::UpdateStats()
{
	CString sCount;
	CWnd* pWnd;
	
	sCount.Format("%d", m_pVaxTeleSIP->GetCallCount());
	pWnd = GetDlgItem(IDC_STATIC_TOTAL_CALLS);
	if(pWnd) pWnd->SetWindowText(sCount);
	
	sCount.Format("%d", m_pVaxTeleSIP->GetRegisteredUserCount());
	pWnd = GetDlgItem(IDC_STATIC_TOTAL_USERS);
	if(pWnd) pWnd->SetWindowText(sCount);
	
	sCount.Format("%d", GetUsageCPU());
	pWnd = GetDlgItem(IDC_STATIC_USAGE_CPU);
	if(pWnd) pWnd->SetWindowText(sCount);
	
	sCount.Format("%d MB", GetAvailableMEM());
	pWnd = GetDlgItem(IDC_STATIC_AVAIL_MEME);
	if(pWnd) pWnd->SetWindowText(sCount);
}

void CGeneralDlg::ClearStats()
{
	CWnd* pWnd;
	
	pWnd = GetDlgItem(IDC_STATIC_TOTAL_CALLS);
	pWnd->SetWindowTextA("0");

	pWnd = GetDlgItem(IDC_STATIC_TOTAL_USERS);
	pWnd->SetWindowTextA("0");
}

void CGeneralDlg::OnDestroy()
{
	CPropertyPage::OnDestroy();
}

DWORD CGeneralDlg::GetAvailableMEM()
{
	MEMORYSTATUSEX statex;
	statex.dwLength = sizeof (statex);

	GlobalMemoryStatusEx (&statex);	// memory retrieved in bytes

	return (DWORD) statex.ullAvailPhys / (1024 * 1024);	// return in the form of mega bytes.
}

long CGeneralDlg::GetUsageCPU()
{
	CPU objCPU;
	return objCPU.GetUsageCPU();
}