#include "StdAfx.h"
#include "VaxCallSession.h"
#include "VaxServerExCOM.h"

CVaxCallSession::CVaxCallSession(CVaxServerExCOM* pServerExCOM)
{
	m_pServerExCOM = pServerExCOM;
}

CVaxCallSession::~CVaxCallSession()
{

}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

void CVaxCallSession::OnCallSessionOpen(LONG lSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, CString sRoomName, LONG lFromPeerType, LPCTSTR sFromPeerName, LONG lToPeerType, LPCTSTR sToPeerName, LPCTSTR sFromIP, LONG lFromPort)
{
	m_sRoomName = sRoomName;

	//////////////////////////////////////////////////////////////////////

	if(!sRoomName.IsEmpty())
	{
		AcceptCallSession(lSessionId, "", "", "", -1, ""); // Accept the incoming call and add to conference room in OnCallSessionConnected()
		return;
	}
	
	//////////////////////////////////////////////////////////////////////

	if(lToPeerType == VAX_PEER_TYPE_LINE)
	{
		sCallerName = "";
		sCallerId   = "";

		// Let AcceptCallSession() use DisplayName & UserName values of LINE as CallerName & CallerId.
	}

	//////////////////////////////////////////////////////////////////////
		
	if(!AcceptCallSession(lSessionId, sCallerName, sCallerId, sDialNo, lToPeerType, sToPeerName))
		return;
	
	m_pServerExCOM->DialToneToCallSession(TRUE, lSessionId);
}

void CVaxCallSession::OnCallSessionConnected(LONG lSessionId)
{
	if(!m_sRoomName.IsEmpty())
	{
		m_pServerExCOM->AddCallSessionToConferenceRoom(m_sRoomName, lSessionId, CONF_ROOM_NORMAL_LISTENER);
		return;
	}
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

void CVaxCallSession::OnCallSessionOnHold(LONG lSessionId, LONG lCallType)
{
	if(!m_sRoomName.IsEmpty())
		return;
		
	m_pServerExCOM->AcceptOnHoldRequest(lSessionId);
}

void CVaxCallSession::OnCallSessionOffHold(LONG lSessionId, LONG lCallType)
{
	if(!m_sRoomName.IsEmpty())
		return;
	
	m_pServerExCOM->AcceptOffHoldRequest(lSessionId);
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

void CVaxCallSession::OnCallSessionTransferBlind(LONG lTransfererSessionId, LONG lTransfererCallType, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo)
{
	if(!m_sRoomName.IsEmpty())
	{
		m_pServerExCOM->RejectTransfer(lTransfererSessionId);
		return;
	}
	
	m_pServerExCOM->AcceptTransferBlind(lTransfererSessionId, sTransferee, sTransferee, sTransferTo, VAX_PEER_TYPE_USER, sTransferTo, 30);
}

void CVaxCallSession::OnCallSessionTransferConsult(LONG lTransfererSessionId, LONG lTransfereeSessionId, LONG lTransferToSessionId, LONG lTransfererCallType, LONG lTransfereeCallType, LONG lTransferToCallType, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo)
{
	if(!m_sRoomName.IsEmpty())
	{
		m_pServerExCOM->RejectTransfer(lTransfererSessionId);
		return;
	}
	
	m_pServerExCOM->AcceptTransferConsult(lTransfererSessionId, lTransferToSessionId);
}

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

BOOL CVaxCallSession::AcceptCallSession(LONG lSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, int nToPeerType, LPCTSTR sToPeerName)
{
	BOOL bResult = m_pServerExCOM->AcceptCallSession(lSessionId, sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName, 30);
	
	if(bResult == FALSE) 
	{	
		m_pServerExCOM->RejectCallSession(lSessionId, 404, "Not Found");
		return bResult;
	}
		
	return bResult;
}

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

void CVaxCallSession::OnDetectedDigitDTMF(LONG lSessionId, LONG lCallType, LPCTSTR sDigitDTMF)
{
	
}