#pragma once
#include "afxwin.h"

///////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////

#define VAX_CREATED_REASON_CODE_INCOMING_CALL	1001
#define VAX_CREATED_REASON_CODE_OUTGOING_CALL	1002
#define VAX_CREATED_REASON_CODE_MERGED			1003
#define VAX_CREATED_REASON_CODE_TRANSFERED		1004

#define VAX_CLOSED_REASON_CODE_HANGUP			2001
#define VAX_CLOSED_REASON_CODE_SESSION_LOST		2002
#define VAX_CLOSED_REASON_CODE_MERGED			2003
#define VAX_CLOSED_REASON_CODE_TRANSFERED		2004
#define VAX_CLOSED_REASON_CODE_REJECTED			2005
#define VAX_CLOSED_REASON_CODE_FAILED			2006
#define VAX_CLOSED_REASON_CODE_CANCELLED		2007
#define VAX_CLOSED_REASON_CODE_TIMEOUT			2008
#define VAX_CLOSED_REASON_CODE_CLOSED			2009

//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////

#define CONF_ROOM_NORMAL_LISTENER				100
#define CONF_ROOM_STEALTH_LISTENER				101
#define CONF_ROOM_STEALTH_SPEAKER				102

#define VAX_CALL_TYPE_FROM						201
#define VAX_CALL_TYPE_TO						202

#define VAX_CUSTOM_HEADER_REQ_ID_INVITE			0

#define VAX_PEER_TYPE_USER						3001
#define VAX_PEER_TYPE_LINE						3002
#define VAX_PEER_TYPE_DIRECT_PROXY				3003

#define DTMF_TYPE_RFC2833						0
#define DTMF_TYPE_INBAND						1
#define DTMF_TYPE_INFO							2

#define VAX_TRANSFER_TYPE_BLIND					401
#define VAX_TRANSFER_TYPE_CONSULT				402

#define VAX_CODEC_GSM610						0
#define VAX_CODEC_ILBC							1
#define VAX_CODEC_G711A							2
#define VAX_CODEC_G711U							3
#define VAX_CODEC_G729							4

///////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////

#if WIN64
#import "..\VaxTele Component (COM)\x64 (64Bit)\VaxTeleServerCOM.dll" rename_namespace("VaxTeleServer")
#else
#import "..\VaxTele Component (COM)\x86 (32Bit)\VaxTeleServerCOM.dll" rename_namespace("VaxTeleServer")
#endif

using namespace VaxTeleServer;

class CVaxServerCOM : public CCmdTarget
{
	DECLARE_DYNCREATE(CVaxServerCOM)

public:
	CVaxServerCOM();
	~CVaxServerCOM();

public:

	DWORD m_dwCookie;
	
	_IVaxServerSIPEvents* m_pVaxEvents;
	IVaxServerSIP* m_pVaxSIP;

	//------------------------------------------------------------------------------------------------------------------
	//-------------------------------			Functions Added
	//------------------------------------------------------------------------------------------------------------------
	
	BOOL LoadObjectCOM();
	void UnLoadObjectCOM();
	BOOL IsLoadedObjectCOM();

	void SetLicenseKey(LPCTSTR sLicenseKey);
	
	BOOL Initialize(LPCTSTR sDomainName, LPCTSTR sSIPListenIP, UINT nSIPListenPort, LPCTSTR sRTPListenIP, UINT nRTPListenPort);
	void UnInitialize();
		
	BOOL AddUser(LPCTSTR sUserName, LPCTSTR sPassword, LPCTSTR sCodecList);
	void RemoveUser(LPCTSTR sUserName);
	BOOL RegisterUserExpiry(int nExpiry);

	BOOL AcceptRegister(LPCTSTR sUserName);
	BOOL RejectRegister(LPCTSTR sUserName, LONG lStatusCode, LPCTSTR sReasonPhrase);
	BOOL AuthRegister(LPCTSTR sUserName);

	BOOL AddLine(LPCTSTR sLineName, LPCTSTR sDisplayName, LPCTSTR sUserName, LPCTSTR sAuthUser, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxySIP, LPCTSTR sOutboundProxySIP, LPCTSTR sCodecList);
	void RemoveLine(LPCTSTR sLineName);
	BOOL RegisterLine(LPCTSTR sLineName, int nExpire);
	BOOL UnRegisterLine(LPCTSTR sLineName);

	BOOL AddDirectProxySIP(LPCTSTR sProxyName, LPCTSTR sAuthLogin, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxyIP, LONG lProxyPort, LPCTSTR sCodecList);
	void RemoveDirectProxySIP(LPCTSTR sProxyName);

	BOOL AcceptCallSession(LONG lSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, int nToPeerType, LPCTSTR sToPeerName, LONG lTimeout); // Seconds.
	BOOL RejectCallSession(LONG lSessionId, LONG lStatusCode, LPCTSTR sReasonPhrase);
	BOOL CloseCallSession(LONG lSessionId);
		
	LONG OpenCallSession(LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, int nToPeerType, LPCTSTR sToPeerName, LONG lTimeout);  // Seconds.

	LONG AcceptTransferBlind(LONG lTransfererSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sTransferTo, int nToPeerType, LPCTSTR sToPeerName, LONG lTimeout); // Seconds
	LONG AcceptTransferConsult(LONG lTransfererSessionId, LONG lTransferToSessionId);
	void RejectTransfer(LONG lSessionId);

	BOOL PlayWaveStartToCallSession(LONG lSessionId, LONG lWaveId, BOOL bLoop);
	BOOL PlayWaveStopToCallSession(LONG lSessionId);

	BOOL RecordWaveStartToCallSession(LONG lSessionId, LPCTSTR sFileName);
	BOOL RecordWaveStopToCallSession(LONG lSessionId);
	BOOL RecordWavePauseToCallSession(LONG lSessionId, BOOL bEnable);

	LONG LoadWaveFile(LPCTSTR sFileName);
	LONG LoadWavePCM(char* pDataPCM, DWORD dwSizePCM);
	void UnLoadWaveFile(LONG lWaveId);

	BOOL LoadMusicHold(LPCTSTR sFileName);
	void UnLoadMusicHold();

	BOOL AcceptOnHoldRequest(LONG lSessionId);
	BOOL AcceptOffHoldRequest(LONG lSessionId);

	BOOL AcceptChatMessage(LONG lChatMsgId, int nToPeerType, LPCTSTR sToPeerName);
	void RejectChatMessage(LONG lChatMsgId, LONG lStatusCode, LPCTSTR sReasonPhrase);

	BOOL AcceptChatStatusSubscribe(LONG lSubscrbId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, int nToPeerType, LPCTSTR sToPeerName);
	void RejectChatStatusSubscribe(LONG lSubscrbId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo);

	BOOL OpenConferenceRoom(LPCTSTR sRoomName);
	void CloseConferenceRoom(LPCTSTR sRoomName);

	BOOL AddCallSessionToConferenceRoom(LPCTSTR sRoomName, LONG lSessionId, int nType);
	BOOL RemoveCallSessionFromConferenceRoom(LONG lSessionId);

	BOOL PlayWaveStartToConferenceRoom(LPCTSTR sRoomName, LONG lWaveId, BOOL bLoop);
	BOOL PlayWaveStopToConferenceRoom(LPCTSTR sRoomName);

	BOOL RecordWaveStartToConferenceRoom(LPCTSTR sRoomName, LPCTSTR sFileName);
	BOOL RecordWaveStopToConferenceRoom(LPCTSTR sRoomName);
	BOOL RecordWavePauseToConferenceRoom(LPCTSTR sRoomName, BOOL bEnable);
		
	BOOL VoiceSessionLost(BOOL bEnable, LONG lTimeout); // Seconds.
	
	LONG SendInfoVM(LPCTSTR sUserLogin, int nNewMsgCount, int nOldMsgCount, BOOL bMsgWaiting);
	
	BOOL StartVaxTeleTick(LONG lTickId, LONG lElapse);  // milli-seconds.
	BOOL StopVaxTeleTick(LONG lTickId);

	BOOL SetUserAgentName(LPCTSTR sName);
	CString GetUserAgentName();
	
	BOOL SetSessionNameSDP(LPCTSTR sName);
	CString GetSessionNameSDP();

	BOOL SendDTMFCallSession(LONG lSessionId, int nTypeDTMF, int nDigit);
	BOOL DetectDigitDTMF(LONG lSessionId, int nCallType, int nTypeDTMF, BOOL bEnable, int nMilliSecTimeout);
		
	LONG GetVaxObjectError();

	BOOL DialToneToCallSession(BOOL bEnable, LONG lSessionId, LONG lWaveId);
	BOOL DiagnosticLogSIP(BOOL bInbound, BOOL bOutbound);

	BOOL CallSessionSwapCalls(LONG lSessionId);
	LONG MergeCallSession(LONG lFromSessionId, LONG lToSessionId);
	BOOL CallSessionSendStatusResponse(LONG lSessionId, LONG lStatusCode, LPCTSTR sReasonPhrase);
	
	BOOL CallSessionDetectAMD(LONG lSessionId, LONG lCallType, BOOL bEnable, int nAnalysisTime, int nSilenceTime, int nSilenceCount);

	BOOL AddCustomHeader(int nReqId, LPCTSTR sName, LPCTSTR sValue);
	BOOL RemoveCustomHeader(int nReqId, LPCTSTR sName);
	BOOL RemoveCustomHeaderAll(int nReqId);

	BOOL AddListenIP(LPCTSTR sSIPListenIP, LPCTSTR sRTPListenIP);

	LONG GetCallSessionTxCodec(LONG lSessionId, LONG lCallType);
	LONG GetCallSessionRxCodec(LONG lSessionId, LONG lCallType);

	BOOL BusyLampSubscribeAccept(LONG lSubScrbId, BOOL bAuthenticate, int nExpires);
	BOOL BusyLampSubscribeReject(LONG lSubScrbId, int nStatusCode, LPCTSTR sReasonPhrase);

public:

	BOOL SetCallSessionData(LONG lSessionId, HANDLE hCustomData);
	HANDLE GetCallSessionData(LONG lSessionId);
		
	BOOL SetUserData(LPCTSTR sUserName, HANDLE hCustomData);
	HANDLE GetUserData(LPCTSTR sUserName);

	BOOL SetLineData(LPCTSTR sLineName, HANDLE hCustomData);
	HANDLE GetLineData(LPCTSTR sLineName);

	BOOL SetDirectProxyData(LPCTSTR sProxyName, HANDLE hCustomData);
	HANDLE GetDirectProxyData(LPCTSTR sProxyName);

	BOOL SetConferenceRoomData(LPCTSTR sRoomName, HANDLE hCustomData);
	HANDLE GetConferenceRoomData(LPCTSTR sRoomName);

public:

	BOOL TrvsUserStart();
	CString TrvsUserNext();

	BOOL TrvsLineStart();
	CString TrvsLineNext();

	BOOL TrvsDirectProxyStart();
	CString TrvsDirectProxyNext();

	BOOL TrvsCallSessionStart();
	LONG TrvsCallSessionNext();

	BOOL TrvsConferenceRoomStart();
	CString TrvsConferenceRoomNext();

public:

	LONG GetUserCount();
	LONG GetLineCount();
	LONG GetDirectProxyCount();
	LONG GetCallSessionCount();
	LONG GetConferenceRoomCount();

public:

	LONG CustomListOpen(int nTableSize);
	BOOL CustomListClose(LONG lListId);
	
	BOOL CustomListAddData(LONG lListId, LPCTSTR sKey, HANDLE hData);
	BOOL CustomListRemoveData(LONG lListId, LPCTSTR sKey);
	HANDLE CustomListFindData(LONG lListId, LPCTSTR sKey);

	LONG CustomListCount(LONG lListId);
	BOOL CustomListReset(LONG lListId);

	BOOL CustomListTrvsStart(LONG lListId);
	HANDLE CustomListTrvsNext(LONG lListId);

public:

	CString GetCallSessionHeaderCallId(LONG lSessionId, LONG lCallType);
	BOOL SetListenPortRangeRTP(LONG lListenStartPort, LONG lListenEndPort);

	BOOL CallSessionMuteVoice(LONG lSessionId, LONG lCallType, BOOL bListen, BOOL bSpeak);
	BOOL VideoCOMM(BOOL bEnable);

public:


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CVaxServerCOM)
	public:
	afx_msg afx_msg virtual void OnFinalRelease();
	//}}AFX_VIRTUAL

// Implementation
public:
	
	// Generated message map functions
	//{{AFX_MSG(CVaxServerCOM)
		// NOTE - the ClassWizard will add and remove member functions here.
	//}}AFX_MSG

	//afx_msg void OnClientUnRegister(LPCTSTR sUserLogin);
	//	afx_msg void OnClientRegister(LPCTSTR sUserLogin, LONG lRegId);

	DECLARE_MESSAGE_MAP()
	// Generated OLE dispatch map functions
	//{{AFX_DISPATCH(CVaxServerCOM)

	afx_msg virtual void OnRegisterUser(LPCTSTR sUserLogin, LPCTSTR sDomain, LPCTSTR sFromIP, LONG lFromPort);
	afx_msg virtual void OnRegisterUserSuccess(LPCTSTR sUserLogin);
	afx_msg virtual void OnRegisterUserFailed(LPCTSTR sUserLogin);
	afx_msg virtual void OnUnRegisterUser(LPCTSTR sUserLogin);
		
	afx_msg virtual void OnCallSessionOpen(LONG lSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, LONG lFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG lFromPort);
	afx_msg virtual void OnCallSessionConnecting(LONG lSessionId, LONG lCallType, LONG lStatusCode, LPCTSTR sReasonPhrase);
	afx_msg virtual void OnCallSessionFailed(LONG lSessionId, LONG lCallType, LONG lStatusCode, LPCTSTR sReasonPhrase);
	afx_msg virtual void OnCallSessionConnected(LONG lSessionId);
	
	afx_msg virtual void OnCallSessionLost(LONG lSessionId, LONG lCallType);
	afx_msg virtual void OnCallSessionHangup(LONG lSessionId, LONG lCallType);
	afx_msg virtual void OnCallSessionTimeout(LONG lSessionId, LONG lCallType);
	afx_msg virtual void OnCallSessionCancelled(LONG lSessionId);

	afx_msg virtual void OnCallSessionOnHold(LONG lSessionId, LONG lCallType);
	afx_msg virtual void OnCallSessionOffHold(LONG lSessionId, LONG lCallType);

	afx_msg virtual void OnCallSessionTransferBlind(LONG lTransfererSessionId, LONG lTransfererCallType, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo);
	afx_msg virtual void OnCallSessionTransferConsult(LONG lTransfererSessionId, LONG lTransfereeSessionId, LONG lTransferToSessionId, LONG lTransfererCallType, LONG lTransfereeCallType, LONG lTransferToCallType, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo);

	afx_msg virtual void OnCallSessionTransfering(LONG lSessionId, LONG lTransferType, LONG lCallType, LONG lStatusCode, LPCTSTR sReasonPhrase);
	afx_msg virtual void OnCallSessionTransferFailed(LONG lSessionId, LONG lTransferType, LONG lCallType, LONG lStatusCode, LPCTSTR sReasonPhrase);
	afx_msg virtual void OnCallSessionTransferTimeout(LONG lSessionId, LONG lTransferType, LONG lCallType);
	afx_msg virtual void OnCallSessionTransfered(LONG lSessionId, LONG lTransferType);

	afx_msg virtual void OnLineRegisterTrying(LPCTSTR sLineName);
	afx_msg virtual void OnLineRegisterFailed(LPCTSTR sLineName, LONG lStatusCode, LPCTSTR sReasonPhrase);
	afx_msg virtual void OnLineRegisterSuccess(LPCTSTR sLineName);

	afx_msg virtual void OnLineUnRegisterTrying(LPCTSTR sLineName);
	afx_msg virtual void OnLineUnRegisterFailed(LPCTSTR sLineName, LONG lStatusCode, LPCTSTR sReasonPhrase);
	afx_msg virtual void OnLineUnRegisterSuccess(LPCTSTR sLineName);
		
	afx_msg virtual void OnChatMessageText(LONG lChatMsgId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LPCTSTR sMsgText, LONG lFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG lFromPort);
	afx_msg virtual void OnChatMessageTyping(LONG lChatMsgId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, BOOL IsTypingStart, LONG lFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG lFromPort);
	afx_msg virtual void OnChatStatusSubscribe(LONG lSubscrbId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LONG lFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG lFromPort);

	afx_msg virtual void OnChatMessageSuccess(LONG lChatMsgId);
	afx_msg virtual void OnChatMessageFailed(LONG lChatMsgId, LONG lStatusId, LPCTSTR sReasonPhrase);
	afx_msg virtual void OnChatMessageTimeout(LONG lChatMsgId);

	afx_msg virtual void OnOutgoingDiagnosticLog(LPCTSTR sMsgSIP, LPCTSTR sToIP, LONG lToPort);
	afx_msg virtual void OnIncomingDiagnosticLog(LPCTSTR sMsgSIP, LPCTSTR sFromIP, LONG lFromPort);

	afx_msg virtual void OnDetectedDigitDTMF(LONG lSessionId, LONG lCallType, LPCTSTR sDigitDTMF);
	afx_msg virtual void OnVaxTeleTick(LONG lTickId);

	afx_msg virtual void OnSendTimeoutVM(LONG lMsgIdVM);
	afx_msg virtual void OnSendSuccessVM(LONG lMsgIdVM);

	afx_msg virtual void OnCallSessionDialToneStart(LONG lSessionId, LONG lWaveId);
	afx_msg virtual void OnCallSessionDialToneStop(LONG lSessionId, LONG lWaveId);

	afx_msg virtual void OnCallSessionPlayWaveDone(LONG lSessionId, LONG lWaveId);
	afx_msg virtual void OnConferenceRoomPlayWaveDone(LPCTSTR sRoomName, LONG lWaveId);

	afx_msg virtual void OnCallSessionCreated(LONG lSessionId, LONG lReasonCode);
	afx_msg virtual void OnCallSessionClosed(LONG lSessionId, LONG lCallType, LONG lReasonCode);

	afx_msg virtual void OnCallSessionOpenCall(LONG lSessionId, LONG lCallType, LONG lPeerType, LPCTSTR sPeerName);
	afx_msg virtual void OnCallSessionCloseCall(LONG lSessionId, LONG lCallType, LONG lPeerType, LPCTSTR sPeerName);

	afx_msg virtual void OnCallSessionDetectedAMD(LONG lSessionId, LONG lCallType, BOOL bIsHuman);
	
	afx_msg virtual void OnCallSessionRecordedPCM(LONG lSessionId, LONGLONG nDataPCM, LONG lSizePCM, LONG lTypePCM);
	afx_msg virtual void OnConferenceRoomRecordedPCM(LPCTSTR sRoomName, LONGLONG nDataPCM, LONG lSizePCM, LONG lTypePCM);	
	
	afx_msg virtual void OnBusyLampSubscribe(LONG lSubScrbId, LPCTSTR sUserName, LPCTSTR sToUserName, LPCTSTR sFromIP, UINT nFromPort);
	afx_msg virtual void OnBusyLampUnSubscribe(LONG lSubScrbId, LPCTSTR sUserName, LPCTSTR sToUserName, LPCTSTR sFromIP, UINT nFromPort);
	afx_msg virtual void OnBusyLampSubscribeSuccess(LONG lSubScrbId, LPCTSTR sUserName);
	afx_msg virtual void OnBusyLampSubscribeFailed(LONG lSubScrbId, LPCTSTR sUserName);

	afx_msg virtual void OnVaxErrorLog(LPCTSTR sFuncName, DWORD dwErrorCode, LPCTSTR sErrorMsg);
						
	//}}AFX_DISPATCH
	DECLARE_DISPATCH_MAP()
	DECLARE_INTERFACE_MAP()

};

