#include "StdAfx.h"
#include "Define.h"
#include "VaxServerExCOM.h"
#include "ConfRoom.h"
#include "VaxCallSession.h"
#include "VaxUser.h"
#include "VaxChat.h"
#include "VaxLine.h"
#include "VaxDirectProxy.h"
#include "VaxCallSessionRoute.h"

CVaxServerExCOM::CVaxServerExCOM()
{
	m_lDialToneId = -1;

	m_nTotalCallCount = 0;
	m_nRegisterUserCount = 0;

	CVaxServerCOM::LoadObjectCOM();
	if(!CVaxServerCOM::IsLoadedObjectCOM()) return;

	m_pConfRoom = new CConfRoom(this);
	m_pChat = new CVaxChat(this);
	m_pRouteCallSIP = new CVaxCallSessionRoute(this);
}

CVaxServerExCOM::~CVaxServerExCOM()
{
	UnInitialize();

	delete m_pConfRoom;
	delete m_pChat;
	delete m_pRouteCallSIP;

	CVaxServerCOM::UnLoadObjectCOM();
}

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::SetLicenseKey(LPCTSTR sLicenseKey)
{
	m_sLicenseKey = sLicenseKey;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::Initialize(LPCTSTR sDomainRealm, LPCTSTR sSIPListenIP, UINT nSIPListenPort, LPCTSTR sRTPListenIP, UINT nRTPListenPort)
{
	if(!CVaxServerCOM::IsLoadedObjectCOM())	
	{
		return FALSE;
	}
	
	CVaxServerCOM::SetLicenseKey(m_sLicenseKey);
	return CVaxServerCOM::Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sRTPListenIP, nRTPListenPort);
}

void CVaxServerExCOM::UnInitialize()
{
	m_nTotalCallCount = 0;
	m_nRegisterUserCount = 0;

	m_pConfRoom->DeleteRoomAll();
	m_pRouteCallSIP->ResetOBJ();

	DeleteCallSessionDataAll();
	DeleteUserDataAll();
	
	CVaxServerCOM::UnInitialize();
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddUser(LPCTSTR sUserName, LPCTSTR sPassword, LPCTSTR sCodecList, BOOL bBlocked, LPCTSTR sUserPrefix, LPCTSTR sDialPrefix, int nToPeerType, LPCTSTR sToPeerName)
{
	if(!CVaxServerCOM::IsLoadedObjectCOM())
		return FALSE;
	
	if(!CVaxServerCOM::AddUser(sUserName, sPassword, sCodecList))	
	{
		return FALSE;
	}

	CVaxUser* pUser = new CVaxUser(this);
	CVaxServerCOM::SetUserData(sUserName, (HANDLE) pUser);

	pUser->SetData(sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
	return TRUE;
}

void CVaxServerExCOM::RemoveUser(LPCTSTR sUserName)
{
	if(!CVaxServerCOM::IsLoadedObjectCOM())
		return;
	
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserName);
	delete pUser;
	
	CVaxServerCOM::RemoveUser(sUserName);
}

void CVaxServerExCOM::GetUserAll(CStringList* pLoginList)
{
	CVaxServerCOM::TrvsUserStart();

	while(TRUE)
	{
		CString sUserName = CVaxServerCOM::TrvsUserNext();
		if(sUserName.IsEmpty()) break;

		pLoginList->AddTail(sUserName);
	}
}

BOOL CVaxServerExCOM::GetUserDetails(LPCTSTR sUserName, CString& sPassword, CString& sCodecList, BOOL& bBlocked, CString& sUserPrefix, CString& sDialPrefix, int& nToPeerType, CString& sToPeerName)
{
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserName);
	
	if(pUser == NULL) 
		return FALSE;

	pUser->GetData(sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

	return TRUE;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddLine(LPCTSTR sLineName, LPCTSTR sDisplayName, LPCTSTR sUserName, LPCTSTR sAuthUser, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxySIP, LPCTSTR sCodecList, BOOL bRegister, int nToPeerType, LPCTSTR sToPeerName, BOOL bBlock, LPCTSTR sRoomName)
{
	if(!CVaxServerCOM::IsLoadedObjectCOM())
		return FALSE;
		
	BOOL bResult = CVaxServerCOM::AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, "", sCodecList);
	if(!bResult)
	{
		return FALSE;
	}

	CVaxLine* pLine = new CVaxLine(this);
	
	CVaxServerCOM::SetLineData(sLineName, (HANDLE) pLine);
	pLine->SetData(sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlock, sRoomName);

	if(bRegister)
		CVaxServerCOM::RegisterLine(sLineName, 1800);

	return TRUE;
}

void CVaxServerExCOM::RemoveLine(LPCTSTR sLineName)
{
	if(!CVaxServerCOM::IsLoadedObjectCOM())
		return;
	
	CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
	delete pLine;

	CVaxServerCOM::RemoveLine(sLineName);
}

void CVaxServerExCOM::GetLineAll(CStringList* pLineList)
{
	CVaxServerCOM::TrvsLineStart();

	while(TRUE)
	{
		CString sLineName = CVaxServerCOM::TrvsLineNext();
		if(sLineName.IsEmpty()) break;

		pLineList->AddTail(sLineName);
	}
}

BOOL CVaxServerExCOM::GetLineDetails(LPCTSTR sLineName, CString& sDisplayName, CString& sUserName, CString& sAuthUser, CString& sAuthPwd, CString& sDomainRealm, CString& sProxySIP, CString& sCodecList, BOOL& bRegister, int& nToPeerType, CString& sToPeerName, BOOL& bBlocked, CString& sRoomName)
{
	CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
	if(pLine == NULL) return FALSE;

	pLine->GetData(sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlocked, sRoomName);

	return TRUE;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddDirectProxySIP(LPCTSTR sProxyName, LPCTSTR sAuthLogin, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxyIP, LONG lProxyPort, LPCTSTR sCodecList, int nToPeerType, LPCTSTR sToPeerName, BOOL bBlocked, LPCTSTR sRoomName)
{
	if(!CVaxServerCOM::IsLoadedObjectCOM())
		return FALSE;
		
	BOOL bResult = CVaxServerCOM::AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList);
	if(!bResult)
	{
		return FALSE;
	}

	CVaxDirectProxy* pDirectProxy = new CVaxDirectProxy(this);
	CVaxServerCOM::SetDirectProxyData(sProxyName, (HANDLE) pDirectProxy);

	pDirectProxy->SetData(sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList, nToPeerType, sToPeerName, bBlocked, sRoomName);
	
	return TRUE;
}
void CVaxServerExCOM::RemoveDirectProxySIP(LPCTSTR sProxyName)
{
	if(!CVaxServerCOM::IsLoadedObjectCOM())
		return;
	
	CVaxDirectProxy* pDirectProxy = (CVaxDirectProxy*) CVaxServerCOM::GetDirectProxyData(sProxyName);
	delete pDirectProxy;

	CVaxServerCOM::RemoveDirectProxySIP(sProxyName);
}

BOOL CVaxServerExCOM::GetDirectProxyAll(CStringList* pDirectProxyList)
{
	CVaxServerCOM::TrvsDirectProxyStart();

	while(TRUE)
	{
		CString sLineName = CVaxServerCOM::TrvsDirectProxyNext();
		if(sLineName.IsEmpty()) break;

		pDirectProxyList->AddTail(sLineName);
	}

	return TRUE;
}

BOOL CVaxServerExCOM::GetDirectProxyDetails(LPCTSTR sProxyName, CString& sAuthLogin, CString& sAuthPwd, CString& sDomainRealm, CString& sProxyIP, LONG& lProxyPort, CString& sCodecList, int& nToPeerType, CString& sToPeerName, BOOL& bBlocked, CString& sRoomName)
{
	CVaxDirectProxy* pDirectProxy = (CVaxDirectProxy*) CVaxServerCOM::GetDirectProxyData(sProxyName);
	if(pDirectProxy == NULL) return FALSE;

	pDirectProxy->GetData(sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList, nToPeerType, sToPeerName, bBlocked, sRoomName);
	return TRUE;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

LONG CVaxServerExCOM::GetVaxObjectError()
{
	if(!CVaxServerCOM::IsLoadedObjectCOM())
		return 0;
	
	return CVaxServerCOM::GetVaxObjectError();
}

BOOL CVaxServerExCOM::DialToneToCallSession(BOOL bEnable, LONG lSessionId)
{
	if(!CVaxServerCOM::IsLoadedObjectCOM())
		return FALSE;

	if(m_lDialToneId == -1)
		return TRUE;
	
	return CVaxServerCOM::DialToneToCallSession(bEnable, lSessionId, m_lDialToneId);
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddRoom(LPCTSTR sRoomName, LPCTSTR sRoomNo)
{
	return m_pConfRoom->AddRoom(sRoomName, sRoomNo);
}

void CVaxServerExCOM::RemoveRoom(LPCTSTR sRoomName)
{
	m_pConfRoom->RemoveRoom(sRoomName);
}

BOOL CVaxServerExCOM::GetRoomDetails(LPCTSTR sRoomName, CString& sRoomNo)
{
	return m_pConfRoom->GetRoomDetails(sRoomName, sRoomNo);
}

BOOL CVaxServerExCOM::GetRoomAll(CStringList* pRoomList)
{
	return m_pConfRoom->GetRoomAll(pRoomList);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::AddUserRoute(LPCTSTR sUserName, LPCTSTR sUserPrefix, LPCTSTR sDialPrefix, int nToPeerType, LPCTSTR sToPeerName)
{
	return m_pRouteCallSIP->AddUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
}

void CVaxServerExCOM::RemoveUserRoute(LPCTSTR sUserName)
{
	m_pRouteCallSIP->RemoveUserRoute(sUserName);
}

BOOL CVaxServerExCOM::AddLineRoute(LPCTSTR sLineName, int nToPeerType, LPCTSTR sToPeerName, BOOL bRejected, LPCTSTR sRoomName)
{
	return m_pRouteCallSIP->AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);
}

void CVaxServerExCOM::RemoveLineRoute(LPCTSTR sLineName)
{
	m_pRouteCallSIP->RemoveLineRoute(sLineName);
}

BOOL CVaxServerExCOM::AddDirectProxyRoute(LPCTSTR sProxyName, int nToPeerType, LPCTSTR sToPeerName, BOOL bRejected, LPCTSTR sRoomName)
{
	return m_pRouteCallSIP->AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName);
}

void CVaxServerExCOM::RemoveDirectProxyRoute(LPCTSTR sProxyName)
{
	m_pRouteCallSIP->RemoveDirectProxyRoute(sProxyName);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

BOOL CVaxServerExCOM::LoadDialToneMusic(LPCTSTR sFileName)
{
	UnLoadDialToneMusic();

	m_lDialToneId = CVaxServerCOM::LoadWaveFile(sFileName);
	return (m_lDialToneId != -1);
}

void CVaxServerExCOM::UnLoadDialToneMusic()
{
	if(m_lDialToneId != -1)
	{
		CVaxServerCOM::UnLoadWaveFile(m_lDialToneId);
		m_lDialToneId = -1;
	}
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

LONG CVaxServerExCOM::GetCallCount()
{
	return m_nTotalCallCount;
}

UINT CVaxServerExCOM::GetRegisteredUserCount()
{
	return m_nRegisterUserCount;
}

BOOL CVaxServerExCOM::IsRoomNoExist(LPCTSTR sRoomNo)
{
	return m_pConfRoom->IsRoomNoExists(sRoomNo);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::DeleteCallSessionDataAll()
{
	if(!CVaxServerCOM::TrvsCallSessionStart())
		return;

	for(int nCount = 0; nCount < CVaxServerCOM::GetCallSessionCount(); nCount++)
	{
		LONG lSessionId = CVaxServerCOM::TrvsCallSessionNext();
		if(lSessionId == -1) continue;

		CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(lSessionId);
		if(pCallSession == NULL) continue;

		delete pCallSession;
	}
}

void CVaxServerExCOM::DeleteUserDataAll()
{
	if(!CVaxServerCOM::TrvsUserStart())
		return;

	for(int nCount = 0; nCount < CVaxServerCOM::GetUserCount(); nCount++)
	{
		CString sUserName = CVaxServerCOM::TrvsUserNext();
		if(sUserName.IsEmpty()) continue;

		CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserName);
		if(pUser == NULL) continue;

		delete pUser;
	}
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnRegisterUser(LPCTSTR sUserLogin, LPCTSTR sDomain, LPCTSTR sFromIP, LONG lFromPort)
{
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserLogin);

	if(pUser == NULL)
	{
		CVaxServerCOM::RejectRegister(sUserLogin, 404, "Not Found");
		return;
	}

	pUser->OnRegisterUser(sUserLogin, sDomain, sFromIP, lFromPort);
}

void CVaxServerExCOM::OnRegisterUserSuccess(LPCTSTR sUserLogin)
{
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserLogin);

	if(!pUser->IsRegistered())
		m_nRegisterUserCount++;

	pUser->OnRegisterUserSuccess(sUserLogin);
}

void CVaxServerExCOM::OnRegisterUserFailed(LPCTSTR sUserLogin)
{
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserLogin);
	pUser->OnRegisterUserFailed(sUserLogin);
}

void CVaxServerExCOM::OnUnRegisterUser(LPCTSTR sUserLogin)
{
	CVaxUser* pUser = (CVaxUser*) CVaxServerCOM::GetUserData(sUserLogin);
	
	if(pUser->IsRegistered())
		m_nRegisterUserCount--;
	
	pUser->OnUnRegisterUser(sUserLogin);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionOpen(LONG lSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, LONG lFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG lFromPort)
{
	CString sToPeerName; CString sDialToNo; CString sRoomName;
	int nToPeerType = -1;  BOOL bRejected = FALSE;
	
	////////////////////////////////////////////////////////////////
	
	if(lFromPeerType == VAX_PEER_TYPE_USER)
	{
		if(m_pConfRoom->IsRoomNoExists(sDialNo))
			sRoomName = m_pConfRoom->GetRoomName(sDialNo);
		else
			m_pRouteCallSIP->OnCallFromUser(sFromPeerName, sDialNo, sDialToNo, nToPeerType, sToPeerName);
	}
	else if(lFromPeerType == VAX_PEER_TYPE_LINE)
	{
		m_pRouteCallSIP->OnCallFromLine(sFromPeerName, nToPeerType, sToPeerName, bRejected, sRoomName);
		sDialToNo = sToPeerName;
	}
	else if(lFromPeerType == VAX_PEER_TYPE_DIRECT_PROXY)
	{
		m_pRouteCallSIP->OnCallFromDirectProxySIP(sFromPeerName, nToPeerType, sToPeerName, bRejected, sRoomName);
		sDialToNo = sToPeerName;
	}

	//////////////////////////////////////////////////////////////////////
	
	if(bRejected)
	{
		CVaxServerCOM::RejectCallSession(lSessionId, 404, "Not Found");
		return;
	}
	
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(lSessionId);
	pCallSession->OnCallSessionOpen(lSessionId, sCallerName, sCallerId, sDialNo, sRoomName, lFromPeerType, sFromPeerName, nToPeerType, sToPeerName, sFromIP, lFromPort);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionCreated(LONG lSessionId, LONG lReasonCode)
{
	CVaxCallSession* pCallSession = new CVaxCallSession(this);
	CVaxServerCOM::SetCallSessionData(lSessionId, (HANDLE) pCallSession);
}

void CVaxServerExCOM::OnCallSessionClosed(LONG lSessionId, LONG lCallType, LONG lReasonCode)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(lSessionId);
	delete pCallSession;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionOnHold(LONG lSessionId, LONG lCallType)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(lSessionId);
	pCallSession->OnCallSessionOnHold(lSessionId, lCallType);
}

void CVaxServerExCOM::OnCallSessionOffHold(LONG lSessionId, LONG lCallType)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(lSessionId);
	pCallSession->OnCallSessionOffHold(lSessionId, lCallType);
}

///////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionTransferBlind(LONG lTransfererSessionId, LONG lTransfererCallType, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(lTransfererSessionId);
	pCallSession->OnCallSessionTransferBlind(lTransfererSessionId, lTransfererCallType, sTransferer, sTransferee, sTransferTo);
}

void CVaxServerExCOM::OnCallSessionTransferConsult(LONG lTransfererSessionId, LONG lTransfereeSessionId, LONG lTransferToSessionId, LONG lTransfererCallType, LONG lTransfereeCallType, LONG lTransferToCallType, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(lTransfererSessionId);
	pCallSession->OnCallSessionTransferConsult(lTransfererSessionId, lTransfereeSessionId, lTransferToSessionId, lTransfererCallType, lTransfereeCallType, lTransferToCallType, sTransferer, sTransferee, sTransferTo);
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnCallSessionOpenCall(LONG lSessionId, LONG lCallType, LONG lPeerType, LPCTSTR sPeerName)
{
	m_nTotalCallCount++;
}

void CVaxServerExCOM::OnCallSessionCloseCall(LONG lSessionId, LONG lCallType, LONG lPeerType, LPCTSTR sPeerName)
{
	m_nTotalCallCount--;
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////
	
void CVaxServerExCOM::OnChatMessageText(LONG lChatMsgId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LPCTSTR sMsgText, LONG lFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG lFromPort)
{
	m_pChat->OnChatMessageText(lChatMsgId, sMsgFrom, sMsgTo, sMsgText, lFromPeerType, sFromPeerName, sFromIP, lFromPort);
}

void CVaxServerExCOM::OnChatMessageTyping(LONG lChatMsgId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, BOOL IsTypingStart, LONG lFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG lFromPort)
{
	m_pChat->OnChatMessageTyping(lChatMsgId, sMsgFrom, sMsgTo, IsTypingStart, lFromPeerType, sFromPeerName, sFromIP, lFromPort);
}

void CVaxServerExCOM::OnChatStatusSubscribe(LONG lSubscrbId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LONG lFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG lFromPort)
{
	m_pChat->OnChatStatusSubscribe(lSubscrbId, sMsgFrom, sMsgTo, lFromPeerType, sFromPeerName, sFromIP, lFromPort);
}

void CVaxServerExCOM::OnChatMessageSuccess(LONG lChatMsgId)
{
	m_pChat->OnChatMessageSuccess(lChatMsgId);
}

void CVaxServerExCOM::OnChatMessageFailed(LONG lChatMsgId, LONG lStatusId, LPCTSTR sReasonPhrase)
{
	m_pChat->OnChatMessageFailed(lChatMsgId, lStatusId, sReasonPhrase);
}

void CVaxServerExCOM::OnChatMessageTimeout(LONG lChatMsgId)
{
	m_pChat->OnChatMessageTimeout(lChatMsgId);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnLineRegisterTrying(LPCTSTR sLineName)
{
	CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
	pLine->OnLineRegisterTrying(sLineName);
}

void CVaxServerExCOM::OnLineRegisterFailed(LPCTSTR sLineName, LONG lStatusCode, LPCTSTR sReasonPhrase)
{
	CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
	pLine->OnLineRegisterFailed(sLineName, lStatusCode, sReasonPhrase);
}

void CVaxServerExCOM::OnLineRegisterSuccess(LPCTSTR sLineName)
{
	CVaxLine* pLine = (CVaxLine*) CVaxServerCOM::GetLineData(sLineName);
	pLine->OnLineRegisterSuccess(sLineName);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::OnDetectedDigitDTMF(LONG lSessionId, LONG lCallType, LPCTSTR sDigitDTMF)
{
	CVaxCallSession* pCallSession = (CVaxCallSession*) CVaxServerCOM::GetCallSessionData(lSessionId);
	pCallSession->OnDetectedDigitDTMF(lSessionId, lCallType, sDigitDTMF);
}

//////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////

void CVaxServerExCOM::GenStatusLog(LPCTSTR sStatus)
{
	OnStatusLog(sStatus);
}

void CVaxServerExCOM::OnVaxErrorLog(LPCTSTR sFuncName, DWORD dwErrorCode, LPCTSTR sErrorMsg)
{
	CString sMsg;
	sMsg.Format("[Method: %s] [Error Msg: %s] [Code: %d]", sFuncName, sErrorMsg, dwErrorCode);

	OnErrorLog(sMsg);
}

void CVaxServerExCOM::OnStatusLog(LPCTSTR sMsg)
{

}

void CVaxServerExCOM::OnErrorLog(LPCTSTR sMsg)
{

}