﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using VaxTeleServerApp;

namespace VaxTeleConfigSIP
{
    public partial class AddConfRoom : Form
    {

        private CVaxServerSIP m_objVaxTeleSIP;

        public AddConfRoom(ref CVaxServerSIP objVaxServer)
        {
            InitializeComponent();

            m_objVaxTeleSIP = objVaxServer;
        }

        private void OnAddConfRoom(object sender, EventArgs e)
        {
            if (!AddLineChecks())
                return;

            if(!m_objVaxTeleSIP.AddRoom(ComboRoomName.Text.Trim(), EditRoomNo.Text.Trim()))
            {
                MessageBox.Show("Room could not be created or Please start the server first.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            ComboRoomName.Items.Add(ComboRoomName.Text);
            MessageBox.Show("Room created successfully", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }

        private void OnRemoveConfRoom(object sender, EventArgs e)
        {
            m_objVaxTeleSIP.RemoveRoom(ComboRoomName.Text.Trim());

            int nIndex = ComboRoomName.FindStringExact(ComboRoomName.Text);
            if (nIndex == -1) return;

            m_objVaxTeleSIP.RemoveRoom(ComboRoomName.Text);
            ComboRoomName.Items.RemoveAt(nIndex);
            
            MessageBox.Show("Room removed successfully!", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
            ClearDlgContent();
        }

        private Boolean AddLineChecks()
        {
            if (ComboRoomName.Text.Length == 0)
            {
                MessageBox.Show("Please enter Room Name.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            if (EditRoomNo.Text.Length == 0)
            {
                MessageBox.Show("Room No cann't be empty.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            string sDigit = "0123456789";

            for (int nCount = 0; nCount < EditRoomNo.Text.Length; nCount++)
            {
                if (sDigit.IndexOf(EditRoomNo.Text[nCount]) == -1)
                {
                    MessageBox.Show("Room no should contain only numerals 0 through 9. For example: 12, 324323, 800122, 2109756 etc.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                    return false;
                }
            }

            return true;
        }

        private void ComboRoomName_SelectedIndexChanged(object sender, EventArgs e)
        {
            ShowRoomDetails(ComboRoomName.Text);
        }

        private void ClearDlgContent()
        {
            EditRoomNo.Text = "";
        }

        private void ShowRoomDetails(String sRoomName)
        {
            String sRoomNo = "";

            if (!m_objVaxTeleSIP.GetRoomDetails(sRoomName, ref sRoomNo))
                return;

            EditRoomNo.Text = sRoomNo;
        }
    }
}
