using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using VaxTeleServerApp;

namespace VaxTeleConfigSIP
{
    public partial class AddLineForm : Form
    {
        private CVaxServerSIP m_objVaxTeleSIP;
        
        public AddLineForm(ref CVaxServerSIP objVaxServer)
        {
            InitializeComponent();
            
            m_objVaxTeleSIP = objVaxServer;
            RadioRejectCall.Checked = true;
        }

        private void AddLineForm_Load(object sender, EventArgs e)
        {
            LoadCodecs();
        }
 
        private void BtnAddLine_Click(object sender, EventArgs e)
        {
            if(AddLineChecks() == false)
                return;
            
            if(ComboLine.FindStringExact(ComboLine.Text) != -1)
            {
                MessageBox.Show("Line already exists.", "VaxTeleSIP", MessageBoxButtons.OK);
                return;
            }

            cCodec objCodec = new cCodec();
            string sCodec = "";

            for(int nCount = 0; nCount < ListBoxEnableCodec.Items.Count; nCount++)
                sCodec += objCodec.GetCodecNo((string) ListBoxEnableCodec.Items[nCount]);

            int nToPeerType = -1;
            string sToPeerName = "", sRoomName = "";
            bool bRejected = false;

            bRejected = RadioRejectCall.Checked;

            if (RadioConnectToUser.Checked)
            {
                nToPeerType = CVaxServerCOM.VAX_PEER_TYPE_USER;
                sToPeerName = ComboConnectToUser.Text.Trim().ToString();
            }
            else if (RadioPutInConf.Checked)
            {
                nToPeerType = CVaxServerCOM.VAX_PEER_TYPE_USER;
                sRoomName = ComboPutInConf.Text.Trim().ToString();
            }

            if (m_objVaxTeleSIP.AddLine(ComboLine.Text, EditDisplayName.Text, EditUserName.Text, EditAuthUser.Text, EditPassword.Text, EditDomainRealm.Text, EditProxySIP.Text, sCodec, CheckBoxRegLine.Checked, nToPeerType, sToPeerName, bRejected, sRoomName) == false)
            {
                MessageBox.Show("Line could not be created or Please start the server first.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            ComboLine.Items.Add(ComboLine.Text);
            MessageBox.Show("Line created successfully", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }
               
        private void ClearDlgContent()
        {
            ComboLine.Text = "";

            EditUserName.Text = "";
            EditAuthUser.Text = "";
            EditPassword.Text = "";
            EditDisplayName.Text = "";
            EditDomainRealm.Text = "";
            EditProxySIP.Text = "";

            if(ComboConnectToUser.Items.Count > 0)
                ComboConnectToUser.SelectedIndex = 0;

            if(ComboPutInConf.Items.Count > 0)
                ComboPutInConf.SelectedIndex = 0;
            
            CheckBoxRegLine.Checked = false;
            RadioRejectCall.Checked = true;

            ListBoxEnableCodec.Items.Clear();
            ListBoxDisableCodec.Items.Clear();

            ListBoxEnableCodec.Items.Add(cCodec.G711U_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.G711A_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.ILBC_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.G610_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.G729_TEXT);
        }

        private void BtnRemoveLine_Click(object sender, EventArgs e)
        {
            if(ComboLine.Text.Length == 0)
            {
                MessageBox.Show("Please enter line name.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return;
            }

            int nIndex = ComboLine.FindStringExact(ComboLine.Text);
            if (nIndex == -1) return;

            m_objVaxTeleSIP.RemoveLine(ComboLine.Text);
            ComboLine.Items.RemoveAt(nIndex);
            
            MessageBox.Show("Line removed successfully!", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
            ClearDlgContent();
        }

        private void ComboLine_SelectedIndexChanged(object sender, EventArgs e)
        {
            ShowLineDetails(ComboLine.Text);
        }

        private void BtnClearLineDlg_Click(object sender, EventArgs e)
        {
            ClearDlgContent();
        }

        private void BtnDisableCodec_Click(object sender, EventArgs e)
        {
            if(ListBoxEnableCodec.SelectedItems.Count == 0) return;

            ListBoxDisableCodec.Items.Add(ListBoxEnableCodec.SelectedItem.ToString());
            ListBoxEnableCodec.Items.Remove(ListBoxEnableCodec.SelectedItem);
        }

        private void BtnEnableCodec_Click(object sender, EventArgs e)
        {
            if(ListBoxDisableCodec.SelectedItems.Count == 0) return;

            ListBoxEnableCodec.Items.Add(ListBoxDisableCodec.SelectedItem.ToString());
            ListBoxDisableCodec.Items.Remove(ListBoxDisableCodec.SelectedItem);
        }

        private void LoadCodecs()
        {
            cCodec objCodec = new cCodec();

            for (int nCount = 0; nCount < cCodec.TOTAL_SIZE_CODEC; nCount++)
                ListBoxEnableCodec.Items.Add(objCodec.GetCodecName(Convert.ToString(nCount)));
        }

        private void ShowLines()
        {
            ComboLine.Items.Clear();

            RadioRejectCall.Checked = true;

            ArrayList objListLines = new ArrayList();
            m_objVaxTeleSIP.GetLineAll(ref objListLines);

            if (objListLines.Count <= 0)
            {
                return;
            }

            for (int nCount = 0; nCount < objListLines.Count; nCount++)
                ComboLine.Items.Add(objListLines[nCount]);

            if (ComboLine.Items.Count > 0)
                ComboLine.SelectedIndex = 0;

            ShowLineDetails(ComboLine.Text);
        }

        private void ShowUsers()
        {
            ComboConnectToUser.Items.Clear();
            
            ArrayList objListUsers = new ArrayList();
            m_objVaxTeleSIP.GetUserAll(ref objListUsers);

            if (objListUsers.Count <= 0) return;

            for (int nCount = 0; nCount < objListUsers.Count; nCount++)
                ComboConnectToUser.Items.Add(objListUsers[nCount]);

            if (ComboConnectToUser.Items.Count > 0)
                ComboConnectToUser.SelectedIndex = 0;
        }

        private void ShowRooms()
        {
            ComboPutInConf.Items.Clear();

            ArrayList objListRooms = new ArrayList();
            m_objVaxTeleSIP.GetRoomAll(ref objListRooms);

            if (objListRooms.Count <= 0) return;

            for (int nCount = 0; nCount < objListRooms.Count; nCount++)
                ComboPutInConf.Items.Add(objListRooms[nCount]);

            if (ComboPutInConf.Items.Count > 0)
                ComboPutInConf.SelectedIndex = 0;
        }

        public void OnSetActive()
        {
            ShowUsers();
            ShowRooms();
            ShowLines();
        }

        private Boolean AddLineChecks()
        {
            if (ComboLine.Text.Length == 0)
            {
                MessageBox.Show("Please enter Line Name.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            if (ListBoxEnableCodec.Items.Count == 0)
            {
                MessageBox.Show("Please select a codec.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            return true;
        }

        private void ShowLineDetails(String sLineName)
        {
            string sDisplayName = "", sUserName = "", sAuthUser = "";
            string sAuthPwd = "", sDomainRealm = "", sProxySIP = "";
            string sCodecList = "", sToPeerName = "", sRoomName = "";

            int nToPeerType = -1;
            bool bRegister = false, bBlock = false, bAddToConf = false;

            m_objVaxTeleSIP.GetLineDetails(sLineName, ref sDisplayName, ref sUserName, ref sAuthUser, ref sAuthPwd, ref sDomainRealm, ref sProxySIP, ref sCodecList, ref bRegister, ref nToPeerType, ref sToPeerName, ref bBlock, ref bAddToConf, ref sRoomName);
            UpdateDlgContent(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);
        }

        private void UpdateDlgContent(string sLineName, string sDisplayName, string sUserName, string sAuthUser, string sAuthPwd, string sRealm, string sProxy, string sCodecList, bool bRegister, long lToPeerType, string sToPeerName, bool bBlock, bool bAddToConf, string sRoomName)
        {
            if (sLineName.Length == 0)
                return;

            EditDisplayName.Text = sDisplayName;
            EditUserName.Text = sUserName;

            EditAuthUser.Text = sAuthUser;
            EditPassword.Text = sAuthPwd;
            EditDomainRealm.Text = sRealm;
            EditProxySIP.Text = sProxy;

            CheckBoxRegLine.Checked = bRegister;

            UpdateIncomingCallSection((int)lToPeerType, sToPeerName, bBlock, bAddToConf, sRoomName);

            ListBoxEnableCodec.Items.Clear();
            ListBoxDisableCodec.Items.Clear();

            cCodec objCodec = new cCodec();

            for (int nCount = 0; nCount < cCodec.TOTAL_SIZE_CODEC; nCount++)
                ListBoxDisableCodec.Items.Add(objCodec.GetCodecName(Convert.ToString(nCount)));

            string sCodecName;

            for (int nCount = 0; nCount < sCodecList.Length; nCount++)
            {
                sCodecName = objCodec.GetCodecName(sCodecList[nCount].ToString());
                ListBoxEnableCodec.Items.Add(sCodecName);
                ListBoxDisableCodec.Items.Remove(sCodecName);
            }
        }

        private void UpdateIncomingCallSection(int nToPeerType, string sToPeerName, bool bRejected, bool bAddToConf, string sRoomName)
        {
            if (bRejected)
            {
                RadioRejectCall.Checked = true;
                return;
            }
            
            if (nToPeerType == CVaxServerCOM.VAX_PEER_TYPE_USER)
            {
                int nIndex = ComboConnectToUser.FindStringExact(sToPeerName);

                if (nIndex == -1)
                {
                    RadioRejectCall.Checked = true;
                    return;
                }

                if (ComboConnectToUser.Items.Count > 0)
                    ComboConnectToUser.SelectedIndex = nIndex;

                RadioConnectToUser.Checked = true;
                return;
            }
            
            if (bAddToConf)
            {
                int nIndex = ComboPutInConf.FindStringExact(sRoomName);

                if (nIndex == -1)
                {
                    RadioRejectCall.Checked = true;
                    return;
                }

                if (ComboPutInConf.Items.Count > 0)
                    ComboPutInConf.SelectedIndex = nIndex;

                RadioPutInConf.Checked = true;
                return;
            }
        }
    }
}