using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

using VaxTeleServerApp;

namespace VaxTeleConfigSIP
{
    public partial class GeneralForm : Form
    {

        CVaxServerSIP m_objVaxTeleSIP;
        private PerformanceCounter m_objUsageCPU = new PerformanceCounter("Processor", "% Processor Time", "_Total");

        public GeneralForm(ref CVaxServerSIP objVaxTeleSIP)
        {
            InitializeComponent();
            m_objVaxTeleSIP = objVaxTeleSIP;
        }
                
        private void GeneralForm_Load(object sender, EventArgs e)
        {
            UpdateStats();
            TimerGeneral.Enabled = true;
        }

        private void BtnStartServerSIP_Click(object sender, EventArgs e)
        {
            m_objVaxTeleSIP.SetLicenseKey("TRIAL-LICENSE-KEY");

            Boolean bStatusRun = m_objVaxTeleSIP.Initialize(EditListenIP.Text, EditListenIP.Text, Convert.ToInt32(EditListenPort.Text), EditListenIP.Text, -1);

            if( bStatusRun == false )
            {
                LabelServerStatus.Text = "UNABLE TO START SIP SERVER (SEE ERROR LOG).";
                return;
            }

            AddLogins();

            LabelServerStatus.Text = "SIP SERVER IS RUNNING.";
            
            m_objVaxTeleSIP.LoadMusicHold(EditPlayWaveHold.Text);
            m_objVaxTeleSIP.LoadMusicDialTone(EditPlayWaveDialTone.Text);

            TimerGeneral.Enabled = true;

            m_objVaxTeleSIP.VoiceSessionLost(true, 20); // Enable voice session lost for 20 seconds.
            m_objVaxTeleSIP.VideoCOMM(true); // Enable Video Communication.
            
            //m_objVaxTeleSIP.AddCustomHeader(0, "Field", "\"Value\"");
        }

        private void BtnStopServerSIP_Click(object sender, EventArgs e)
        {
            StopServer();
        }

        public void StopServer()        // This function also gets called in MainForm::MainForm_Closing()
        {
            m_objVaxTeleSIP.UnInitialize();

            LabelServerStatus.Text = "SIP SERVER IS NOT RUNNING.";
            TimerGeneral.Enabled = false;        
        }

        private void TimerGeneral_Tick(object sender, EventArgs e)
        {
            UpdateStats();
        }

        private void UpdateStats()
        {
            LabelTotalCalls.Text = m_objVaxTeleSIP.GetCallCount().ToString();
            LabelTotalUsers.Text = m_objVaxTeleSIP.GetRegisteredUserCount().ToString();

            LabelUsageCPU.Text = GetUsageCPU().ToString();
            LabelUsageMEM.Text = GetAvailableMEM().ToString();
        }

        public void OnSetActive()
        {
          
        }

        public long GetAvailableMEM()
        {
            PerformanceCounter objUsageMEM = new PerformanceCounter("Memory", "Available KBytes");
            return (long) objUsageMEM.NextValue();

        }
        public long GetUsageCPU()
        {
            return (long) m_objUsageCPU.NextValue();
        }

        public void AddLogins()
        {
            for (int nCount = 4040; nCount <= 4050; nCount++)
            {
                string sUser, sPass;
                
                sUser = nCount.ToString();
                sPass = nCount.ToString();
                                
                m_objVaxTeleSIP.AddUser(sUser, sPass, "32014", false, "", "", CVaxServerCOM.VAX_PEER_TYPE_USER, "");
            }
        }
    }
}