﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Runtime.InteropServices;

namespace VaxTeleServerApp
{
    public class CVaxServerExCOM : CVaxServerCOM
    {
        int m_nTotalCallCount = 0;
        int m_nDialToneId = -1;
        int m_nRegisterUserCount = 0;

        CVaxCallSessionRoute m_objRouteCallSIP = null;
        CConfRoom m_objConfRoom = null;
        CVaxChat m_objChat = null;

        #region Methods

        public CVaxServerExCOM()
        {
            m_objConfRoom = new CConfRoom(this);
            m_objRouteCallSIP = new CVaxCallSessionRoute(this);
            m_objChat = new CVaxChat(this);
        }

        ~CVaxServerExCOM()
        {

        }
        
	    public bool Initialize(string  sDomainRealm, string  sSIPListenIP, int nSIPListenPort, string  sRTPListenIP, int nRTPListenPort)
        {
	        return base.Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sRTPListenIP, nRTPListenPort);
        }
	    
        public void UnInitialize()
        {
            m_nTotalCallCount = 0;
            m_nRegisterUserCount = 0;

            DeleteUserDataAll();
            DeleteCallSessionDataAll();

            m_objConfRoom.DeleteRoomAll();
            base.UnInitialize();
        }

        //////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////

        public bool AddUser(string sUserName, string sPassword, string sCodecList, bool bBlocked, string sUserPrefix, string sDialPrefix, int nToPeerType, string sToPeerName)
        {
	        if(!base.AddUser(sUserName, sPassword, sCodecList))	
	        {
		        return false;
	        }

            CVaxUser objUser = new CVaxUser(this);
	        base.SetUserData(sUserName, objUser);

            objUser.SetData(sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

	        return true;

        }
	    public void RemoveUser(string  sUserName)
        {
            base.RemoveUser(sUserName);
            base.FreeUserData(sUserName);
        }

        public void GetUserAll(ref ArrayList objList)
        {
            base.TrvsUserStart();

            while (true)
            {
                string sUserName = base.TrvsUserNext();
		        if(sUserName.Length == 0) break;

                objList.Add(sUserName);
            }
        }

        public bool GetUserDetails(string sUserName, ref string sPassword, ref string sCodecList, ref bool bBlocked, ref string sUserPrefix, ref string sDialPrefix, ref int nToPeerType, ref string sToPeerName)
        {
            CVaxUser objUser = (CVaxUser)base.GetUserData(sUserName);
            if (objUser == null) return false;

            objUser.GetData(ref sPassword, ref sCodecList, ref bBlocked, ref sUserPrefix, ref sDialPrefix, ref nToPeerType, ref sToPeerName);
            return true;
        }

        //////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////

        public bool AddLine(string sLineName, string sDisplayName, string sUserName, string sAuthUser, string sAuthPwd, string sDomainRealm, string sProxySIP, string sCodecList, bool bRegister, int nToPeerType, string sToPeerName, bool bBlock, string sRoomName)
        {
	        if(!base.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, "", sCodecList))
	        {
		        return false;
	        }

            CVaxLine objLine = new CVaxLine(this);
            
            base.SetLineData(sUserName, objLine);
            objLine.SetData(sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlock, sRoomName);

            if (bRegister)
                base.RegisterLine(sLineName, 1800);

             return true;
        }
	    
        public void RemoveLine(string  sLineName)
        {
        	base.RemoveLine(sLineName);
            base.FreeLineData(sLineName);
        }
                
        public void GetLineAll(ref ArrayList objList)
        {
            base.TrvsLineStart();

            while (true)
            {
                string sLineName = base.TrvsLineNext();
                if (sLineName.Length == 0) break;

                objList.Add(sLineName);
            }
        }

        public bool GetLineDetails(string sLineName, ref string sDisplayName, ref string sUserName, ref string sAuthUser, ref string sAuthPwd, ref string sDomainRealm, ref string sProxySIP, ref string sCodecList, ref bool bRegister, ref int nToPeerType, ref string sToPeerName, ref bool bBlock, ref bool bAddToConf, ref string sRoomName)
        {
            CVaxLine objLine = (CVaxLine)base.GetLineData(sLineName);
            if (objLine == null) return false;

            objLine.GetData(ref sDisplayName, ref sUserName, ref sAuthUser, ref sAuthPwd, ref sDomainRealm, ref sProxySIP, ref sCodecList, ref bRegister, ref nToPeerType, ref sToPeerName, ref bBlock, ref sRoomName);
            return true;
        }

        //////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////
        
        public bool AddDirectProxySIP(string sProxyName, string sAuthLogin, string sAuthPwd, string sDomainRealm, string sProxyIP, int nProxyPort, string sCodecList, int nToPeerType, string sToPeerName, bool bBlock, string sRoomName)
        {
            if (!base.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList))
	        {
		        return false;
	        }

            CVaxDirectProxy objDirectProxy = new CVaxDirectProxy(this);
            base.SetDirectProxyData(sProxyName, objDirectProxy);

            objDirectProxy.SetData(sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList, nToPeerType, sToPeerName, bBlock, sRoomName);
            return true;
        }

	    public void RemoveDirectProxySIP(string  sProxyName)
        {
            base.RemoveDirectProxySIP(sProxyName);
            base.FreeDirectProxyData(sProxyName);
        }

        public void GetDirectProxyAll(ref ArrayList objList)
        {
            base.TrvsDirectProxyStart();

            while (true)
            {
                string sProxyName = base.TrvsDirectProxyNext();
                if (sProxyName.Length == 0) break;

                objList.Add(sProxyName);
            }
        }

        public bool GetDirectProxyDetails(string sProxyName, ref string sAuthLogin, ref string sAuthPwd, ref string sDomainRealm, ref string sProxyIP, ref int nProxyPort, ref string sCodecList, ref int nToPeerType, ref string sToPeerName, ref bool bBlocked, ref string sRoomName)
        {
            CVaxDirectProxy objDirectProxy = (CVaxDirectProxy)base.GetDirectProxyData(sProxyName);
            if (objDirectProxy == null) return false;

            objDirectProxy.GetData(ref sAuthLogin, ref sAuthPwd, ref sDomainRealm, ref sProxyIP, ref nProxyPort, ref sCodecList, ref nToPeerType, ref sToPeerName, ref bBlocked, ref sRoomName);
            return true;
        }

        //////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////
                
        public int GetVaxObjectError()
        {
        	return base.GetVaxObjectError();
        }

        public bool DialToneToCallSession(bool bEnable, int nSessionId)
        {
            if (m_nDialToneId == -1)
                return true;

            return base.DialToneToCallSession(bEnable, nSessionId, m_nDialToneId);
        }

        public int GetCallCount()
        {
            return m_nTotalCallCount;
        }

        public int GetRegisteredUserCount()
        {
	        return m_nRegisterUserCount;
        }
        
        //////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////

        public bool AddRoom(string sRoomName, string sRoomNo)
        {
            return m_objConfRoom.AddRoom(sRoomName, sRoomNo);
        }

        public void RemoveRoom(string sRoomName)
        {
            m_objConfRoom.RemoveRoom(sRoomName);
        }

        public bool GetRoomDetails(string sRoomName, ref string sRoomNo)
        {
            return m_objConfRoom.GetRoomDetails(sRoomName, ref sRoomNo);
        }

        public bool IsRoomNoExists(string sRoomNo)
        {
            return m_objConfRoom.IsRoomNoExists(sRoomNo);
        }

        public bool GetRoomAll(ref ArrayList aRoomList)
        {
            return m_objConfRoom.GetRoomAll(ref aRoomList);
        }

        //////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////

        public bool LoadMusicDialTone(string sFileName)
        {
            UnLoadMusicDialTone();

            m_nDialToneId = base.LoadWaveFile(sFileName);
            return (m_nDialToneId != -1);
        }

        public void UnLoadMusicDialTone()
        {
            if (m_nDialToneId != -1)
            {
                base.UnLoadWaveFile(m_nDialToneId);
                m_nDialToneId = -1;
            }
        }

        //////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////

        public bool AddUserRoute(string sUserName, string sUserPrefix, string sDialPrefix, int nToPeerType, string sToPeerName)
        {
            return m_objRouteCallSIP.AddUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
        }

        public void RemoveUserRoute(string sUserName)
        {
            m_objRouteCallSIP.RemoveUserRoute(sUserName);
        }

        public bool AddLineRoute(string sLineName, int nToPeerType, string sToPeerName, bool bRejected,string sRoomName)
        {
            return m_objRouteCallSIP.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);
        }

        public void RemoveLineRoute(string sLineName)
        {
            m_objRouteCallSIP.RemoveLineRoute(sLineName);
        }

        public bool AddDirectProxyRoute(string sProxyName, int nToPeerType, string sToPeerName, bool bRejected, string sRoomName)
        {
            return m_objRouteCallSIP.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName);
        }

        public void RemoveDirectProxyRoute(string sProxyName)
        {
            m_objRouteCallSIP.RemoveDirectProxyRoute(sProxyName);
        }

        //////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////
                
        public void DeleteCallSessionDataAll()
        {
            base.TrvsCallSessionStart();
		    
	        for(int nCount = 0; nCount < base.GetCallSessionCount(); nCount++)
	        {
		        int nSessionId = base.TrvsCallSessionNext();
		        base.FreeCallSessionData(nSessionId);
	        }
        }

        public void DeleteUserDataAll()
        {
            base.TrvsUserStart();
		    
	        for(int nCount = 0; nCount < base.GetUserCount(); nCount++)
	        {
		        string sUserName = base.TrvsUserNext();
		        base.FreeUserData(sUserName);
	        }
        }

    //////////////////////////////////////////////////////////////////////////////////
    //////////////////////////////////////////////////////////////////////////////////


        #endregion

        #region Events

        public override void OnCallSessionCreated(int nSessionId, int nReasonCode)
        {
            CVaxCallSession objCallSession = new CVaxCallSession(this);
            base.SetCallSessionData(nSessionId, objCallSession);
        }

        public override void OnCallSessionClosed(int nSessionId, int nCallType, int nReasonCode)
        {
            base.FreeCallSessionData(nSessionId);
        }
        
        public override void OnCallSessionOpen(int nSessionId, string sCallerName, string sCallerId, string sDialNo, int nFromPeerType, string sFromPeerName, string sFromIP, int nFromPort)
        {
            string sToPeerName = "", sDialToNo = "", sRoomName = "";
            int nToPeerType = -1; bool bRejected = false;

            if (nFromPeerType == CVaxServerCOM.VAX_PEER_TYPE_USER)
            {
                if (m_objConfRoom.IsRoomNoExists(sDialNo))
                    sRoomName = m_objConfRoom.GetRoomName(sDialNo);
                else
                    m_objRouteCallSIP.OnCallFromUser(sFromPeerName, sDialNo, ref sDialToNo, ref nToPeerType, ref sToPeerName);
            }
            else if (nFromPeerType == CVaxServerCOM.VAX_PEER_TYPE_LINE)
            {
                m_objRouteCallSIP.OnCallFromLine(sFromPeerName, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName);
                sDialToNo = sToPeerName;
            }
            else if (nFromPeerType == CVaxServerCOM.VAX_PEER_TYPE_DIRECT_PROXY)
            {
                m_objRouteCallSIP.OnCallFromDirectProxySIP(sFromPeerName, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName);
                sDialToNo = sToPeerName;
            }

            //////////////////////////////////////////////////////////////////////

            if (bRejected == true)
            {
                base.RejectCallSession(nSessionId, 404, "Not Found");
                return;
            }

            CVaxCallSession objCallSession = (CVaxCallSession)base.GetCallSessionData(nSessionId);
            objCallSession.OnCallSessionOpen(nSessionId, sCallerName, sCallerId, sDialNo, sRoomName, nFromPeerType, sFromPeerName, nToPeerType, sToPeerName, sFromIP, nFromPort);

        }
   
        public override void OnCallSessionConnected(int nSessionId)
        {
            CVaxCallSession objCallSession = (CVaxCallSession)base.GetCallSessionData(nSessionId);
            objCallSession.OnCallSessionConnected(nSessionId);
        }
        
        public override void OnCallSessionOnHold(int nSessionId, int nCallType)
        {
            CVaxCallSession objCallSession = (CVaxCallSession)base.GetCallSessionData(nSessionId);
            objCallSession.OnCallSessionOnHold(nSessionId, nCallType);
        }
        public override void OnCallSessionOffHold(int nSessionId, int nCallType)
        {
            CVaxCallSession objCallSession = (CVaxCallSession)base.GetCallSessionData(nSessionId);
            objCallSession.OnCallSessionOffHold(nSessionId, nCallType);
        }

        ////////////////////////////////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////////////////////////////////

        public override void OnCallSessionTransferBlind(int nTransfererSessionId, int nTransfererCallType, string sTransferer, string sTransferee, string sTransferTo)
        {
            CVaxCallSession objCallSession = (CVaxCallSession)base.GetCallSessionData(nTransfererSessionId);
            objCallSession.OnCallSessionTransferBlind(nTransfererSessionId, nTransfererCallType, sTransferer, sTransferee, sTransferTo);
        }
        public override void OnCallSessionTransferConsult(int nTransfererSessionId, int nTransfereeSessionId, int nTransferToSessionId, int nTransfererCallType, int nTransfereeCallType, int nTransferToCallType, string sTransferer, string sTransferee, string sTransferTo)
        {
            CVaxCallSession objCallSession = (CVaxCallSession)base.GetCallSessionData(nTransfererSessionId);
            objCallSession.OnCallSessionTransferConsult(nTransfererSessionId, nTransfereeSessionId, nTransferToSessionId, nTransfererCallType, nTransfereeCallType, nTransferToCallType, sTransferer, sTransferee, sTransferTo);
        }

        ////////////////////////////////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////////////////////////////////

        public override void OnDetectedDigitDTMF(int nSessionId, int nCallType, string sDigitDTMF)
        {
            CVaxCallSession objCallSession = (CVaxCallSession)base.GetCallSessionData(nSessionId);
            objCallSession.OnDetectedDigitDTMF(nSessionId, nCallType, sDigitDTMF);
        }
        
        ////////////////////////////////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////////////////////////////////

        public override void OnCallSessionOpenCall(int nSessionId, int nCallType, int nPeerType, string sPeerName)
        {
            m_nTotalCallCount++;
        }

        public override void OnCallSessionCloseCall(int nSessionId, int nCallType, int nPeerType, string sPeerName)
        {
            m_nTotalCallCount--;
        }

        //////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////

        public override void OnLineRegisterTrying(string sLineName)
        {
            CVaxLine objLine = (CVaxLine)base.GetLineData(sLineName);
            objLine.OnLineRegisterTrying(sLineName);
        }
        public override void OnLineRegisterFailed(string sLineName, int nStatusCode, string sReasonPhrase)
        {
            CVaxLine objLine = (CVaxLine)base.GetLineData(sLineName);
            objLine.OnLineRegisterFailed(sLineName, nStatusCode, sReasonPhrase);
        }
        public override void OnLineRegisterSuccess(string sLineName)
        {
            CVaxLine objLine = (CVaxLine)base.GetLineData(sLineName);
            objLine.OnLineRegisterSuccess(sLineName);
        }
        
        //////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////

        public override void OnRegisterUser(string sUserLogin, string sDomain, string sFromIP, int nFromPort)
        {
            CVaxUser objUser = (CVaxUser)base.GetUserData(sUserLogin);

            if (objUser == null)
            {
                RejectRegister(sUserLogin, 404, "Not Found");
                return;
            }
                                
            objUser.OnRegisterUser(sUserLogin, sDomain, sFromIP, nFromPort);
        }

        public override void OnRegisterUserSuccess(string sUserLogin)
        {
            CVaxUser objUser = (CVaxUser)base.GetUserData(sUserLogin);

            if (!objUser.IsRegistered())
                m_nRegisterUserCount++;

            objUser.OnRegisterUserSuccess(sUserLogin);
        }

        public override void OnRegisterUserFailed(string sUserLogin)
        {
            CVaxUser objUser = (CVaxUser)base.GetUserData(sUserLogin);
            objUser.OnRegisterUserFailed(sUserLogin);
        }

        public override void OnUnRegisterUser(string sUserLogin)
        {
            CVaxUser objUser = (CVaxUser)base.GetUserData(sUserLogin);

            if (objUser.IsRegistered())
                m_nRegisterUserCount--;

            objUser.OnUnRegisterUser(sUserLogin);
        }

        //////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////

        public override void OnChatMessageText(int nChatMsgId, string sMsgFrom, string sMsgTo, string sMsgText, int nFromPeerType, string sFromPeerName, string sFromIP, int nFromPort)
        {
            m_objChat.OnChatMessageText(nChatMsgId, sMsgFrom, sMsgTo, sMsgText, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        }
        public override void OnChatMessageTyping(int nChatMsgId, string sMsgFrom, string sMsgTo, bool bIsTypingStart, int nFromPeerType, string sFromPeerName, string sFromIP, int nFromPort)
        {
            m_objChat.OnChatMessageTyping(nChatMsgId, sMsgFrom, sMsgTo, bIsTypingStart, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        }
        public override void OnChatStatusSubscribe(int nSubscrbId, string sMsgFrom, string sMsgTo, int nFromPeerType, string sFromPeerName, string sFromIP, int nFromPort)
        {
            m_objChat.OnChatStatusSubscribe(nSubscrbId, sMsgFrom, sMsgTo, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        }

        public override void OnChatMessageSuccess(int nChatMsgId)
        {
            m_objChat.OnChatMessageSuccess(nChatMsgId);
        }
        public override void OnChatMessageFailed(int nChatMsgId, int nStatusCode, string sReasonPhrase)
        {
            m_objChat.OnChatMessageFailed(nChatMsgId, nStatusCode, sReasonPhrase);
        }
        public override void OnChatMessageTimeout(int nChatMsgId)
        {
            m_objChat.OnChatMessageTimeout(nChatMsgId);
        }

        //////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////

        public void GenStatusLog(string sStatus)
        {
	        OnStatusLog(sStatus);
        }

        public override void OnVaxErrorLog(string sFuncName, int nErrorCode, string sErrorMsg)
        {
            string sMsg = "[Method: " + sFuncName + "] [Error Msg: " + sErrorMsg + "] [Code: " + nErrorCode.ToString() + "]";
            OnErrorLog(sMsg);
        }

        public virtual void OnStatusLog(string sMsg)
        {

        }

        public virtual void OnErrorLog(string sMsg)
        {

        }
                
        #endregion

    }
}
