﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace VaxTeleServerApp
{
    class CVaxCallSession
    {
        CVaxServerExCOM m_objServerExCOM = null;
        string m_sRoomName;
        
        public CVaxCallSession(CVaxServerExCOM objServerExCOM)
        {
           m_objServerExCOM = objServerExCOM;
        }

        ~CVaxCallSession()
        {
        }

        //////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////

        public bool AcceptCallSession(int nSessionId, string sCallerName, string sCallerId, string sDialNo, int nToPeerType, string sToPeerName)
        {
            bool bResult = m_objServerExCOM.AcceptCallSession(nSessionId, sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName, 30);
            
            if(!bResult) 
	        {
                m_objServerExCOM.RejectCallSession(nSessionId, 404, "Not Found");
		        return false;
	        }

            return true;
        }
        
        //////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////

        public void OnCallSessionOpen(int nSessionId, string sCallerName, string sCallerId, string sDialNo, string sRoomName, int nFromPeerType, string sFromPeerName, int nToPeerType, string sToPeerName, string sFromIP, int nFromPort)
        {
            m_sRoomName = sRoomName;

            //////////////////////////////////////////////////////////////////////

            if (sRoomName.Length != 0)
            {
                AcceptCallSession(nSessionId, "", "", "", -1, ""); // Accept the incoming call and add to conference room in OnCallSessionConnected()
                return;
            }

            //////////////////////////////////////////////////////////////////////

            if (nToPeerType == CVaxServerCOM.VAX_PEER_TYPE_LINE)
            {
                sCallerName = "";
                sCallerId = "";

                // Let AcceptCallSession() use DisplayName & UserName values of LINE as CallerName & CallerId.
            }

            //////////////////////////////////////////////////////////////////////

            if (!AcceptCallSession(nSessionId, sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName))
                return;

            m_objServerExCOM.DialToneToCallSession(true, nSessionId);
        }

        //////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////

        public void OnCallSessionConnected(int nSessionId)
        {
            if(m_sRoomName.Length != 0)
	        {
		        m_objServerExCOM.AddCallSessionToConferenceRoom(m_sRoomName, nSessionId, CVaxServerCOM.CONF_ROOM_NORMAL_LISTENER);
		        return;
	        }
        }

        //////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////

        public void OnCallSessionOnHold(int nSessionId, int nCallType)
        {
            if(m_sRoomName.Length != 0)
	            return;

            m_objServerExCOM.AcceptOnHoldRequest(nSessionId);
        }

        public void OnCallSessionOffHold(int nSessionId, int nCallType)
        {
            if(m_sRoomName.Length != 0)
	            return;

            m_objServerExCOM.AcceptOffHoldRequest(nSessionId);
        }

        //////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////

        public void OnCallSessionTransferBlind(int nTransfererSessionId, int nTransfererCallType, string sTransferer, string sTransferee, string sTransferTo)
        {
            if(m_sRoomName.Length != 0)
            {
                m_objServerExCOM.RejectTransfer(nTransfererSessionId);
	            return;
            }

            m_objServerExCOM.AcceptTransferBlind(nTransfererSessionId, sTransferee, sTransferee, sTransferTo, CVaxServerCOM.VAX_PEER_TYPE_USER, sTransferTo, 30);
        }

        public void OnCallSessionTransferConsult(int nTransfererSessionId, int nTransfereeSessionId, int nTransferToSessionId, int nTransfererCallType, int nTransfereeCallType, int nTransferToCallType, string sTransferer, string sTransferee, string sTransferTo)
        {
            if(m_sRoomName.Length != 0)
            {
                m_objServerExCOM.RejectTransfer(nTransfererSessionId);
	            return;
            }

            m_objServerExCOM.AcceptTransferConsult(nTransfererSessionId, nTransferToSessionId);
        }

        ////////////////////////////////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////////////////////////////////
        
        public void OnDetectedDigitDTMF(int nSessionId, int nCallType, string sDigitDTMF)
        {
           
        }
    }
}
