﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace VaxTeleServerApp
{

    /// <summary>
    /// User Route Details
    /// </summary>

    class CUserRouteDetails
    {
        public string m_sUserPrefix = "", m_sToPeerName = "", m_sDialPrefix = "";
	    public int m_nToPeerType = -1;

	    public CUserRouteDetails()
        {}
	    ~CUserRouteDetails()
        {}
    }

    /// <summary>
    /// User Route Details
    /// </summary>

    class CLineRouteDetails
    {

        public string m_sLineName = "", m_sRoomName = "", m_sToPeerName = "";
        public int m_nToPeerType = -1;
        public bool m_bRejected = false;

	    public CLineRouteDetails()
        {}
	    ~CLineRouteDetails()
        {}
    }

    /// <summary>
    /// DirectProxy Route Details
    /// </summary>

    class CDirectProxyRouteDetails
    {
        public string m_sProxyName = "", m_sRoomName = "", m_sToPeerName = "";
        public int m_nToPeerType = -1;
        public bool m_bRejected = false;

	    public CDirectProxyRouteDetails()
        {}
	    ~CDirectProxyRouteDetails(){}
    }

    ////////////////////////////////////////////////////////////////////////////////////////////
    ////////////////////////////////////////////////////////////////////////////////////////////

    class CVaxCallSessionRoute
    {

        Hashtable m_objMapUserRouteToPtr;
        Hashtable m_objMapLineRouteToPtr;
        Hashtable m_objMapDirectProxyRouteToPtr;

        CVaxServerExCOM m_objServerExCOM = null;

        public CVaxCallSessionRoute(CVaxServerExCOM objServerExCOM)
        {
            m_objServerExCOM = objServerExCOM;

            m_objMapUserRouteToPtr = new Hashtable(256);
            m_objMapLineRouteToPtr = new Hashtable(256);
            m_objMapDirectProxyRouteToPtr = new Hashtable(256);
        }

        ~CVaxCallSessionRoute()
        {
            DeleteAllUserRoutes();
            DeleteAllLineRoutes();
            DeleteAllProxyRoutes();
        }


	    private string GenKey(string sValue)
        {
            return sValue.ToLower();
        }

	    private CUserRouteDetails FindUserRoute(string sUserName)
        {
            return (CUserRouteDetails)m_objMapUserRouteToPtr[sUserName.ToLower()];
        }
	    
        private CLineRouteDetails FindLineRoute(string sLineName)
        {
            return (CLineRouteDetails)m_objMapLineRouteToPtr[sLineName.ToLower()];
        }
	    
        private CDirectProxyRouteDetails FindDirectProxyRoute(string sProxyName)
        {
            return (CDirectProxyRouteDetails)m_objMapDirectProxyRouteToPtr[sProxyName.ToLower()];
        }

	    private void DeleteAllUserRoutes()
        {
            m_objMapUserRouteToPtr.Clear();
        }
	    
        private void DeleteAllLineRoutes()
        {
            m_objMapLineRouteToPtr.Clear();
        }
	    
        private void DeleteAllProxyRoutes()
        {
            m_objMapDirectProxyRouteToPtr.Clear();
        }

	    private bool GetUserRouteDetails(string sUserName, ref string sUserPrefix, ref string sDialPrefix, ref int nToPeerType, ref string sToPeerName)
        {
            CUserRouteDetails objUserRoute = FindUserRoute(sUserName);
            if (objUserRoute == null) return false;

            sUserPrefix = objUserRoute.m_sUserPrefix;
            sDialPrefix = objUserRoute.m_sDialPrefix;

            nToPeerType = objUserRoute.m_nToPeerType;
            sToPeerName = objUserRoute.m_sToPeerName;

            return true;
        }
	 
        private bool GetLineRouteDetails(string sLineName, ref int nToPeerType, ref string sToPeerName, ref bool bRejected, ref string sRoomName)
        {

            CLineRouteDetails objLineRoute = FindLineRoute(sLineName);
            if (objLineRoute == null) return false;

            nToPeerType = objLineRoute.m_nToPeerType;
            sToPeerName = objLineRoute.m_sToPeerName;

            bRejected = objLineRoute.m_bRejected;
            sRoomName = objLineRoute.m_sRoomName;

            return true;
        }
	 
        private bool GetDirectProxyRouteDetails(string sProxyName, ref int nToPeerType, ref string sToPeerName, ref bool bRejected, ref string sRoomName)
        {
            CDirectProxyRouteDetails objProxyRoute = FindDirectProxyRoute(sProxyName);
            if (objProxyRoute == null) return false;

            nToPeerType = objProxyRoute.m_nToPeerType;
            sToPeerName = objProxyRoute.m_sToPeerName;

            bRejected = objProxyRoute.m_bRejected;
            sRoomName = objProxyRoute.m_sRoomName;

            return true;
        }

        public void ResetOBJ()
        {
            DeleteAllUserRoutes();
            DeleteAllLineRoutes();
            DeleteAllProxyRoutes();
        }

	    public bool AddUserRoute(string sUserName, string sUserPrefix, string sDialPrefix, int nToPeerType, string sToPeerName)
        {
            CUserRouteDetails objUserRoute = FindUserRoute(sUserName);
            if (objUserRoute == null)
            {
                objUserRoute = new CUserRouteDetails();

                objUserRoute.m_sUserPrefix = sUserPrefix;
                objUserRoute.m_sDialPrefix = sDialPrefix;

                objUserRoute.m_nToPeerType = nToPeerType;
                objUserRoute.m_sToPeerName = sToPeerName;

                m_objMapUserRouteToPtr.Add(sUserName.ToLower(), objUserRoute);

                return true;
            }

            objUserRoute.m_sUserPrefix = sUserPrefix;
            objUserRoute.m_sDialPrefix = sDialPrefix;

            objUserRoute.m_nToPeerType = nToPeerType;
            objUserRoute.m_sToPeerName = sToPeerName;

            m_objMapUserRouteToPtr[sUserName.ToLower()] = objUserRoute;

            return true;
        }
	
        public void RemoveUserRoute(string sUserName)
        {
            CUserRouteDetails objUserRoute = FindUserRoute(sUserName);
            if (objUserRoute == null) return;

            m_objMapUserRouteToPtr.Remove(sUserName.ToLower());
            objUserRoute = null;
        }

	    public bool AddLineRoute(string sLineName, int nToPeerType, string sToPeerName, bool bRejected, string sRoomName)
        {

            CLineRouteDetails objLineRoute = FindLineRoute(sLineName);
            if (objLineRoute == null)
            {
                objLineRoute = new CLineRouteDetails();

                objLineRoute.m_nToPeerType = nToPeerType;
                objLineRoute.m_sToPeerName = sToPeerName;

                objLineRoute.m_bRejected = bRejected;
                objLineRoute.m_sRoomName = sRoomName;

                m_objMapLineRouteToPtr.Add(sLineName.ToLower(), objLineRoute);

                return true;
            }

            objLineRoute.m_nToPeerType = nToPeerType;
            objLineRoute.m_sToPeerName = sToPeerName;

            objLineRoute.m_bRejected = bRejected;
            objLineRoute.m_sRoomName = sRoomName;

            m_objMapLineRouteToPtr[sLineName.ToLower()] = objLineRoute;

            return true;
        }
	
        public void RemoveLineRoute(string sLineName)
        {
            CLineRouteDetails objLineRoute = FindLineRoute(sLineName);
            if (objLineRoute == null) return;

            m_objMapLineRouteToPtr.Remove(sLineName.ToLower());
            objLineRoute = null;
        
        }

	    public bool AddDirectProxyRoute(string sProxyName, int nToPeerType, string sToPeerName, bool bRejected, string sRoomName)
        {

            CDirectProxyRouteDetails objProxyRoute = FindDirectProxyRoute(sProxyName);
            if (objProxyRoute == null)
            {
                objProxyRoute = new CDirectProxyRouteDetails();

                objProxyRoute.m_nToPeerType = nToPeerType;
                objProxyRoute.m_sToPeerName = sToPeerName;

                objProxyRoute.m_bRejected = bRejected;
                objProxyRoute.m_sRoomName = sRoomName;

                m_objMapDirectProxyRouteToPtr.Add(sProxyName.ToLower(), objProxyRoute);

                return true;
            }

            objProxyRoute.m_nToPeerType = nToPeerType;
            objProxyRoute.m_sToPeerName = sToPeerName;

            objProxyRoute.m_bRejected = bRejected;
            objProxyRoute.m_sRoomName = sRoomName;

            m_objMapDirectProxyRouteToPtr[sProxyName.ToLower()] = objProxyRoute;

            return true;

        }
	 
        public void RemoveDirectProxyRoute(string sProxyName)
        {
            CDirectProxyRouteDetails objProxyRoute = FindDirectProxyRoute(sProxyName);
            if (objProxyRoute == null) return;

            m_objMapDirectProxyRouteToPtr.Remove(sProxyName.ToLower());
            objProxyRoute = null;
        }
	
	    public bool OnCallFromUser(string sUserName, string sUserDialedNo, ref string sDialNo, ref int nToPeerType, ref string sToPeerName)
        {
            string sUserPrefix = "", sDialPrefix = "";

            bool bResult = GetUserRouteDetails(sUserName, ref sUserPrefix, ref sDialPrefix, ref nToPeerType, ref sToPeerName);

            // USER-ROUTE not found. Make it U2U call.

            if (!bResult || nToPeerType == -1 || sToPeerName.Equals(""))
            {
                sDialNo = sUserDialedNo;
                nToPeerType = CVaxServerCOM.VAX_PEER_TYPE_USER;
                sToPeerName = sUserDialedNo;

                return true;
            }

            int nUserPrefixLength = sUserPrefix.Length;

            // check if first 'N' charachters are equal to sUserPrefix. If YES; Modify it according to dialplan. Callee is on other server.

            if (sUserDialedNo.Substring(0, nUserPrefixLength) == sUserPrefix)
            {
                string sCallTo = sUserDialedNo.Remove(0, nUserPrefixLength);
                sDialNo = sDialPrefix + sCallTo;
            }
            else
            {
                //Make it U2U call.

                sDialNo = sUserDialedNo;
                nToPeerType = CVaxServerCOM.VAX_PEER_TYPE_USER;
                sToPeerName = sUserDialedNo;
            }

            return true;
        }
	  
        public bool OnCallFromLine(string sLineName, ref int nToPeerType, ref string sToPeerName, ref bool bRejected, ref string sRoomName)
        {
            bool bResult = GetLineRouteDetails(sLineName, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName);
            if (!bResult) return false;
            
            return true;
        }
	   
        public bool OnCallFromDirectProxySIP(string sProxyName, ref int nToPeerType, ref string sToPeerName, ref bool bRejected, ref string sRoomName)
        {
            bool bResult = GetDirectProxyRouteDetails(sProxyName, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName);
            if (!bResult) return false;

            return true;
        }
    }
}
